/*---------------------------------------------------------------------*/
/* Copyright (C)	Metso Automation (2004). All Rights Reserved	   */
/* Product:			Siemens Simatic PDM								   */
/* Device:			ND800PA positioner								   */
/* Communication:	Profibus PA/DPV1								   */
/* Dictionary:		SIPADC01.dct, ND800PA.dct						   */
/* $Revision:		3.4  $											   */
/* $Date:			19 Sept 2002 16:40:14 $							   */
/*---------------------------------------------------------------------*/

MANUFACTURER	87,
DEVICE_TYPE		2,
DEVICE_REVISION 0x0300,		/* PROFIBUS-PA-Profile for Process Control Devices, Version 3.0 */
DD_REVISION		1


#define ND800PA_DD_REV			"ND800PA Device Description v1.12"
#define DEVICE_MANUAL_FILENAME		"ND800PA_Users_Guide.pdf"
#define DEVICE_MANUAL_FILENAME_1	"7nd72en.pdf"

//#include "SI_HlpM.inc"
#include "ND_HlpM.inc"

#include "SI_FileM.inc"

//#define COMM_ERROR_DIALOG_AVAILABLE
#include "SI_OptM.inc"
#include "SIPAST.inc"

#define	BLOCK_MODE_RCAS				0x02
#define	BLOCK_MODE_AUTO				0x08
#define	BLOCK_MODE_MAN				0x10
#define	BLOCK_MODE_LOCAL_OVERRIDE	0x20
#define	BLOCK_MODE_OUT_OF_SERVICE	0x80

#define	DEVICE_TYPE_STR				"ND800PA"

#define UINT8_MAX		255
#define UINT16_MAX		65535
#define INT32_MAX		0x7FFFFFFF

#define STEP		1		
#define HYSTERESIS	2

#define CAL_TIMEOUT	10
#define CAL_POLL_TIME 5

#define ID_NONE			0
#define ID_VALVE_TEST	1
#define ID_POS_CAL		2
#define ID_POS_BIAS		3
#define ID_PRES_ZERO	4
#define ID_PRES_SPAN	5
#define ID_TEMP			6

#define CTRL_NONE		0
#define CTRL_START		1
#define CTRL_CANCEL		2
#define CTRL_STATUS		3

#define STAT_IDLE			0
#define STAT_INITIALIZING	1
#define STAT_RUNNING		2
#define STAT_CANCELED		3
#define STAT_CANCELLING		4
#define STAT_SUCCESFULL		5
#define STAT_UNSUCCESFULL	6
#define STAT_UNKNOWN		7


#define TEMP_COMP_TABLE_USER			(pos_sensor_temp_comp == 1)

#define VALID_TEMP_COMP_TABLE	\
IF (TEMP_COMP_TABLE_USER)		\
{								\
	TRUE;						\
}								\
ELSE							\
{								\
	FALSE;						\
}

#define STATUS_QUALITY						\
		{ 0x00,	[status_BAD_00]			},	\
		{ 0x01,	[status_BAD_01]			},	\
		{ 0x02,	[status_BAD_02]			},	\
		{ 0x03,	[status_BAD_03]			},	\
		{ 0x04,	[status_BAD_04]			},	\
		{ 0x05,	[status_BAD_05]			},	\
		{ 0x06,	[status_BAD_06]			},	\
		{ 0x07,	[status_BAD_07]			},	\
		{ 0x10,	[status_UNCERTAIN_00]	},	\
		{ 0x11,	[status_UNCERTAIN_01]	},	\
		{ 0x12,	[status_UNCERTAIN_02]	},	\
		{ 0x13,	[status_UNCERTAIN_03]	},	\
		{ 0x14,	[status_UNCERTAIN_04]	},	\
		{ 0x15,	[status_UNCERTAIN_05]	},	\
		{ 0x16,	[status_UNCERTAIN_06]	},	\
		{ 0x17,	[status_UNCERTAIN_07]	},	\
		{ 0x20,	[status_GOOD_00]		},	\
		{ 0x21,	[status_GOOD_01]		},	\
		{ 0x22,	[status_GOOD_02]		},	\
		{ 0x23,	[status_GOOD_03]		},	\
		{ 0x24,	[status_GOOD_04]		},	\
		{ 0x25,	[status_GOOD_05]		},	\
		{ 0x26,	[status_GOOD_06]		},	\
		{ 0x28,	[status_GOOD_08]		},	\
		{ 0x29,	[status_GOOD_09]		},  \
		{ 0x30,	[status_GOOD_RCAS_00]	},	\
		{ 0x31,	[status_GOOD_RCAS_01]	},	\
		{ 0x32,	[status_GOOD_RCAS_02]	},	\
		{ 0x33,	[status_GOOD_RCAS_03]	},	\
		{ 0x34,	[status_GOOD_RCAS_04]	},	\
		{ 0x35,	[status_GOOD_RCAS_05]	},	\
		{ 0x36,	[status_GOOD_RCAS_06]	},	\
		{ 0x37,	[status_GOOD_RCAS_07]	},	\
		{ 0x38,	[status_GOOD_RCAS_08]	}

#define STATUS_LIMIT								\
		{ 0x00,	[status_limit_OK]				},	\
		{ 0x01,	[status_limit_UNDERFLOW]		},	\
		{ 0x02,	[status_limit_OVERFLOW]			},	\
		{ 0x03,	[status_limit_VALUE_CONSTANT]	}


#define UNIT_LIST									    \
		{ 1000,	[unit_1000],	[unit_1000_help]	},	\
		{ 1001,	[unit_1001],	[unit_1001_help]	},	\
		{ 1002,	[unit_1002],	[unit_1002_help]	},	\
		{ 1003,	[unit_1003],	[unit_1003_help]	},	\
		{ 1004,	[unit_1004],	[unit_1004_help]	},	\
		{ 1005,	[unit_1005],	[unit_1005_help]	},	\
		{ 1006,	[unit_1006],	[unit_1006_help]	},	\
		{ 1007,	[unit_1007],	[unit_1007_help]	},	\
		{ 1008,	[unit_1008],	[unit_1008_help]	},	\
		{ 1009,	[unit_1009],	[unit_1009_help]	},	\
		{ 1010,	[unit_1010],	[unit_1010_help]	},	\
		{ 1011,	[unit_1011],	[unit_1011_help]	},	\
		{ 1012,	[unit_1012],	[unit_1012_help]	},	\
		{ 1013,	[unit_1013],	[unit_1013_help]	},	\
		{ 1014,	[unit_1014],	[unit_1014_help]	},	\
		{ 1015,	[unit_1015],	[unit_1015_help]	},	\
		{ 1016,	[unit_1016],	[unit_1016_help]	},	\
		{ 1017,	[unit_1017],	[unit_1017_help]	},	\
		{ 1018,	[unit_1018],	[unit_1018_help]	},	\
		{ 1019,	[unit_1019],	[unit_1019_help]	},	\
		{ 1020,	[unit_1020],	[unit_1020_help]	},	\
		{ 1021,	[unit_1021],	[unit_1021_help]	},	\
		{ 1022,	[unit_1022],	[unit_1022_help]	},	\
		{ 1023,	[unit_1023],	[unit_1023_help]	},	\
		{ 1024,	[unit_1024],	[unit_1024_help]	},	\
		{ 1025,	[unit_1025],	[unit_1025_help]	},	\
		{ 1026,	[unit_1026],	[unit_1026_help]	},	\
		{ 1027,	[unit_1027],	[unit_1027_help]	},	\
		{ 1028,	[unit_1028],	[unit_1028_help]	},	\
		{ 1029,	[unit_1029],	[unit_1029_help]	},	\
		{ 1030,	[unit_1030],	[unit_1030_help]	},	\
		{ 1031,	[unit_1031],	[unit_1031_help]	},	\
		{ 1032,	[unit_1032],	[unit_1032_help]	},	\
		{ 1033,	[unit_1033],	[unit_1033_help]	},	\
		{ 1034,	[unit_1034],	[unit_1034_help]	},	\
		{ 1035,	[unit_1035],	[unit_1035_help]	},	\
		{ 1036,	[unit_1036],	[unit_1036_help]	},	\
		{ 1037,	[unit_1037],	[unit_1037_help]	},	\
		{ 1038,	[unit_1038],	[unit_1038_help]	},	\
		{ 1039,	[unit_1039],	[unit_1039_help]	},	\
		{ 1040,	[unit_1040],	[unit_1040_help]	},	\
		{ 1041,	[unit_1041],	[unit_1041_help]	},	\
		{ 1042,	[unit_1042],	[unit_1042_help]	},	\
		{ 1043,	[unit_1043],	[unit_1043_help]	},	\
		{ 1044,	[unit_1044],	[unit_1044_help]	},	\
		{ 1045,	[unit_1045],	[unit_1045_help]	},	\
		{ 1046,	[unit_1046],	[unit_1046_help]	},	\
		{ 1047,	[unit_1047],	[unit_1047_help]	},	\
		{ 1048,	[unit_1048],	[unit_1048_help]	},	\
		{ 1049,	[unit_1049],	[unit_1049_help]	},	\
		{ 1050,	[unit_1050],	[unit_1050_help]	},	\
		{ 1051,	[unit_1051],	[unit_1051_help]	},	\
		{ 1052,	[unit_1052],	[unit_1052_help]	},	\
		{ 1053,	[unit_1053],	[unit_1053_help]	},	\
		{ 1054,	[unit_1054],	[unit_1054_help]	},	\
		{ 1055,	[unit_1055],	[unit_1055_help]	},	\
		{ 1056,	[unit_1056],	[unit_1056_help]	},	\
		{ 1057,	[unit_1057],	[unit_1057_help]	},	\
		{ 1058,	[unit_1058],	[unit_1058_help]	},	\
		{ 1059,	[unit_1059],	[unit_1059_help]	},	\
		{ 1060,	[unit_1060],	[unit_1060_help]	},	\
		{ 1061,	[unit_1061],	[unit_1061_help]	},	\
		{ 1062,	[unit_1062],	[unit_1062_help]	},	\
		{ 1063,	[unit_1063],	[unit_1063_help]	},	\
		{ 1064,	[unit_1064],	[unit_1064_help]	},	\
		{ 1065,	[unit_1065],	[unit_1065_help]	},	\
		{ 1066,	[unit_1066],	[unit_1066_help]	},	\
		{ 1067,	[unit_1067],	[unit_1067_help]	},	\
		{ 1068,	[unit_1068],	[unit_1068_help]	},	\
		{ 1069,	[unit_1069],	[unit_1069_help]	},	\
		{ 1070,	[unit_1070],	[unit_1070_help]	},	\
		{ 1071,	[unit_1071],	[unit_1071_help]	},	\
		{ 1072,	[unit_1072],	[unit_1072_help]	},	\
		{ 1073,	[unit_1073],	[unit_1073_help]	},	\
		{ 1074,	[unit_1074],	[unit_1074_help]	},	\
		{ 1075,	[unit_1075],	[unit_1075_help]	},	\
		{ 1076,	[unit_1076],	[unit_1076_help]	},	\
		{ 1077,	[unit_1077],	[unit_1077_help]	},	\
		{ 1078,	[unit_1078],	[unit_1078_help]	},	\
		{ 1079,	[unit_1079],	[unit_1079_help]	},	\
		{ 1080,	[unit_1080],	[unit_1080_help]	},	\
		{ 1081,	[unit_1081],	[unit_1081_help]	},	\
		{ 1082,	[unit_1082],	[unit_1082_help]	},	\
		{ 1083,	[unit_1083],	[unit_1083_help]	},	\
		{ 1084,	[unit_1084],	[unit_1084_help]	},	\
		{ 1085,	[unit_1085],	[unit_1085_help]	},	\
		{ 1086,	[unit_1086],	[unit_1086_help]	},	\
		{ 1087,	[unit_1087],	[unit_1087_help]	},	\
		{ 1088,	[unit_1088],	[unit_1088_help]	},	\
		{ 1089,	[unit_1089],	[unit_1089_help]	},	\
		{ 1090,	[unit_1090],	[unit_1090_help]	},	\
		{ 1091,	[unit_1091],	[unit_1091_help]	},	\
		{ 1092,	[unit_1092],	[unit_1092_help]	},	\
		{ 1093,	[unit_1093],	[unit_1093_help]	},	\
		{ 1094,	[unit_1094],	[unit_1094_help]	},	\
		{ 1095,	[unit_1095],	[unit_1095_help]	},	\
		{ 1096,	[unit_1096],	[unit_1096_help]	},	\
		{ 1097,	[unit_1097],	[unit_1097_help]	},	\
		{ 1098,	[unit_1098],	[unit_1098_help]	},	\
		{ 1099,	[unit_1099],	[unit_1099_help]	},	\
		{ 1100,	[unit_1100],	[unit_1100_help]	},	\
		{ 1101,	[unit_1101],	[unit_1101_help]	},	\
		{ 1102,	[unit_1102],	[unit_1102_help]	},	\
		{ 1103,	[unit_1103],	[unit_1103_help]	},	\
		{ 1104,	[unit_1104],	[unit_1104_help]	},	\
		{ 1105,	[unit_1105],	[unit_1105_help]	},	\
		{ 1106,	[unit_1106],	[unit_1106_help]	},	\
		{ 1107,	[unit_1107],	[unit_1107_help]	},	\
		{ 1108,	[unit_1108],	[unit_1108_help]	},	\
		{ 1109,	[unit_1109],	[unit_1109_help]	},	\
		{ 1110,	[unit_1110],	[unit_1110_help]	},	\
		{ 1111,	[unit_1111],	[unit_1111_help]	},	\
		{ 1112,	[unit_1112],	[unit_1112_help]	},	\
		{ 1113,	[unit_1113],	[unit_1113_help]	},	\
		{ 1114,	[unit_1114],	[unit_1114_help]	},	\
		{ 1115,	[unit_1115],	[unit_1115_help]	},	\
		{ 1116,	[unit_1116],	[unit_1116_help]	},	\
		{ 1117,	[unit_1117],	[unit_1117_help]	},	\
		{ 1118,	[unit_1118],	[unit_1118_help]	},	\
		{ 1119,	[unit_1119],	[unit_1119_help]	},	\
		{ 1120,	[unit_1120],	[unit_1120_help]	},	\
		{ 1121,	[unit_1121],	[unit_1121_help]	},	\
		{ 1122,	[unit_1122],	[unit_1122_help]	},	\
		{ 1123,	[unit_1123],	[unit_1123_help]	},	\
		{ 1124,	[unit_1124],	[unit_1124_help]	},	\
		{ 1125,	[unit_1125],	[unit_1125_help]	},	\
		{ 1126,	[unit_1126],	[unit_1126_help]	},	\
		{ 1127,	[unit_1127],	[unit_1127_help]	},	\
		{ 1128,	[unit_1128],	[unit_1128_help]	},	\
		{ 1129,	[unit_1129],	[unit_1129_help]	},	\
		{ 1130,	[unit_1130],	[unit_1130_help]	},	\
		{ 1131,	[unit_1131],	[unit_1131_help]	},	\
		{ 1132,	[unit_1132],	[unit_1132_help]	},	\
		{ 1133,	[unit_1133],	[unit_1133_help]	},	\
		{ 1134,	[unit_1134],	[unit_1134_help]	},	\
		{ 1135,	[unit_1135],	[unit_1135_help]	},	\
		{ 1136,	[unit_1136],	[unit_1136_help]	},	\
		{ 1137,	[unit_1137],	[unit_1137_help]	},	\
		{ 1138,	[unit_1138],	[unit_1138_help]	},	\
		{ 1139,	[unit_1139],	[unit_1139_help]	},	\
		{ 1140,	[unit_1140],	[unit_1140_help]	},	\
		{ 1141,	[unit_1141],	[unit_1141_help]	},	\
		{ 1142,	[unit_1142],	[unit_1142_help]	},	\
		{ 1143,	[unit_1143],	[unit_1143_help]	},	\
		{ 1144,	[unit_1144],	[unit_1144_help]	},	\
		{ 1145,	[unit_1145],	[unit_1145_help]	},	\
		{ 1146,	[unit_1146],	[unit_1146_help]	},	\
		{ 1147,	[unit_1147],	[unit_1147_help]	},	\
		{ 1148,	[unit_1148],	[unit_1148_help]	},	\
		{ 1149,	[unit_1149],	[unit_1149_help]	},	\
		{ 1150,	[unit_1150],	[unit_1150_help]	},	\
		{ 1151,	[unit_1151],	[unit_1151_help]	},	\
		{ 1152,	[unit_1152],	[unit_1152_help]	},	\
		{ 1153,	[unit_1153],	[unit_1153_help]	},	\
		{ 1154,	[unit_1154],	[unit_1154_help]	},	\
		{ 1155,	[unit_1155],	[unit_1155_help]	},	\
		{ 1156,	[unit_1156],	[unit_1156_help]	},	\
		{ 1157,	[unit_1157],	[unit_1157_help]	},	\
		{ 1158,	[unit_1158],	[unit_1158_help]	},	\
		{ 1159,	[unit_1159],	[unit_1159_help]	},	\
		{ 1160,	[unit_1160],	[unit_1160_help]	},	\
		{ 1161,	[unit_1161],	[unit_1161_help]	},	\
		{ 1162,	[unit_1162],	[unit_1162_help]	},	\
		{ 1163,	[unit_1163],	[unit_1163_help]	},	\
		{ 1164,	[unit_1164],	[unit_1164_help]	},	\
		{ 1165,	[unit_1165],	[unit_1165_help]	},	\
		{ 1166,	[unit_1166],	[unit_1166_help]	},	\
		{ 1167,	[unit_1167],	[unit_1167_help]	},	\
		{ 1168,	[unit_1168],	[unit_1168_help]	},	\
		{ 1169,	[unit_1169],	[unit_1169_help]	},	\
		{ 1170,	[unit_1170],	[unit_1170_help]	},	\
		{ 1171,	[unit_1171],	[unit_1171_help]	},	\
		{ 1172,	[unit_1172],	[unit_1172_help]	},	\
		{ 1173,	[unit_1173],	[unit_1173_help]	},	\
		{ 1174,	[unit_1174],	[unit_1174_help]	},	\
		{ 1175,	[unit_1175],	[unit_1175_help]	},	\
		{ 1176,	[unit_1176],	[unit_1176_help]	},	\
		{ 1177,	[unit_1177],	[unit_1177_help]	},	\
		{ 1178,	[unit_1178],	[unit_1178_help]	},	\
		{ 1179,	[unit_1179],	[unit_1179_help]	},	\
		{ 1180,	[unit_1180],	[unit_1180_help]	},	\
		{ 1181,	[unit_1181],	[unit_1181_help]	},	\
		{ 1182,	[unit_1182],	[unit_1182_help]	},	\
		{ 1183,	[unit_1183],	[unit_1183_help]	},	\
		{ 1184,	[unit_1184],	[unit_1184_help]	},	\
		{ 1185,	[unit_1185],	[unit_1185_help]	},	\
		{ 1186,	[unit_1186],	[unit_1186_help]	},	\
		{ 1187,	[unit_1187],	[unit_1187_help]	},	\
		{ 1188,	[unit_1188],	[unit_1188_help]	},	\
		{ 1189,	[unit_1189],	[unit_1189_help]	},	\
		{ 1190,	[unit_1190],	[unit_1190_help]	},	\
		{ 1191,	[unit_1191],	[unit_1191_help]	},	\
		{ 1192,	[unit_1192],	[unit_1192_help]	},	\
		{ 1193,	[unit_1193],	[unit_1193_help]	},	\
		{ 1194,	[unit_1194],	[unit_1194_help]	},	\
		{ 1195,	[unit_1195],	[unit_1195_help]	},	\
		{ 1196,	[unit_1196],	[unit_1196_help]	},	\
		{ 1197,	[unit_1197],	[unit_1197_help]	},	\
		{ 1198,	[unit_1198],	[unit_1198_help]	},	\
		{ 1199,	[unit_1199],	[unit_1199_help]	},	\
		{ 1200,	[unit_1200],	[unit_1200_help]	},	\
		{ 1201,	[unit_1201],	[unit_1201_help]	},	\
		{ 1202,	[unit_1202],	[unit_1202_help]	},	\
		{ 1203,	[unit_1203],	[unit_1203_help]	},	\
		{ 1204,	[unit_1204],	[unit_1204_help]	},	\
		{ 1205,	[unit_1205],	[unit_1205_help]	},	\
		{ 1206,	[unit_1206],	[unit_1206_help]	},	\
		{ 1207,	[unit_1207],	[unit_1207_help]	},	\
		{ 1208,	[unit_1208],	[unit_1208_help]	},	\
		{ 1209,	[unit_1209],	[unit_1209_help]	},	\
		{ 1210,	[unit_1210],	[unit_1210_help]	},	\
		{ 1211,	[unit_1211],	[unit_1211_help]	},	\
		{ 1212,	[unit_1212],	[unit_1212_help]	},	\
		{ 1213,	[unit_1213],	[unit_1213_help]	},	\
		{ 1214,	[unit_1214],	[unit_1214_help]	},	\
		{ 1215,	[unit_1215],	[unit_1215_help]	},	\
		{ 1216,	[unit_1216],	[unit_1216_help]	},	\
		{ 1217,	[unit_1217],	[unit_1217_help]	},	\
		{ 1218,	[unit_1218],	[unit_1218_help]	},	\
		{ 1219,	[unit_1219],	[unit_1219_help]	},	\
		{ 1220,	[unit_1220],	[unit_1220_help]	},	\
		{ 1221,	[unit_1221],	[unit_1221_help]	},	\
		{ 1222,	[unit_1222],	[unit_1222_help]	},	\
		{ 1223,	[unit_1223],	[unit_1223_help]	},	\
		{ 1224,	[unit_1224],	[unit_1224_help]	},	\
		{ 1225,	[unit_1225],	[unit_1225_help]	},	\
		{ 1226,	[unit_1226],	[unit_1226_help]	},	\
		{ 1227,	[unit_1227],	[unit_1227_help]	},	\
		{ 1228,	[unit_1228],	[unit_1228_help]	},	\
		{ 1229,	[unit_1229],	[unit_1229_help]	},	\
		{ 1230,	[unit_1230],	[unit_1230_help]	},	\
		{ 1231,	[unit_1231],	[unit_1231_help]	},	\
		{ 1232,	[unit_1232],	[unit_1232_help]	},	\
		{ 1233,	[unit_1233],	[unit_1233_help]	},	\
		{ 1234,	[unit_1234],	[unit_1234_help]	},	\
		{ 1235,	[unit_1235],	[unit_1235_help]	},	\
		{ 1236,	[unit_1236],	[unit_1236_help]	},	\
		{ 1237,	[unit_1237],	[unit_1237_help]	},	\
		{ 1238,	[unit_1238],	[unit_1238_help]	},	\
		{ 1239,	[unit_1239],	[unit_1239_help]	},	\
		{ 1240,	[unit_1240],	[unit_1240_help]	},	\
		{ 1241,	[unit_1241],	[unit_1241_help]	},	\
		{ 1242,	[unit_1242],	[unit_1242_help]	},	\
		{ 1243,	[unit_1243],	[unit_1243_help]	},	\
		{ 1244,	[unit_1244],	[unit_1244_help]	},	\
		{ 1245,	[unit_1245],	[unit_1245_help]	},	\
		{ 1246,	[unit_1246],	[unit_1246_help]	},	\
		{ 1247,	[unit_1247],	[unit_1247_help]	},	\
		{ 1248,	[unit_1248],	[unit_1248_help]	},	\
		{ 1249,	[unit_1249],	[unit_1249_help]	},	\
		{ 1250,	[unit_1250],	[unit_1250_help]	},	\
		{ 1251,	[unit_1251],	[unit_1251_help]	},	\
		{ 1252,	[unit_1252],	[unit_1252_help]	},	\
		{ 1253,	[unit_1253],	[unit_1253_help]	},	\
		{ 1254,	[unit_1254],	[unit_1254_help]	},	\
		{ 1255,	[unit_1255],	[unit_1255_help]	},	\
		{ 1256,	[unit_1256],	[unit_1256_help]	},	\
		{ 1257,	[unit_1257],	[unit_1257_help]	},	\
		{ 1258,	[unit_1258],	[unit_1258_help]	},	\
		{ 1259,	[unit_1259],	[unit_1259_help]	},	\
		{ 1260,	[unit_1260],	[unit_1260_help]	},	\
		{ 1261,	[unit_1261],	[unit_1261_help]	},	\
		{ 1262,	[unit_1262],	[unit_1262_help]	},	\
		{ 1263,	[unit_1263],	[unit_1263_help]	},	\
		{ 1264,	[unit_1264],	[unit_1264_help]	},	\
		{ 1265,	[unit_1265],	[unit_1265_help]	},	\
		{ 1266,	[unit_1266],	[unit_1266_help]	},	\
		{ 1267,	[unit_1267],	[unit_1267_help]	},	\
		{ 1268,	[unit_1268],	[unit_1268_help]	},	\
		{ 1269,	[unit_1269],	[unit_1269_help]	},	\
		{ 1270,	[unit_1270],	[unit_1270_help]	},	\
		{ 1271,	[unit_1271],	[unit_1271_help]	},	\
		{ 1272,	[unit_1272],	[unit_1272_help]	},	\
		{ 1273,	[unit_1273],	[unit_1273_help]	},	\
		{ 1274,	[unit_1274],	[unit_1274_help]	},	\
		{ 1275,	[unit_1275],	[unit_1275_help]	},	\
		{ 1276,	[unit_1276],	[unit_1276_help]	},	\
		{ 1277,	[unit_1277],	[unit_1277_help]	},	\
		{ 1278,	[unit_1278],	[unit_1278_help]	},	\
		{ 1279,	[unit_1279],	[unit_1279_help]	},	\
		{ 1280,	[unit_1280],	[unit_1280_help]	},	\
		{ 1281,	[unit_1281],	[unit_1281_help]	},	\
		{ 1282,	[unit_1282],	[unit_1282_help]	},	\
		{ 1283,	[unit_1283],	[unit_1283_help]	},	\
		{ 1284,	[unit_1284],	[unit_1284_help]	},	\
		{ 1285,	[unit_1285],	[unit_1285_help]	},	\
		{ 1286,	[unit_1286],	[unit_1286_help]	},	\
		{ 1287,	[unit_1287],	[unit_1287_help]	},	\
		{ 1288,	[unit_1288],	[unit_1288_help]	},	\
		{ 1289,	[unit_1289],	[unit_1289_help]	},	\
		{ 1290,	[unit_1290],	[unit_1290_help]	},	\
		{ 1291,	[unit_1291],	[unit_1291_help]	},	\
		{ 1292,	[unit_1292],	[unit_1292_help]	},	\
		{ 1293,	[unit_1293],	[unit_1293_help]	},	\
		{ 1294,	[unit_1294],	[unit_1294_help]	},	\
		{ 1295,	[unit_1295],	[unit_1295_help]	},	\
		{ 1296,	[unit_1296],	[unit_1296_help]	},	\
		{ 1297,	[unit_1297],	[unit_1297_help]	},	\
		{ 1298,	[unit_1298],	[unit_1298_help]	},	\
		{ 1299,	[unit_1299],	[unit_1299_help]	},	\
		{ 1300,	[unit_1300],	[unit_1300_help]	},	\
		{ 1301,	[unit_1301],	[unit_1301_help]	},	\
		{ 1302,	[unit_1302],	[unit_1302_help]	},	\
		{ 1303,	[unit_1303],	[unit_1303_help]	},	\
		{ 1304,	[unit_1304],	[unit_1304_help]	},	\
		{ 1305,	[unit_1305],	[unit_1305_help]	},	\
		{ 1306,	[unit_1306],	[unit_1306_help]	},	\
		{ 1307,	[unit_1307],	[unit_1307_help]	},	\
		{ 1308,	[unit_1308],	[unit_1308_help]	},	\
		{ 1309,	[unit_1309],	[unit_1309_help]	},	\
		{ 1310,	[unit_1310],	[unit_1310_help]	},	\
		{ 1311,	[unit_1311],	[unit_1311_help]	},	\
		{ 1312,	[unit_1312],	[unit_1312_help]	},	\
		{ 1313,	[unit_1313],	[unit_1313_help]	},	\
		{ 1314,	[unit_1314],	[unit_1314_help]	},	\
		{ 1315,	[unit_1315],	[unit_1315_help]	},	\
		{ 1316,	[unit_1316],	[unit_1316_help]	},	\
		{ 1317,	[unit_1317],	[unit_1317_help]	},	\
		{ 1318,	[unit_1318],	[unit_1318_help]	},	\
		{ 1319,	[unit_1319],	[unit_1319_help]	},	\
		{ 1320,	[unit_1320],	[unit_1320_help]	},	\
		{ 1321,	[unit_1321],	[unit_1321_help]	},	\
		{ 1322,	[unit_1322],	[unit_1322_help]	},	\
		{ 1323,	[unit_1323],	[unit_1323_help]	},	\
		{ 1324,	[unit_1324],	[unit_1324_help]	},	\
		{ 1325,	[unit_1325],	[unit_1325_help]	},	\
		{ 1326,	[unit_1326],	[unit_1326_help]	},	\
		{ 1327,	[unit_1327],	[unit_1327_help]	},	\
		{ 1328,	[unit_1328],	[unit_1328_help]	},	\
		{ 1329,	[unit_1329],	[unit_1329_help]	},	\
		{ 1330,	[unit_1330],	[unit_1330_help]	},	\
		{ 1331,	[unit_1331],	[unit_1331_help]	},	\
		{ 1332,	[unit_1332],	[unit_1332_help]	},	\
		{ 1333,	[unit_1333],	[unit_1333_help]	},	\
		{ 1334,	[unit_1334],	[unit_1334_help]	},	\
		{ 1335,	[unit_1335],	[unit_1335_help]	},	\
		{ 1336,	[unit_1336],	[unit_1336_help]	},	\
		{ 1337,	[unit_1337],	[unit_1337_help]	},	\
		{ 1338,	[unit_1338],	[unit_1338_help]	},	\
		{ 1339,	[unit_1339],	[unit_1339_help]	},	\
		{ 1340,	[unit_1340],	[unit_1340_help]	},	\
		{ 1341,	[unit_1341],	[unit_1341_help]	},	\
		{ 1342,	[unit_1342],	[unit_1342_help]	},	\
		{ 1343,	[unit_1343],	[unit_1343_help]	},	\
		{ 1344,	[unit_1344],	[unit_1344_help]	},	\
		{ 1345,	[unit_1345],	[unit_1345_help]	},	\
		{ 1346,	[unit_1346],	[unit_1346_help]	},	\
		{ 1347,	[unit_1347],	[unit_1347_help]	},	\
		{ 1348,	[unit_1348],	[unit_1348_help]	},	\
		{ 1349,	[unit_1349],	[unit_1349_help]	},	\
		{ 1350,	[unit_1350],	[unit_1350_help]	},	\
		{ 1351,	[unit_1351],	[unit_1351_help]	},	\
		{ 1352,	[unit_1352],	[unit_1352_help]	},	\
		{ 1353,	[unit_1353],	[unit_1353_help]	},	\
		{ 1354,	[unit_1354],	[unit_1354_help]	},	\
		{ 1355,	[unit_1355],	[unit_1355_help]	},	\
		{ 1356,	[unit_1356],	[unit_1356_help]	},	\
		{ 1357,	[unit_1357],	[unit_1357_help]	},	\
		{ 1358,	[unit_1358],	[unit_1358_help]	},	\
		{ 1359,	[unit_1359],	[unit_1359_help]	},	\
		{ 1360,	[unit_1360],	[unit_1360_help]	},	\
		{ 1361,	[unit_1361],	[unit_1361_help]	},	\
		{ 1362,	[unit_1362],	[unit_1362_help]	},	\
		{ 1363,	[unit_1363],	[unit_1363_help]	},	\
		{ 1364,	[unit_1364],	[unit_1364_help]	},	\
		{ 1365,	[unit_1365],	[unit_1365_help]	},	\
		{ 1366,	[unit_1366],	[unit_1366_help]	},	\
		{ 1367,	[unit_1367],	[unit_1367_help]	},	\
		{ 1368,	[unit_1368],	[unit_1368_help]	},	\
		{ 1369,	[unit_1369],	[unit_1369_help]	},	\
		{ 1370,	[unit_1370],	[unit_1370_help]	},	\
		{ 1371,	[unit_1371],	[unit_1371_help]	},	\
		{ 1372,	[unit_1372],	[unit_1372_help]	},	\
		{ 1373,	[unit_1373],	[unit_1373_help]	},	\
		{ 1374,	[unit_1374],	[unit_1374_help]	},	\
		{ 1375,	[unit_1375],	[unit_1375_help]	},	\
		{ 1376,	[unit_1376],	[unit_1376_help]	},	\
		{ 1377,	[unit_1377],	[unit_1377_help]	},	\
		{ 1378,	[unit_1378],	[unit_1378_help]	},	\
		{ 1379,	[unit_1379],	[unit_1379_help]	},	\
		{ 1380,	[unit_1380],	[unit_1380_help]	},	\
		{ 1381,	[unit_1381],	[unit_1381_help]	},	\
		{ 1382,	[unit_1382],	[unit_1382_help]	},	\
		{ 1383,	[unit_1383],	[unit_1383_help]	},	\
		{ 1384,	[unit_1384],	[unit_1384_help]	},	\
		{ 1385,	[unit_1385],	[unit_1385_help]	},	\
		{ 1386,	[unit_1386],	[unit_1386_help]	},	\
		{ 1387,	[unit_1387],	[unit_1387_help]	},	\
		{ 1388,	[unit_1388],	[unit_1388_help]	},	\
		{ 1389,	[unit_1389],	[unit_1389_help]	},	\
		{ 1390,	[unit_1390],	[unit_1390_help]	},	\
		{ 1391,	[unit_1391],	[unit_1391_help]	},	\
		{ 1392,	[unit_1392],	[unit_1392_help]	},	\
		{ 1393,	[unit_1393],	[unit_1393_help]	},	\
		{ 1394,	[unit_1394],	[unit_1394_help]	},	\
		{ 1395,	[unit_1395],	[unit_1395_help]	},	\
		{ 1396,	[unit_1396],	[unit_1396_help]	},	\
		{ 1397,	[unit_1397],	[unit_1397_help]	},	\
		{ 1398,	[unit_1398],	[unit_1398_help]	},	\
		{ 1399,	[unit_1399],	[unit_1399_help]	},	\
		{ 1400,	[unit_1400],	[unit_1400_help]	},	\
		{ 1401,	[unit_1401],	[unit_1401_help]	},	\
		{ 1402,	[unit_1402],	[unit_1402_help]	},	\
		{ 1403,	[unit_1403],	[unit_1403_help]	},	\
		{ 1404,	[unit_1404],	[unit_1404_help]	},	\
		{ 1405,	[unit_1405],	[unit_1405_help]	},	\
		{ 1406,	[unit_1406],	[unit_1406_help]	},	\
		{ 1407,	[unit_1407],	[unit_1407_help]	},	\
		{ 1408,	[unit_1408],	[unit_1408_help]	},	\
		{ 1409,	[unit_1409],	[unit_1409_help]	},	\
		{ 1410,	[unit_1410],	[unit_1410_help]	},	\
		{ 1411,	[unit_1411],	[unit_1411_help]	},	\
		{ 1412,	[unit_1412],	[unit_1412_help]	},	\
		{ 1413,	[unit_1413],	[unit_1413_help]	},	\
		{ 1414,	[unit_1414],	[unit_1414_help]	},	\
		{ 1415,	[unit_1415],	[unit_1415_help]	},	\
		{ 1416,	[unit_1416],	[unit_1416_help]	},	\
		{ 1417,	[unit_1417],	[unit_1417_help]	},	\
		{ 1418,	[unit_1418],	[unit_1418_help]	},	\
		{ 1419,	[unit_1419],	[unit_1419_help]	},	\
		{ 1420,	[unit_1420],	[unit_1420_help]	},	\
		{ 1421,	[unit_1421],	[unit_1421_help]	},	\
		{ 1422,	[unit_1422],	[unit_1422_help]	},	\
		{ 1423,	[unit_1423],	[unit_1423_help]	},	\
		{ 1424,	[unit_1424],	[unit_1424_help]	},	\
		{ 1425,	[unit_1425],	[unit_1425_help]	},	\
		{ 1426,	[unit_1426],	[unit_1426_help]	},	\
		{ 1427,	[unit_1427],	[unit_1427_help]	},	\
		{ 1428,	[unit_1428],	[unit_1428_help]	},	\
		{ 1429,	[unit_1429],	[unit_1429_help]	},	\
		{ 1430,	[unit_1430],	[unit_1430_help]	},	\
		{ 1431,	[unit_1431],	[unit_1431_help]	},	\
		{ 1432,	[unit_1432],	[unit_1432_help]	},	\
		{ 1433,	[unit_1433],	[unit_1433_help]	},	\
		{ 1434,	[unit_1434],	[unit_1434_help]	},	\
		{ 1435,	[unit_1435],	[unit_1435_help]	},	\
		{ 1436,	[unit_1436],	[unit_1436_help]	},	\
		{ 1437,	[unit_1437],	[unit_1437_help]	},	\
		{ 1438,	[unit_1438],	[unit_1438_help]	},	\
		{ 1439,	[unit_1439],	[unit_1439_help]	},	\
		{ 1440,	[unit_1440],	[unit_1440_help]	},	\
		{ 1441,	[unit_1441],	[unit_1441_help]	},	\
		{ 1442,	[unit_1442],	[unit_1442_help]	},	\
		{ 1443,	[unit_1443],	[unit_1443_help]	},	\
		{ 1444,	[unit_1444],	[unit_1444_help]	},	\
		{ 1445,	[unit_1445],	[unit_1445_help]	},	\
		{ 1446,	[unit_1446],	[unit_1446_help]	},	\
		{ 1447,	[unit_1447],	[unit_1447_help]	},	\
		{ 1448,	[unit_1448],	[unit_1448_help]	},	\
		{ 1449,	[unit_1449],	[unit_1449_help]	},	\
		{ 1450,	[unit_1450],	[unit_1450_help]	},	\
		{ 1451,	[unit_1451],	[unit_1451_help]	},	\
		{ 1452,	[unit_1452],	[unit_1452_help]	},	\
		{ 1453,	[unit_1453],	[unit_1453_help]	},	\
		{ 1454,	[unit_1454],	[unit_1454_help]	},	\
		{ 1455,	[unit_1455],	[unit_1455_help]	},	\
		{ 1456,	[unit_1456],	[unit_1456_help]	},	\
		{ 1457,	[unit_1457],	[unit_1457_help]	},	\
		{ 1458,	[unit_1458],	[unit_1458_help]	},	\
		{ 1459,	[unit_1459],	[unit_1459_help]	},	\
		{ 1460,	[unit_1460],	[unit_1460_help]	},	\
		{ 1461,	[unit_1461],	[unit_1461_help]	},	\
		{ 1462,	[unit_1462],	[unit_1462_help]	},	\
		{ 1463,	[unit_1463],	[unit_1463_help]	},	\
		{ 1464,	[unit_1464],	[unit_1464_help]	},	\
		{ 1465,	[unit_1465],	[unit_1465_help]	},	\
		{ 1466,	[unit_1466],	[unit_1466_help]	},	\
		{ 1467,	[unit_1467],	[unit_1467_help]	},	\
		{ 1468,	[unit_1468],	[unit_1468_help]	},	\
		{ 1469,	[unit_1469],	[unit_1469_help]	},	\
		{ 1470,	[unit_1470],	[unit_1470_help]	},	\
		{ 1471,	[unit_1471],	[unit_1471_help]	},	\
		{ 1472,	[unit_1472],	[unit_1472_help]	},	\
		{ 1473,	[unit_1473],	[unit_1473_help]	},	\
		{ 1474,	[unit_1474],	[unit_1474_help]	},	\
		{ 1475,	[unit_1475],	[unit_1475_help]	},	\
		{ 1476,	[unit_1476],	[unit_1476_help]	},	\
		{ 1477,	[unit_1477],	[unit_1477_help]	},	\
		{ 1478,	[unit_1478],	[unit_1478_help]	},	\
		{ 1479,	[unit_1479],	[unit_1479_help]	},	\
		{ 1480,	[unit_1480],	[unit_1480_help]	},	\
		{ 1481,	[unit_1481],	[unit_1481_help]	},	\
		{ 1482,	[unit_1482],	[unit_1482_help]	},	\
		{ 1483,	[unit_1483],	[unit_1483_help]	},	\
		{ 1484,	[unit_1484],	[unit_1484_help]	},	\
		{ 1485,	[unit_1485],	[unit_1485_help]	},	\
		{ 1486,	[unit_1486],	[unit_1486_help]	},	\
		{ 1487,	[unit_1487],	[unit_1487_help]	},	\
		{ 1488,	[unit_1488],	[unit_1488_help]	},	\
		{ 1489,	[unit_1489],	[unit_1489_help]	},	\
		{ 1490,	[unit_1490],	[unit_1490_help]	},	\
		{ 1491,	[unit_1491],	[unit_1491_help]	},	\
		{ 1492,	[unit_1492],	[unit_1492_help]	},	\
		{ 1493,	[unit_1493],	[unit_1493_help]	},	\
		{ 1494,	[unit_1494],	[unit_1494_help]	},	\
		{ 1495,	[unit_1495],	[unit_1495_help]	},	\
		{ 1496,	[unit_1496],	[unit_1496_help]	},	\
		{ 1497,	[unit_1497],	[unit_1497_help]	},	\
		{ 1498,	[unit_1498],	[unit_1498_help]	},	\
		{ 1499,	[unit_1499],	[unit_1499_help]	},	\
		{ 1500,	[unit_1500],	[unit_1500_help]	},	\
		{ 1501,	[unit_1501],	[unit_1501_help]	},	\
		{ 1502,	[unit_1502],	[unit_1502_help]	},	\
		{ 1503,	[unit_1503],	[unit_1503_help]	},	\
		{ 1504,	[unit_1504],	[unit_1504_help]	},	\
		{ 1505,	[unit_1505],	[unit_1505_help]	},	\
		{ 1506,	[unit_1506],	[unit_1506_help]	},	\
		{ 1507,	[unit_1507],	[unit_1507_help]	},	\
		{ 1508,	[unit_1508],	[unit_1508_help]	},	\
		{ 1509,	[unit_1509],	[unit_1509_help]	},	\
		{ 1510,	[unit_1510],	[unit_1510_help]	},	\
		{ 1511,	[unit_1511],	[unit_1511_help]	},	\
		{ 1512,	[unit_1512],	[unit_1512_help]	},	\
		{ 1513,	[unit_1513],	[unit_1513_help]	},	\
		{ 1514,	[unit_1514],	[unit_1514_help]	},	\
		{ 1515,	[unit_1515],	[unit_1515_help]	},	\
		{ 1516,	[unit_1516],	[unit_1516_help]	},	\
		{ 1517,	[unit_1517],	[unit_1517_help]	},	\
		{ 1518,	[unit_1518],	[unit_1518_help]	},	\
		{ 1519,	[unit_1519],	[unit_1519_help]	},	\
		{ 1520,	[unit_1520],	[unit_1520_help]	}	\


/***********************************************************************/
/*    RENAME Variables												   */
/***********************************************************************/

COLLECTION OF VARIABLE rename_value
{
    MEMBERS
    {
		PHYS_ST_REV,			phys_st_rev,					[blk_block_object_PHYSICAL];
		TRANS_ST_REV,			trans1_st_rev,					[blk_block_object_TRANSDUCER];
		FUNC_ST_REV,			func1_st_rev,					[blk_block_object_FUNCTION];
		TRANS_SELF_CAL_RESET,	trans1_self_calibration_cmd,	[trans_act_self_calibration_message];
		vtravel_w,	valve_travel_counters_full_strokes_warning_limit,	"Warning limit";
		vrev_w,		valve_travel_counters_reversals_warning_limit,		"Warning limit";
		atravel_w,	act_travel_counters_full_strokes_warning_limit,		"Warning limit";
		arev_w,	act_travel_counters_reversals_warning_limit,		"Warning limit";
		graph_signal_mod_1,	signal_mod_1,"Output";
		graph_source_1,	source_1,"Current";
		graph_target_1,	target_1,"Desired";
	}
}

/***********************************************************************/
/*    Physical Block												   */
/***********************************************************************/

BLOCK physical_block
{
	TYPE	PHYSICAL;
	NUMBER	1;
}

VARIABLE pw_1
{
	LABEL		"pw";
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

pw_2 LIKE VARIABLE pw_1 {}
pw_3 LIKE VARIABLE pw_1 {}
pw_4 LIKE VARIABLE pw_1 {}
pw_5 LIKE VARIABLE pw_1 {}
pw_6 LIKE VARIABLE pw_1 {}
pw_7 LIKE VARIABLE pw_1 {}

#define valid_pw	(pw_1==83&&pw_2==69&&pw_3==82&&pw_4==86&&pw_5==73&&pw_6==67&&pw_7==69)

VARIABLE phys_blk_reserve
{
	LABEL		[blk_reserved];
	HELP		[blk_reserved_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE phys_blk_object
{
	LABEL		[blk_block_object];
	HELP		[blk_block_object_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	1,	[blk_block_object_PHYSICAL]	}
	}
	HANDLING	READ;
}

VARIABLE phys_blk_parent_class
{
	LABEL		[blk_parent_class];
	HELP		[phys_blk_parent_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{	2,	[phys_blk_parent_class_ACTUATOR]	}
	}
	HANDLING	READ;
}

VARIABLE phys_blk_class
{
	LABEL		[blk_class];
	HELP		[phys_blk_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	250;
		{	250,	[not_used]		}
	}
	HANDLING	READ;
}

VARIABLE phys_blk_dd_reference
{
	LABEL		[blk_dd_reference];
	HELP		[blk_dd_reference_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4);
	HANDLING	READ;
}

VARIABLE phys_blk_dd_rev
{
	LABEL		[blk_dd_rev];
	HELP		[blk_dd_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(2);
	HANDLING	READ;
}

VARIABLE phys_blk_profile
{
	LABEL		[blk_profile];
	HELP		[blk_profile_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		{ 0x4001,	[blk_profile_PA_COMPACT_A]	},
		{ 0x4002,	[blk_profile_PA_COMPACT_B]	},
		{ 0x4081,	[blk_profile_PA_SIMPLE_A]	},
		{ 0x4082,	[blk_profile_PA_SIMPLE_B]	}
	}
	HANDLING	READ;
}

VARIABLE phys_blk_profile_rev
{
	LABEL		[blk_profile_rev];
	HELP		[blk_profile_rev_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x025D;
		{	0x025A,	"2.90"	},
		{	0x025B,	"2.91"	},
		{	0x025C,	"2.92"	},
		{	0x025D,	"2.93"	},
		{	0x025E,	"2.94"	},
		{	0x025F,	"2.95"	},
		{	0x0260,	"2.96"	},
		{	0x0261,	"2.97"	},
		{	0x0262,	"2.98"	},
		{	0x0263,	"2.99"	},
		{	0x0300,	"3.0"	}
	}
	HANDLING	READ;
}

VARIABLE phys_blk_execution_time
{
	LABEL		[blk_execution_time];
	HELP		[blk_execution_time_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(1);
	HANDLING	READ;
	
}

VARIABLE phys_blk_num_parameters
{
	LABEL		[blk_num_parameters];
	HELP		[blk_num_parameters_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE phys_blk_index_view_1
{
	LABEL		[blk_index_view_1];
	HELP		[blk_index_view_1_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE phys_blk_num_view_lists
{
	LABEL		[blk_num_view_lists];
	HELP		[blk_num_view_lists_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}

VARIABLE phys_st_rev
{
	LABEL		[st_rev];
	HELP		[st_rev_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}

VARIABLE phys_tag_desc
{
	LABEL		[tag_desc];		
	HELP		[tag_desc_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
    	DEFAULT_VALUE	"ND800PA";
    }
	HANDLING	READ & WRITE;
}

VARIABLE softing_error_code
{
	LABEL		"Softing error code";		
	CLASS		CONTAINED;
	TYPE		ASCII (32);
	HANDLING	READ;
}

VARIABLE phys_strategy
{
	LABEL		[strategy];		
	HELP		[strategy_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_alert_key
{
	LABEL		[alert_key];		
	HELP		[alert_key_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_target_mode
{
	LABEL		[target_mode];		
	HELP		[target_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0x08;
		{	0x08,	[mode_AUTO]				}
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_actual_mode
{
	LABEL		[actual_mode];		
	HELP		[actual_mode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE phys_permitted_mode
{
	LABEL		[permitted_mode];		
	HELP		[permitted_mode_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE phys_normal_mode
{
	LABEL		[normal_mode];		
	HELP		[normal_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE phys_current_state_alarm_sum
{
	LABEL		[current_state_alarm_sum];		
	HELP		[current_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE phys_unacknowledged_state_alarm_sum
{
	LABEL		[unacknowledged_state_alarm_sum];		
	HELP		[unacknowledged_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE phys_unreported_state_alarm_sum
{
	LABEL		[unreported_state_alarm_sum];		
	HELP		[unreported_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE phys_disabled_state_alarm_sum
{
	LABEL		[disabled_state_alarm_sum];		
	HELP		[disabled_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE phys_software_rev
{
	LABEL		[phys_software_revision];
	HELP		[phys_software_revision_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
    	DEFAULT_VALUE	"-/-";
    }
	HANDLING	READ;
}

VARIABLE phys_hardware_rev
{
	LABEL		[phys_hardware_revision];
	HELP		[phys_hardware_revision_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
    	DEFAULT_VALUE	"-/-";
    }
	HANDLING	READ;
}

VARIABLE phys_device_man_id
{
	LABEL		[phys_device_man_id];
	HELP		[phys_device_man_id_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	87;
		{ 87,	[Neles_Automation]	}
	}
	HANDLING	READ;
}

VARIABLE phys_device_id
{
	LABEL		[phys_device_id];
	HELP		[phys_device_id_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE DEVICE_TYPE_STR;
	}
	HANDLING	READ;
}

VARIABLE phys_device_ser_num
{
	LABEL		[phys_serial_num];
	HELP		[phys_device_ser_num_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
	    DEFAULT_VALUE	"-/-";
    }
	HANDLING	READ;
}

#define DIA_HW_ELECTR			0x01000000		/* 0x00000001 */
#define DIA_HW_MECH				0x02000000		/* 0x00000002 */
#define DIA_TEMP_MOTOR			0x04000000		/* 0x00000004 */
#define DIA_TEMP_ELECTR			0x08000000		/* 0x00000008 */
#define DIA_MEM_CHKSUM			0x10000000		/* 0x00000010 */
#define DIA_MEASUREMENT			0x20000000		/* 0x00000020 */
#define DIA_NOT_INIT			0x40000000		/* 0x00000040 */
#define DIA_INIT_ERR			0x80000000		/* 0x00000080 */
#define DIA_ZERO_ERR			0x00010000		/* 0x00000100 */
#define DIA_SUPPLY				0x00020000		/* 0x00000200 */
#define DIA_CONF_INVAL			0x00040000		/* 0x00000400 */
#define DIA_WARMSTART			0x00080000		/* 0x00000800 */
#define DIA_COLDSTART			0x00100000		/* 0x00001000 */
#define DIA_MAINTENANCE			0x00200000		/* 0x00002000 */
#define DIA_CHARACT				0x00400000		/* 0x00004000 */
#define EXTENSION_AVAILABLE		0x00000080		/* 0x80000000 */

VARIABLE phys_diagnosis
{
	LABEL		[phys_diagnosis];
	HELP		[phys_diagnosis_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (4)
	{
		{	0,						[dia_OK],					[dia_OK_help]					},
		{	DIA_HW_ELECTR,			[dia_HW_ELECTR],			[dia_HW_ELECTR_help]			},
		{	DIA_HW_MECH,			[dia_HW_MECH],				[dia_HW_MECH_help]				},
		{	DIA_TEMP_MOTOR,			[dia_TEMP_MOTOR],			[dia_TEMP_MOTOR_help]			},
		{	DIA_TEMP_ELECTR,		[dia_TEMP_ELECTR],			[dia_TEMP_ELECTR_help]			},
		{	DIA_MEM_CHKSUM,			[dia_MEM_CHKSUM],			[dia_MEM_CHKSUM_help]			},
		{	DIA_MEASUREMENT,		[dia_MEASUREMENT],			[dia_MEASUREMENT_help]			},
		{	DIA_NOT_INIT,			[dia_NOT_INIT],				[dia_NOT_INIT_help]				},
		{	DIA_INIT_ERR,			[dia_INIT_ERR],				[dia_INIT_ERR_help]				},
		{	DIA_ZERO_ERR,			[dia_ZERO_ERR],				[dia_ZERO_ERR_help]				},
		{	DIA_SUPPLY,				[dia_SUPPLY],				[dia_SUPPLY_help]				},
		{	DIA_CONF_INVAL,			[dia_CONF_INVAL],			[dia_CONF_INVAL_help]			},
		{	DIA_WARMSTART,			[dia_WARMSTART_nd],			[dia_WARMSTART_help]			},
		{	DIA_COLDSTART,			[dia_COLDSTART_nd],			[dia_COLDSTART_help]			},
		{	DIA_MAINTENANCE,		[dia_MAINTENANCE],			[dia_MAINTENANCE_help]			},
		{	DIA_CHARACT,			[dia_CHARACT],				[dia_CHARACT_help]				},
		{	EXTENSION_AVAILABLE,	[dia_EXTENSION_AVAILABLE],	[dia_EXTENSION_AVAILABLE_help]	}
	}
	HANDLING	READ;
}

VARIABLE phys_diagnosis_extension			
{
	LABEL		[phys_diagnosis_extension];
	HELP		[phys_diagnosis_extension_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (4)

	{
		{0			   , [dia_OK], [dia_OK_help]},
		{0x01000000,"Pneumatic prestage valve 1 control failure"},
		{0x02000000,"Pneumatic prestage valve 2 control failure"},
		{0x04000000,"Position feedback ADC low limit failure"},
		{0x08000000,"Position feedback ADC high limit failure"},
		{0x10000000,"Pressure sensor failure"},
		{0x20000000,"Both LS1 and LS2 on"},
//		{0x40000000,""},
//		{0x80000000,""},
		{0x00010000,"EEPROM error"},
		{0x00020000,"RAM error"},
		{0x00040000,"ROM error"},
		{0x00080000,"Processor failure"},
		{0x00100000,"Board to board communication timeout"},
		{0x00200000,"Write was not successful"},
//		{0x00400000,""},
//		{0x00800000,""},
		{0x00000100,"Valve full strokes warning limit exceeded"},
		{0x00000200,"Valve reversals warning limit exceeded"},
		{0x00000400,"Actuator full strokes warning limit exceeded"},
		{0x00000800,"Actuator reversals warning limit exceeded"},
		{0x00001000,"Deviation warning limit exceeded"},
		{0x00002000,"Load factor warning limit exceeded"},
		{0x00004000,"Deviation alarm limit exceeded"},
		{0x00008000,"Load factor alarm limit exceeded"},
		{0x00000001,"Pneumatics problem"},
		{0x00000002,"Friction problem"},
		{0x00000004,"Travel deviation alert"},
		{0x00000008,"Load factor alert"}
//		{0x00000010,""},
//		{0x00000020,""},
//		{0x00000040,""},
//		{0x00000080,""}
	}
	HANDLING	READ;
}

VARIABLE phys_diagnosis_extension_rest			
{
	LABEL		[phys_diagnosis_extension];
	HELP		[phys_diagnosis_extension_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)

	{
		{0x0100," "},
		{0x0200," "},
		{0x0400," "},
		{0x0800," "},
		{0x1000," "},
		{0x2000," "},
		{0x4000," "},
		{0x8000," "},
		{0x0001," "},
		{0x0002," "},
		{0x0004," "},
		{0x0008," "},
		{0x0010," "},
		{0x0020," "},
		{0x0040," "},
		{0x0080," "}
	}
	HANDLING	READ;
}

VARIABLE phys_diagnosis_mask
{
	LABEL		[phys_diagnosis_mask];
	HELP		[phys_diagnosis_mask_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (4)
	{
		{	DIA_HW_ELECTR,			[dia_HW_ELECTR],			[dia_HW_ELECTR_help]			},
		{	DIA_HW_MECH,			[dia_HW_MECH],				[dia_HW_MECH_help]				},
		{	DIA_TEMP_MOTOR,			[dia_TEMP_MOTOR],			[dia_TEMP_MOTOR_help]			},
		{	DIA_TEMP_ELECTR,		[dia_TEMP_ELECTR],			[dia_TEMP_ELECTR_help]			},
		{	DIA_MEM_CHKSUM,			[dia_MEM_CHKSUM],			[dia_MEM_CHKSUM_help]			},
		{	DIA_MEASUREMENT,		[dia_MEASUREMENT],			[dia_MEASUREMENT_help]			},
		{	DIA_NOT_INIT,			[dia_NOT_INIT],				[dia_NOT_INIT_help]				},
		{	DIA_INIT_ERR,			[dia_INIT_ERR],				[dia_INIT_ERR_help]				},
		{	DIA_ZERO_ERR,			[dia_ZERO_ERR],				[dia_ZERO_ERR_help]				},
		{	DIA_SUPPLY,				[dia_SUPPLY],				[dia_SUPPLY_help]				},
		{	DIA_CONF_INVAL,			[dia_CONF_INVAL],			[dia_CONF_INVAL_help]			},
		{	DIA_WARMSTART,			[dia_WARMSTART_nd],			[dia_WARMSTART_help]			},
		{	DIA_COLDSTART,			[dia_COLDSTART_nd],			[dia_COLDSTART_help]			},
		{	DIA_MAINTENANCE,		[dia_MAINTENANCE],			[dia_MAINTENANCE_help]			},
		{	DIA_CHARACT,			[dia_CHARACT],				[dia_CHARACT_help]				},
		{	EXTENSION_AVAILABLE,	[dia_EXTENSION_AVAILABLE],	[dia_EXTENSION_AVAILABLE_help]	}
	}
	HANDLING	READ;
}

VARIABLE phys_diagnosis_extension_mask
{
	LABEL		[phys_diagnosis_extension_mask];
	HELP		[phys_diagnosis_extension_mask_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (4)

	{
		{0			   , [dia_OK], [dia_OK_help]},
		{0x01000000,"Pneumatic prestage valve 1 control failure	"},
		{0x02000000,"Pneumatic prestage valve 2 control failure	"},
		{0x04000000,"Position feedback ADC low limit failure	"},
		{0x08000000,"Position feedback ADC high limit failure	"},
		{0x10000000,"Pressure sensor failure					"},
		{0x20000000,"Both LS1 and LS2 on						"},
//		{0x40000000,"											"},
//		{0x80000000,"											"},
		{0x00010000,"EEPROM error								"},
		{0x00020000,"RAM error									"},
		{0x00040000,"ROM error									"},
		{0x00080000,"Processor failure							"},
		{0x00100000,"Board to board communication timeout		"},
		{0x00200000,"Write was not successful					"},
//		{0x00400000,"											"},
//		{0x00800000,"											"},
		{0x00000100,"Pilot valve problem						"},
		{0x00000200,"Friction ptoblem							"},
		{0x00000400,"Travel deviation alarm limit exceeded		"},
		{0x00000800,"Load factor alarm limit exceeded			"},
//		{0x00001000,"											"},
//		{0x00002000,"											"},
//		{0x00004000,"											"},
//		{0x00008000,"											"},
		{0x00000001,"Valve full strokes alarm limit exceeded	"},
		{0x00000002,"Valve reversals alarm limit exceeded		"},
		{0x00000004,"Actuator full strokes alarm limit exceeded	"},
		{0x00000008,"Actuator reversals alarm limit exceeded	"},
//		{0x00000010,"											"},
//		{0x00000020,"											"},
//		{0x00000040,"											"},
//		{0x00000080,"											"}
	}
	HANDLING	READ;
}

VARIABLE phys_diagnosis_extension_mask_rest			
{
	LABEL		[phys_diagnosis_extension];
	HELP		[phys_diagnosis_extension_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (2)

	{
		{0x0100," "},
		{0x0200," "},
		{0x0400," "},
		{0x0800," "},
		{0x1000," "},
		{0x2000," "},
		{0x4000," "},
		{0x8000," "},
		{0x0001," "},
		{0x0002," "},
		{0x0004," "},
		{0x0008," "},
		{0x0010," "},
		{0x0020," "},
		{0x0040," "},
		{0x0080," "}
	}
	HANDLING	READ;
}

VARIABLE phys_device_certification				/* optional */
{
	LABEL		[phys_device_certification];
	HELP		[phys_device_certification_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
	   	DEFAULT_VALUE	"-/-";
    }
	HANDLING	READ;
}

VARIABLE phys_write_locking						/* optional */
{
	LABEL		[phys_write_locking];
	HELP		[phys_write_locking_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	2457;
		{ 0,		[prot_on]	},
		{ 2457,	[prot_off]	}
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_factory_reset						/* optional */
{
	LABEL		[phys_factory_reset];
	HELP		[phys_factory_reset_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0;
		{ 0,		[no_function]			},
		{ 1,		[factory_reset_PARAMS]	},
		{ 2506,		[factory_reset_WARMSTART]},
		{ 2712,		[factory_reset_ADDRESS]	}
	}
	HANDLING READ & WRITE;
	PRE_WRITE_ACTIONS
	{
		method_reset_msg
	}
}

VARIABLE phys_descriptor						/* optional */
{
	LABEL		[phys_descriptor];
	HELP		[phys_descriptor_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
	    	DEFAULT_VALUE	"-/-";
    }
	HANDLING	READ & WRITE;
}

VARIABLE phys_message							/* optional */
{
	LABEL		[phys_message];
	HELP		[phys_message_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
	    DEFAULT_VALUE	"-/-";
    }
	HANDLING	READ & WRITE;
}

VARIABLE phys_install_date						/* optional */
{
	LABEL		[phys_install_date];
	HELP		[phys_install_date_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE "01.01.2000";
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_local_operation_enable
{
	LABEL		[trans_act_local_operation];
	HELP		[trans_act_local_operation_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{	0,	[lo_disabled]	},
		{	1,	[lo_enabled]	}
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_ident_number
{
	LABEL		[phys_ident_number];
	HELP		[phys_ident_number_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{	0,	[phys_ident_number_PROFILE]		},
		{	1,	[phys_ident_number_MANUFACURER]	}
	}
	HANDLING	READ & WRITE;
}

VARIABLE phys_hw_write_protection
{
	LABEL		[phys_hw_write_protection];
	HELP		[phys_hw_write_protection_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{	0,	[prot_off]	},
		{	1,	[prot_on]	}
	}
	HANDLING	READ;
}


/***********************************************************************/
/*    Transducer Block: Actuator 									   */
/***********************************************************************/

BLOCK transducer_block_1
{
	TYPE	TRANSDUCER;
	NUMBER	1;
}

trans1_blk_reserve							LIKE VARIABLE	phys_blk_reserve
{
}

VARIABLE trans1_blk_object
{
	LABEL		[blk_block_object];
	HELP		[blk_block_object_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{	3,	[blk_block_object_TRANSDUCER]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_blk_parent_class
{
	LABEL		[blk_parent_class];
	HELP		[trans_blk_parent_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{	5,	[trans_blk_parent_class_VALVE]	}
	}
	HANDLING	READ;
}

VARIABLE trans1_blk_class
{
	LABEL		[blk_class];
	HELP		[trans_blk_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{	2,		[trans_act_blk_class_ELECTRO_PNEU]	},
		{	250,	[not_used] 							},
		{	251,	[none]								},
		{	252,	[unknown]							},
		{	253,	[special]							}
	}
	HANDLING	READ;
}

trans1_blk_dd_reference						LIKE VARIABLE	phys_blk_dd_reference
{											
}											
											
trans1_blk_dd_rev							LIKE VARIABLE	phys_blk_dd_rev
{											
}											
											
trans1_blk_profile							LIKE VARIABLE	phys_blk_profile
{											
}											
											
trans1_blk_profile_rev						LIKE VARIABLE	phys_blk_profile_rev
{											
}											
											
trans1_blk_execution_time					LIKE VARIABLE	phys_blk_execution_time
{											
}											
											
trans1_blk_num_parameters					LIKE VARIABLE	phys_blk_num_parameters
{											
}											
											
trans1_blk_index_view_1						LIKE VARIABLE	phys_blk_index_view_1
{											
}											
											
trans1_blk_num_view_lists					LIKE VARIABLE	phys_blk_num_view_lists
{											
}											
											
trans1_st_rev								LIKE VARIABLE	phys_st_rev
{											
}											
											
trans1_tag_desc								LIKE VARIABLE	phys_tag_desc
{											
}											
											
trans1_strategy								LIKE VARIABLE	phys_strategy
{											
}											
											
trans1_alert_key							LIKE VARIABLE	phys_alert_key
{											
}											

trans1_target_mode							LIKE VARIABLE	phys_target_mode
{
	REDEFINE TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0x08;
		{	0x08,	[mode_AUTO]				},
		{	0x20,	[mode_LO]				}
	}
}

trans1_actual_mode							LIKE VARIABLE	phys_actual_mode
{
}

trans1_permitted_mode						LIKE VARIABLE	phys_permitted_mode
{
}

trans1_normal_mode							LIKE VARIABLE	phys_normal_mode
{
}

trans1_current_state_alarm_sum				LIKE VARIABLE	phys_current_state_alarm_sum
{
}

trans1_unacknowledged_state_alarm_sum		LIKE VARIABLE	phys_unacknowledged_state_alarm_sum
{
}

trans1_unreported_state_alarm_sum			LIKE VARIABLE	phys_unreported_state_alarm_sum
{
}

trans1_disabled_state_alarm_sum				LIKE VARIABLE	phys_disabled_state_alarm_sum
{
}

VARIABLE trans1_act_stroke_time_dec				/* optional */
{
	LABEL		[trans_act_stroke_time_dec];
	HELP		[trans_act_stroke_time_dec_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
			DEFAULT_VALUE	0.0;
	}
	CONSTANT_UNIT	[sec];
	HANDLING	READ;
}

VARIABLE trans1_act_stroke_time_inc				/* optional */
{
	LABEL		[trans_act_stroke_time_inc];
	HELP		[trans_act_stroke_time_inc_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
			DEFAULT_VALUE	0.0;
	}
	CONSTANT_UNIT	[sec];
	HANDLING	READ;
}

VARIABLE trans1_deadband
{
	LABEL		[trans_act_deadband];
	HELP		[trans_act_deadband_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	1.0;
		MIN_VALUE		0.1;
		MAX_VALUE		10.0;
		DISPLAY_FORMAT ".1f" ;
		EDIT_FORMAT ".1f" ;
	}
	CONSTANT_UNIT	[Percent];
	HANDLING	READ & WRITE;
}

VARIABLE trans1_device_calib_date				/* optional */
{
	LABEL		[trans_act_device_calib_date];
	HELP		[trans_act_device_calib_date_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE "01.01.2000";
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_device_config_date				/* optional */
{
	LABEL		[trans_act_device_config_date];
	HELP		[trans_act_device_config_date_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE "01.01.2000";
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_lin_type
{
	LABEL		[trans_lin_type];
	HELP		[trans_lin_type_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{ 0,	[lin_type_no_lin]						}
/*		{ 1,	[lin_type_TABLE]						},
		{ 50,	[lin_type_PERC_1_33]					},
		{ 51,	[lin_type_PERC_1_33_INVERSE]			},
		{ 52,	[lin_type_PERC_1_50]					},
		{ 53,	[lin_type_PERC_1_50_INVERSE]			},
		{ 54,	[lin_type_PERC_1_25]					},
		{ 55,	[lin_type_PERC_1_25_INVERSE]			} */
// 240 ... 249 Manufacturer specific		
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_rated_travel_value
{
	LABEL		[trans_act_rated_travel_value];
	HELP		[trans_act_rated_travel_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	100;
	}
	CONSTANT_UNIT	[Percent];
	HANDLING	READ & WRITE;
}

VARIABLE trans1_self_calibration_cmd
{
	LABEL		[trans_act_self_calibration_cmd];
	HELP		[trans_act_self_calibration_cmd_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{ 0,	[no_function]								},
		{ 2,	[trans_act_self_calibration_cmd_START]		},	
/*		{ 7,	[cb_TOT_VALVE_TRAV]							}, */
/*		{ 10,	[cb_CONTR_ERR]								}, */
		{ 255,	[abort_current_cal]							}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_self_calibration_status
{
	LABEL		[trans_act_self_calibration_status];
	HELP		[trans_act_self_calibration_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	0;
		{ 0,		[undefined]					},
		{ 2,		[cal_cancelled]				},
		{ 4,		[error_in_mechanical_system]},
		{ 11,		[cal_timeout]				},
		{ 20,		[aborted_emerg]				},
		{ 254,		[cal_successful]			}
	}
	HANDLING	READ;
}

VARIABLE trans1_servo_gain
{
	LABEL		[trans_act_servo_gain];
	HELP		[trans_act_servo_gain_help];
	CLASS		CONTAINED;
	TYPE FLOAT
	{
		DEFAULT_VALUE 1.0;
		MIN_VALUE 0.1;
		MAX_VALUE 3.0;
	}

	HANDLING	READ & WRITE;
}

VARIABLE trans1_setp_cutoff_dec
{
	LABEL		[trans_act_setp_cutoff_dec];
	HELP		[trans_act_setp_cutoff_dec_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	2.0;
		MIN_VALUE		0.0;
		MAX_VALUE		100.0;
	}
	CONSTANT_UNIT	[Percent];
	HANDLING	READ & WRITE;
}

VARIABLE trans1_setp_cutoff_inc
{
	LABEL		[trans_act_setp_cutoff_inc];
	HELP		[trans_act_setp_cutoff_inc_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	100.0;
		MIN_VALUE		0.0;
		MAX_VALUE		100.0;
	}
	CONSTANT_UNIT	[Percent];
	HANDLING	READ & WRITE;
}

VARIABLE trans1_travel_limit_lower_value
{
	LABEL		[trans_act_travel_limit_lower_value];
	HELP		[trans_act_travel_limit_lower_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
		MIN_VALUE		0.0;
		MAX_VALUE		100.0;
	}
	CONSTANT_UNIT	[Percent];
	HANDLING	READ & WRITE;
}

VARIABLE trans1_travel_limit_upper_value
{
	LABEL		[trans_act_travel_limit_upper_value];
	HELP		[trans_act_travel_limit_upper_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	100.0;
		MIN_VALUE		0.0;
		MAX_VALUE		100.0;
	}
	CONSTANT_UNIT	[Percent];
	HANDLING	READ & WRITE;
}

VARIABLE trans1_travel_rate_dec
{
	LABEL		[trans_act_travel_time_dec];
	HELP		[trans_act_travel_time_dec_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
		MIN_VALUE		0.0;
		MAX_VALUE		1000.0;
	}
	CONSTANT_UNIT	[sec];
	HANDLING	READ & WRITE;
}

VARIABLE trans1_travel_rate_inc
{
	LABEL		[trans_act_travel_time_inc];
	HELP		[trans_act_travel_time_inc_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
		MIN_VALUE		0.0;
		MAX_VALUE		1000.0;
	}
	CONSTANT_UNIT	[sec];
	HANDLING	READ & WRITE;
}

VARIABLE trans1_valve_maintenance_date			/* optional */
{
	LABEL		[trans_act_valve_maintenance_date];
	HELP		[trans_act_valve_maintenance_date_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE "01.01.2000";
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_positioning_value
{
	LABEL		[trans_act_positioning_value];
	HELP		[trans_act_positioning_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	CONSTANT_UNIT	[Percent];
	HANDLING	READ;
}

VARIABLE trans1_positioning_status_quality
{
	LABEL		[status_quality];
	HELP		[trans_act_positioning_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_QUALITY
	}
	HANDLING	READ;
}

trans1_positioning_status_limit LIKE VARIABLE trans1_positioning_status_quality
{
	REDEFINE LABEL		[status_limit];		
		REDEFINE HELP [status_limit_help];
	REDEFINE TYPE		ENUMERATED (1)
	{
		STATUS_LIMIT
	}
}

VARIABLE trans1_feedback_value
{
	LABEL		[trans_act_feedback_value];
	HELP		[trans_act_feedback_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	CONSTANT_UNIT	[Percent];
	HANDLING	READ;
}

VARIABLE trans1_feedback_status_quality
{
	LABEL		[status_quality];
	HELP		[trans_act_feedback_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_QUALITY
	}
	HANDLING	READ;
}

trans1_feedback_status_limit				LIKE VARIABLE	trans1_feedback_status_quality
{
	REDEFINE LABEL		[status_limit];		
		REDEFINE HELP [status_limit_help];
	REDEFINE TYPE		ENUMERATED (1)
	{
		STATUS_LIMIT
	}
}

VARIABLE trans1_valve_man
{
	LABEL		[phys_device_man_id];
	HELP		[phys_device_man_id_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE "Metso Automation";
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_actuator_man
{
	LABEL		[phys_device_man_id];
	HELP		[phys_device_man_id_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE "Metso Automation";
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_valve_type
{
	LABEL		[phys_valve_type];
	HELP		[phys_valve_type_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{	0,		[phys_valve_type_LINEAR]	},
		{	1,		[phys_valve_type_PART_TURN]		}
//		{	2,		[phys_valve_type_PART_MULTI]	}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_actuator_type
{
	LABEL		[phys_actuator_type];
	HELP		[phys_actuator_type_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{	0,	[phys_actuator_type_ELECTRO_PNEUMATIC]	},
		{	1,	[phys_actuator_type_ELECTRIC]			},
		{	2,	[phys_actuator_type_ELECTRO_HYDRAULIC]	},
		{	3,	[other]									}
	}
	HANDLING	READ;
}

VARIABLE trans1_actuator_action
{
	LABEL		[phys_actuator_action];
	HELP		[phys_actuator_action_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{	0,	[phys_actuator_action_NOT_INIT]		},
		{	1,	[phys_actuator_action_OPEN]			},
		{	2,	[phys_actuator_action_CLOSE]		},
		{	3,	[phys_actuator_action_NONE]			}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_valve_serial_number				/* optional */
{
	LABEL		[phys_serial_num];
	HELP		[phys_valve_serial_num_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
    	DEFAULT_VALUE	"-/-";
    }
	HANDLING	READ & WRITE;
}

VARIABLE trans1_actuator_serial_number			/* optional */
{
	LABEL		[phys_serial_num];
	HELP		[phys_actuator_serial_num_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
    	DEFAULT_VALUE	"-/-";
    }
	HANDLING	READ & WRITE;
}

VARIABLE trans1_additional_gear_ser_number		/* optional */
{
	LABEL		[phys_serial_num];
	HELP		[phys_additional_gear_serial_num_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
    	DEFAULT_VALUE	"-/-";
    }
	HANDLING	READ & WRITE;
}

VARIABLE trans1_additional_gear_man				/* optional */
{
	LABEL		[phys_device_man_id];
	HELP		[phys_device_man_id_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE "Metso Automation";
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_additional_gear_id				/* optional */
{
	LABEL		[phys_device_id];
	HELP		[phys_device_id_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
    	DEFAULT_VALUE	"-/-";
    }
	HANDLING	READ & WRITE;
}

VARIABLE trans1_additional_gear_install_date		/* optional */
{
	LABEL		[phys_install_date];
	HELP		[phys_additional_gear_install_date_help];
	CLASS		CONTAINED;
	TYPE		ASCII (16)
	{
		DEFAULT_VALUE "01.01.2000";
	}
	HANDLING	READ & WRITE;
}

/***********************************************************************/
/*    Transducer Block: Actuator (manufacturer specific)			   */
/***********************************************************************/

VARIABLE limit_switches
{
    LABEL "Limit switches";
	HELP [limit_switches_help];
	CLASS CONTAINED;
	TYPE ENUMERATED (1)
	{
		{0,"Not installed"},
		{1,"Installed"}
	}
 	HANDLING READ & WRITE;
}

VARIABLE vc_gw_index
{
    LABEL "Index";
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER (1);
 	HANDLING	READ & WRITE;
}

VARIABLE vc_gw_rw
{
    LABEL "Handling";
	CLASS CONTAINED;
	TYPE ENUMERATED (1)
	{
		{0,"Read"},
		{1,"Write"}
	}
 	HANDLING	READ & WRITE;
}

VARIABLE vc_gw_data
{
    LABEL "Data";
	CLASS CONTAINED & DYNAMIC;
	TYPE FLOAT;
 	HANDLING	IF (vc_gw_rw==0) {READ;} ELSE {READ & WRITE;}
}

VARIABLE vc_gw_status
{
    LABEL "Status";
	CLASS CONTAINED & DYNAMIC;
	TYPE ENUMERATED (1)
	{
		{0,"idle"},
		{1,"reading"},
		{2,"writing"},
		{3,"read OK"},
		{4,"write OK"},
		{5,"read failed"},
		{6,"write failed"}
	}
 	HANDLING READ;
}

VARIABLE device_pcb_sn
{
    LABEL [DEVICE_PCB_SN_LABEL];
    HELP [DEVICE_PCB_SN_LABEL_HELP];
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER (4) ;
	HANDLING	READ; 
}


VARIABLE servo_param_d
{
    LABEL [SERVO_PARAM_D_LABEL];
    HELP [SERVO_PARAM_D_HELP];
	CLASS CONTAINED;
	TYPE FLOAT
	{
		DEFAULT_VALUE	0.0;
		MIN_VALUE 0.0;
		MAX_VALUE 3.0;
	}
 	HANDLING	READ & WRITE;
}

VARIABLE servo_param_b
{
    LABEL [SERVO_PARAM_B_LABEL];
    HELP [SERVO_PARAM_B_HELP];
	CLASS CONTAINED;
	TYPE FLOAT
	{
		DEFAULT_VALUE	1.0;
		MIN_VALUE 0.0;
		MAX_VALUE 3.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE act_type
{
    LABEL [ACT_TYPE_LABEL];
    HELP [ACT_TYPE_LABEL_HELP];
	CLASS CONTAINED;
	TYPE ENUMERATED (1)
	{
		{0,"Undefined"},
		{1,"Single acting actuator"},
		{2,"Double acting actuator"}
	}
	HANDLING	READ & WRITE; 
}

VARIABLE supply_pressure
{
    LABEL [SUPPLY_PRESSURE_LABEL];
    HELP [SUPPLY_PRESSURE_LABEL_HELP];
	CLASS CONTAINED;
	TYPE FLOAT
	{
		DEFAULT_VALUE	5.0;
		MIN_VALUE 0.1;
		MAX_VALUE 15.0;
	}
	CONSTANT_UNIT [unit_1137];
	HANDLING	READ & WRITE; 
}
VARIABLE fail_action
{
    LABEL [FAIL_ACTION_LABEL];
    HELP [FAIL_ACTION_LABEL_HELP];
	CLASS CONTAINED;
	TYPE ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{0,"Close"},
		{1,"Open"}
	}
	HANDLING	READ & WRITE; 
}
VARIABLE pos_sensor_rot
{
    LABEL [POS_SENSOR_ROT_LABEL];
    HELP [POS_SENSOR_ROT_LABEL_HELP];
	TYPE ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{0,"Nonstandard : Counter clockwise to close"},
		{1,"Standard : Clockwise to close"}
	}
	HANDLING	READ & WRITE; 
}

VARIABLE dead_angle_comp
{
    LABEL [DEAD_ANGLE_COMP_LABEL];
    HELP [DEAD_ANGLE_COMP_LABEL_HELP];
	CLASS CONTAINED;
	TYPE FLOAT
	{
		DEFAULT_VALUE	0.0;
		MIN_VALUE 0.0;
		MAX_VALUE 99;
	}
	CONSTANT_UNIT [Percent];
	HANDLING	READ & WRITE; 
}

VARIABLE act_pressure
{
    LABEL [ACT_PRESSURE_LABEL];
    HELP [ACT_PRESSURE_LABEL_HELP];
	CLASS CONTAINED & DYNAMIC;
	TYPE FLOAT;
	HANDLING READ;
	CONSTANT_UNIT [unit_1137];  // bar
}


VARIABLE dev_temperature
{
    LABEL [DEV_TEMPERATURE_LABEL];
    HELP [DEV_TEMPERATURE_LABEL_HELP];
	CLASS CONTAINED & DYNAMIC;
	TYPE FLOAT;
	HANDLING READ;
	CONSTANT_UNIT [unit_1001];  // celsius
}

VARIABLE operation_time
{
    LABEL [OPERATION_TIME_LABEL];
    HELP [OPERATION_TIME_LABEL_HELP];
	CLASS CONTAINED & DYNAMIC;
	TYPE FLOAT;
	HANDLING READ;
	CONSTANT_UNIT [unit_1059];	//h
}

VARIABLE travel_deviation_warning_limit
{
	LABEL		[travel_deviation_warning_limit_label];
	HELP		[travel_deviation_warning_limit_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	2;
		MIN_VALUE		0.0;
		MAX_VALUE		100.0;
	}
	CONSTANT_UNIT	[Percent];
	HANDLING	READ & WRITE;
}

VARIABLE travel_deviation_alarm_limit
{
	LABEL		[travel_deviation_alarm_limit_label];
	HELP		[travel_deviation_alarm_limit_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	10;
		MIN_VALUE		0.0;
		MAX_VALUE		100.0;
	}
	CONSTANT_UNIT	[Percent];
	HANDLING	READ & WRITE;
}

VARIABLE load_factor_warning_limit
{
	LABEL		[load_factor_warning_limit_label];
	HELP		[load_factor_warning_limit_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	50;
		MIN_VALUE		0.0;
		MAX_VALUE		100.0;
	}
	CONSTANT_UNIT	[Percent];
	HANDLING	READ & WRITE;
}

VARIABLE load_factor_alarm_limit
{
	LABEL		[load_factor_alarm_limit_label];
	HELP		[load_factor_alarm_limit_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	85;
		MIN_VALUE		0.0;
		MAX_VALUE		100.0;
	}
	CONSTANT_UNIT	[Percent];
	HANDLING	READ & WRITE;
}

VARIABLE valve_travel_counters_full_strokes
{
    LABEL [valve_full_strokes_label];
    HELP [valve_full_strokes_help];
	CLASS CONTAINED & DYNAMIC;
	TYPE FLOAT
	{
		MIN_VALUE 0.0;
	}
	CONSTANT_UNIT [blank];
	HANDLING READ;
}

VARIABLE valve_travel_counters_full_strokes_warning_limit
{
    LABEL [valve_full_strokes_warning_label];
    HELP [valve_full_strokes_warning_help];
	CLASS CONTAINED & DIAGNOSTIC;
	TYPE UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE	250000;
		MIN_VALUE		0;
		MAX_VALUE		INT32_MAX;
	}
	HANDLING READ & WRITE;
	CONSTANT_UNIT [blank];
}

VARIABLE valve_travel_counters_reversals
{
    LABEL [valve_reversals_label];
    HELP [valve_reversals_help];
	CLASS CONTAINED & DYNAMIC & DIAGNOSTIC;
	TYPE UNSIGNED_INTEGER (4);
	CONSTANT_UNIT [blank];
	HANDLING READ;
}

valve_travel_counters_reversals_warning_limit LIKE VARIABLE valve_travel_counters_full_strokes_warning_limit
{
        REDEFINE LABEL [valve_reversals_warning_label];
        REDEFINE HELP [valve_reversals_warning_help];
		REDEFINE DEFAULT_VALUE 1000000;
}


VARIABLE act_travel_counters_full_strokes
{
    LABEL [act_full_strokes_label];
    HELP [act_full_strokes_help];
	CLASS CONTAINED & DYNAMIC;
	TYPE FLOAT
	{
		MIN_VALUE 0.0;
	}
	CONSTANT_UNIT [blank];
	HANDLING READ;
}

VARIABLE act_travel_counters_full_strokes_warning_limit
{
    LABEL [act_full_strokes_warning_label];
    HELP [act_full_strokes_warning_help];
	CLASS CONTAINED & DIAGNOSTIC;
	TYPE UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE	250000;
		MIN_VALUE		0;
		MAX_VALUE		INT32_MAX;
	}
	HANDLING READ & WRITE;
	CONSTANT_UNIT [blank];
}

VARIABLE act_travel_counters_reversals
{
    LABEL [act_reversals_label];
    HELP [act_reversals_help];
	CLASS CONTAINED & DYNAMIC & DIAGNOSTIC;
	TYPE UNSIGNED_INTEGER (4);
	CONSTANT_UNIT [blank];
	HANDLING READ;
}

act_travel_counters_reversals_warning_limit LIKE VARIABLE act_travel_counters_full_strokes_warning_limit
{
        REDEFINE LABEL [act_reversals_warning_label];
        REDEFINE HELP [act_reversals_warning_help];
		REDEFINE DEFAULT_VALUE 1000000;
}

VARIABLE reset_diagnostics
{
    LABEL [RESET_DIAGNOSTICS_LABEL];
    HELP [RESET_DIAGNOSTICS_LABEL_HELP];
	CLASS CONTAINED & DIAGNOSTIC;
	TYPE ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{0x00,[rdiag_none]},
		{0x01,[rdiag_event]},
		{0x02,[rdiag_dev]},
		{0x04,[rdiag_travel_vs]},
		{0x08,[rdiag_load_factor]},
		{0x10,[rdiag_vtravel]},
		{0x20,[rdiag_atravel]}
	}
	HANDLING	READ & WRITE;
}

VARIABLE pos_sensor_sn
{
	LABEL [POS_SENSOR_SN_LABEL];
	HELP [POS_SENSOR_SN_LABEL_HELP];
	CLASS CONTAINED;
	TYPE UNSIGNED_INTEGER (4)
	{
		MIN_VALUE		0;
		MAX_VALUE		INT32_MAX;
	}
    HANDLING	READ & WRITE; 
}

VARIABLE pos_sensor_temp_comp
{
	LABEL [POS_SENSOR_TEMP_COMP_LABEL];
	HELP [POS_SENSOR_TEMP_COMP_LABEL_HELP];
	CLASS CONTAINED;
	TYPE ENUMERATED (1)
	{
		{0,"Compensation off"},
		{1,"Compensation on; User defined table"},
		{2,"Compensation on; Default table"}
	}
	HANDLING	READ & WRITE; 
}
 
VARIABLE pos_sensor_temp_comp_min_table_1
{
	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_1];
	HELP [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_HELP];
	CLASS CONTAINED & SERVICE;
	TYPE FLOAT
	{
		DEFAULT_VALUE  43.4576;
		MIN_VALUE      0.1;
		MAX_VALUE      99.9;
	}
	CONSTANT_UNIT [Percent];
	HANDLING READ & WRITE;
}

pos_sensor_temp_comp_min_table_2 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_2];
}
pos_sensor_temp_comp_min_table_3 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_3];
}
pos_sensor_temp_comp_min_table_4 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_4];
}
pos_sensor_temp_comp_min_table_5 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_5];
}
pos_sensor_temp_comp_min_table_6 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_6];
}
pos_sensor_temp_comp_min_table_7 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_7];
}
pos_sensor_temp_comp_min_table_8 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_8];
}
pos_sensor_temp_comp_min_table_9 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_9];
}
pos_sensor_temp_comp_min_table_10 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_10];
}
pos_sensor_temp_comp_min_table_11 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_11];
}
pos_sensor_temp_comp_min_table_12 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_12];
}
pos_sensor_temp_comp_min_table_13 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_13];
}
pos_sensor_temp_comp_min_table_14 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_14];
}
pos_sensor_temp_comp_min_table_15 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_15];
}
pos_sensor_temp_comp_min_table_16 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_16];
}
pos_sensor_temp_comp_min_table_17 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_17];
}
pos_sensor_temp_comp_min_table_18 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_18];
}
pos_sensor_temp_comp_min_table_19 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_19];
}
pos_sensor_temp_comp_min_table_20 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_20];
}
pos_sensor_temp_comp_min_table_21 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_21];
}
pos_sensor_temp_comp_min_table_22 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_22];
}
pos_sensor_temp_comp_min_table_23 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_23];
}
pos_sensor_temp_comp_min_table_24 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_24];
}
pos_sensor_temp_comp_min_table_25 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_25];
}
pos_sensor_temp_comp_min_table_26 LIKE VARIABLE pos_sensor_temp_comp_min_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MIN_TABLE_LABEL_26];
}

VARIABLE pos_sensor_temp_comp_max_table_1
{
	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_1];
	HELP [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_HELP];
	CLASS CONTAINED & SERVICE;
	TYPE FLOAT
	{
		DEFAULT_VALUE    52.2259;
//		MIN_VALUE        0.1;
		MAX_VALUE        99.9;
	}
	CONSTANT_UNIT [Percent];
	HANDLING	READ & WRITE;
}

pos_sensor_temp_comp_max_table_2 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_2];
		REDEFINE	DEFAULT_VALUE	52.6243;
}
pos_sensor_temp_comp_max_table_3 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_3];
		REDEFINE	DEFAULT_VALUE	52.9817;
}
pos_sensor_temp_comp_max_table_4 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_4];
		REDEFINE	DEFAULT_VALUE	53.2993;
}
pos_sensor_temp_comp_max_table_5 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_5];
		REDEFINE	DEFAULT_VALUE	53.5789;
}
pos_sensor_temp_comp_max_table_6 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_6];
		REDEFINE	DEFAULT_VALUE	53.8219;
}
pos_sensor_temp_comp_max_table_7 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_7];
		REDEFINE	DEFAULT_VALUE	54.0307;
}
pos_sensor_temp_comp_max_table_8 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_8];
		REDEFINE	DEFAULT_VALUE	54.2074;
}
pos_sensor_temp_comp_max_table_9 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_9];
		REDEFINE	DEFAULT_VALUE	54.354;
}
pos_sensor_temp_comp_max_table_10 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_10];
		REDEFINE	DEFAULT_VALUE	54.4728;
}
pos_sensor_temp_comp_max_table_11 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_11];
		REDEFINE	DEFAULT_VALUE	54.5659;
}
pos_sensor_temp_comp_max_table_12 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_12];
		REDEFINE	DEFAULT_VALUE	54.6353;
}
pos_sensor_temp_comp_max_table_13 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_13];
		REDEFINE	DEFAULT_VALUE	54.6828;
}
pos_sensor_temp_comp_max_table_14 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_14];
		REDEFINE	DEFAULT_VALUE	54.7105;
}
pos_sensor_temp_comp_max_table_15 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_15];
		REDEFINE	DEFAULT_VALUE	54.7197;
}
pos_sensor_temp_comp_max_table_16 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_16];
		REDEFINE	DEFAULT_VALUE	54.7119;
}
pos_sensor_temp_comp_max_table_17 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_17];
		REDEFINE	DEFAULT_VALUE	54.6885;
}
pos_sensor_temp_comp_max_table_18 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_18];
		REDEFINE	DEFAULT_VALUE	54.6508;
}
pos_sensor_temp_comp_max_table_19 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_19];
		REDEFINE	DEFAULT_VALUE	54.5995;
}
pos_sensor_temp_comp_max_table_20 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_20];
		REDEFINE	DEFAULT_VALUE	54.5357;
}
pos_sensor_temp_comp_max_table_21 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_21];
		REDEFINE	DEFAULT_VALUE	54.4599;
}
pos_sensor_temp_comp_max_table_22 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_22];
		REDEFINE	DEFAULT_VALUE	54.3727;
}
pos_sensor_temp_comp_max_table_23 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_23];
		REDEFINE	DEFAULT_VALUE	54.2745;
}
pos_sensor_temp_comp_max_table_24 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_24];
		REDEFINE	DEFAULT_VALUE	54.1655;
}
pos_sensor_temp_comp_max_table_25 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_25];
		REDEFINE	DEFAULT_VALUE	54.0457;
}
pos_sensor_temp_comp_max_table_26 LIKE VARIABLE pos_sensor_temp_comp_max_table_1
{
		REDEFINE 	LABEL [POS_SENSOR_TEMP_COMP_MAX_TABLE_LABEL_26];
		REDEFINE	DEFAULT_VALUE	53.9148;
}

VARIABLE test_type
{
	LABEL [test_type_label];
	HELP [test_type_help];
	TYPE ENUMERATED (2)
	{
		{0,"None"},
		{STEP,"Step response test"},
		{HYSTERESIS,"Hysteresis loop test"}
	}
	CLASS CONTAINED;
	HANDLING	READ & WRITE;
}

last_test_type LIKE VARIABLE test_type
{
	REDEFINE HANDLING READ;
	REDEFINE CLASS CONTAINED & DYNAMIC;
}

VARIABLE test_starting_setpoint
{
	LABEL [test_starting_setpoint_label];
	HELP [test_starting_setpoint_help];
	TYPE FLOAT
	{
		MIN_VALUE 0.0;
		MAX_VALUE 100.0;
	}
	CONSTANT_UNIT [Percent];
	CLASS CONTAINED;
 	HANDLING	READ & WRITE;
}

last_test_starting_setpoint LIKE VARIABLE test_starting_setpoint
{
	REDEFINE HANDLING READ;
	REDEFINE CLASS CONTAINED & DYNAMIC;
}

test_loop_or_step_size LIKE VARIABLE test_starting_setpoint
{
	REDEFINE LABEL [test_loop_or_step_size_label];
	REDEFINE HELP [test_loop_or_step_size_help];
	REDEFINE MIN_VALUE 0.1;
	REDEFINE DEFAULT_VALUE 5;
}

last_test_loop_or_step_size LIKE VARIABLE test_loop_or_step_size
{
	REDEFINE HANDLING READ;
	REDEFINE CLASS CONTAINED & DYNAMIC;
	REDEFINE MIN_VALUE 0.0;
}

VARIABLE test_duration
{
	LABEL [test_duration_label];
	HELP [test_duration_help];
	TYPE FLOAT
	{
		DEFAULT_VALUE 500;
		MIN_VALUE 1;
		MAX_VALUE 2000;
	}
	CONSTANT_UNIT [sec];
	CLASS CONTAINED;
	HANDLING	READ & WRITE;
}

last_test_duration LIKE VARIABLE test_duration
{
	REDEFINE MIN_VALUE 0;
	REDEFINE HANDLING READ;
	REDEFINE CLASS CONTAINED & DYNAMIC;
}

VARIABLE test_start
{
	LABEL [test_start_label];
	HELP [test_start_help];
	TYPE ENUMERATED (1)
	{
		{0,"Idle"},
		{1,"Start test"},
		{2,"Stop test"},
		{3,"Test is initializing"},
		{4,"Test is running"},
		{5,"Test was stopped"},
		{6,"Test was succesfull"},
		{7,"Test was unsuccesfull"}
	}
	CLASS CONTAINED & DYNAMIC;
	HANDLING	READ & WRITE;
}

VARIABLE last_valve_test_sp_or_time_table_1
{
	LABEL [last_valve_test_sp_or_time_table_1_label];
	HELP [last_valve_test_sp_or_time_table_1_help];
	CLASS CONTAINED;
	TYPE FLOAT
	{
		MIN_VALUE 0.0;
	}
	HANDLING READ;
	CONSTANT_UNIT "%/s";
}

last_valve_test_sp_or_time_table_2  LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_3  LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_4  LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_5  LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_6  LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_7  LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_8  LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_9  LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_10 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_11 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_12 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_13 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_14 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_15 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_16 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_17 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_18 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_19 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_20 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_21 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_22 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_23 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_24 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_25 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_26 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_27 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_28 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_29 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_30 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_31 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_32 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_33 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_34 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_35 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_36 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_37 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_38 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_39 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_40 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_41 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_42 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_43 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_44 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_45 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_46 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_47 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_48 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_49 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}
last_valve_test_sp_or_time_table_50 LIKE VARIABLE last_valve_test_sp_or_time_table_1 {}


VARIABLE last_valve_test_position_table_1
{
	LABEL [last_valve_test_position_table_1_label];
	HELP [last_valve_test_position_table_1_help];
	CLASS CONTAINED;
	TYPE FLOAT
	{
		MIN_VALUE 0.0;
		MAX_VALUE 100.0;
	}
	HANDLING READ;
	CONSTANT_UNIT [Percent];
}

last_valve_test_position_table_2  LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_3  LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_4  LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_5  LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_6  LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_7  LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_8  LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_9  LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_10 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_11 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_12 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_13 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_14 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_15 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_16 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_17 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_18 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_19 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_20 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_21 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_22 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_23 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_24 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_25 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_26 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_27 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_28 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_29 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_30 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_31 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_32 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_33 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_34 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_35 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_36 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_37 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_38 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_39 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_40 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_41 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_42 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_43 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_44 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_45 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_46 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_47 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_48 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_49 LIKE VARIABLE last_valve_test_position_table_1 {}
last_valve_test_position_table_50 LIKE VARIABLE last_valve_test_position_table_1 {}

VARIABLE valve_travel_vs_time_trend_table_1
{
	LABEL "% of elapsed trend time";
	HELP "";
	CLASS CONTAINED & DYNAMIC;
	TYPE FLOAT
	{
		MIN_VALUE 0.0;
		MAX_VALUE 100.0;
	}
	HANDLING READ;
	CONSTANT_UNIT "%";
}

valve_travel_vs_time_trend_table_2 LIKE VARIABLE valve_travel_vs_time_trend_table_1 {}
valve_travel_vs_time_trend_table_3 LIKE VARIABLE valve_travel_vs_time_trend_table_1 {}
valve_travel_vs_time_trend_table_4 LIKE VARIABLE valve_travel_vs_time_trend_table_1 {}
valve_travel_vs_time_trend_table_5 LIKE VARIABLE valve_travel_vs_time_trend_table_1 {}
valve_travel_vs_time_trend_table_6 LIKE VARIABLE valve_travel_vs_time_trend_table_1 {}
valve_travel_vs_time_trend_table_7 LIKE VARIABLE valve_travel_vs_time_trend_table_1 {}
valve_travel_vs_time_trend_table_8 LIKE VARIABLE valve_travel_vs_time_trend_table_1 {}
valve_travel_vs_time_trend_table_9 LIKE VARIABLE valve_travel_vs_time_trend_table_1 {}
valve_travel_vs_time_trend_table_10 LIKE VARIABLE valve_travel_vs_time_trend_table_1 {}

VARIABLE elapsed_trend_time
{
	LABEL "Elapsed trend time";
	HELP [elapsed_trend_time_help];
	CLASS CONTAINED & DYNAMIC;
	TYPE FLOAT
	{
		MIN_VALUE 0.0;
	}
	HANDLING READ;
	CONSTANT_UNIT "h";
}

VARIABLE deviation_table_1
{
	LABEL "Travel deviation";
	HELP "";
	CLASS CONTAINED & DYNAMIC;
	TYPE FLOAT
	{
		MIN_VALUE 0.0;
		MAX_VALUE 200.0;
	}
	HANDLING READ;
	CONSTANT_UNIT "%";
}

deviation_table_2 LIKE VARIABLE deviation_table_1 {}
deviation_table_3 LIKE VARIABLE deviation_table_1 {}
deviation_table_4 LIKE VARIABLE deviation_table_1 {}
deviation_table_5 LIKE VARIABLE deviation_table_1 {}
deviation_table_6 LIKE VARIABLE deviation_table_1 {}
deviation_table_7 LIKE VARIABLE deviation_table_1 {}
deviation_table_8 LIKE VARIABLE deviation_table_1 {}
deviation_table_9 LIKE VARIABLE deviation_table_1 {}
deviation_table_10 LIKE VARIABLE deviation_table_1 {}
deviation_table_11 LIKE VARIABLE deviation_table_1 {}
deviation_table_12 LIKE VARIABLE deviation_table_1 {}
deviation_table_13 LIKE VARIABLE deviation_table_1 {}
deviation_table_14 LIKE VARIABLE deviation_table_1 {}
deviation_table_15 LIKE VARIABLE deviation_table_1 {}
deviation_table_16 LIKE VARIABLE deviation_table_1 {}
deviation_table_17 LIKE VARIABLE deviation_table_1 {}
deviation_table_18 LIKE VARIABLE deviation_table_1 {}
deviation_table_19 LIKE VARIABLE deviation_table_1 {}
deviation_table_20 LIKE VARIABLE deviation_table_1 {}

VARIABLE deviation_time_table_1
{
	LABEL "Time";
	HELP "";
	CLASS CONTAINED & DYNAMIC;
	TYPE FLOAT
	{
		SCALING_FACTOR -1;
	}
	HANDLING READ;
	CONSTANT_UNIT "h";
}

deviation_time_table_2 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_3 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_4 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_5 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_6 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_7 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_8 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_9 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_10 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_11 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_12 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_13 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_14 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_15 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_16 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_17 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_18 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_19 LIKE VARIABLE deviation_time_table_1 {}
deviation_time_table_20 LIKE VARIABLE deviation_time_table_1 {}





VARIABLE load_factor_table_1
{
	LABEL "Load factor";
	HELP "";
	CLASS CONTAINED & DYNAMIC;
	TYPE FLOAT
	{
		MIN_VALUE 0.0;
		MAX_VALUE 100.0;
	}
	HANDLING READ;
	CONSTANT_UNIT "%";
}

load_factor_table_2 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_3 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_4 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_5 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_6 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_7 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_8 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_9 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_10 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_11 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_12 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_13 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_14 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_15 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_16 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_17 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_18 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_19 LIKE VARIABLE load_factor_table_1 {}
load_factor_table_20 LIKE VARIABLE load_factor_table_1 {}

VARIABLE load_factor_time_table_1
{
	LABEL "Time";
	HELP "";
	CLASS CONTAINED & DYNAMIC;
	TYPE FLOAT
	{
		SCALING_FACTOR -1;
	}
	HANDLING READ;
	CONSTANT_UNIT "h";
}

load_factor_time_table_2 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_3 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_4 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_5 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_6 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_7 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_8 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_9 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_10 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_11 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_12 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_13 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_14 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_15 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_16 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_17 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_18 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_19 LIKE VARIABLE load_factor_time_table_1 {}
load_factor_time_table_20 LIKE VARIABLE load_factor_time_table_1 {}

VARIABLE event_1
{
	LABEL "";
	HELP "Device event.";
	TYPE ENUMERATED (2)
	{
		{0,"Empty"},
		{30,"Calibration performed"},
		{33,"Calibration error [E33]"},
		{34,"Calibration error [E34]"},
		{35,"Self-tuning error [E35]"},
		{36,"Self-tuning error [E36]"},
		{37,"Self-tuning error [E37]"},
		{38,"Self-tuning error [E38]"},
		{39,"Self-tuning error [E39]"},
		{40,"Self-tuning performed"},
		{41,"Pneumatic prestage valve 1 control failure [E41]"},
		{42,"Pneumatic prestage valve 1 control failure [E42]"},
		{43,"Pneumatic prestage valve 1 control failure [E43]"},
		{44,"Pneumatic prestage valve 2 control failure [E44]"},
		{45,"Pneumatic prestage valve 2 control failure [E45]"},
		{46,"Pneumatic prestage valve 2 control failure [E46]"},
		{51,"Position feedback ADC low limit failure [E51]"},
		{52,"Position feedback ADC high limit failure [E52]"},
		{54,"Pressure sensor failure [E54]"},
		{55,"Pressure sensor failure [E55]"},
		{61,"EEPROM error [E61]"},
		{62,"Statistics damaged in EEPROM [E62]"},
		{63,"Configuration damaged in EEPROM [E63]"},
		{64,"Configuration damaged in EEPROM [E64]"},
		{65,"EEPROM error [E65]"},
		{66,"Temp. comp. damaged in EEPROM [E66]"},
		{67,"On-line diagnostics damaged in EEPROM [E67]"},
		{68,"Operating time damaged in EEPROM [E68]"},		
		{81,"RAM error [E81]"},
		{82,"ROM error [E82]"},
		{90,"VC card booted"},
		{91,"Processor failure [E91]"},
		{101,"Valve full strokes warning limit exceeded"},
		{102,"Valve reversals warning limit exceeded"},
		{103,"Actuator full strokes warning limit exceeded"},
		{104,"Actuator reversals warning limit exceeded"},
		{105,"Deviation warning limit exceeded"},
		{106,"Load factor warning limit exceeded"},
		{107,"Deviation alarm limit exceeded"},
		{108,"Load factor alarm limit exceeded"},
		{111,"Pneumatics problem"},
		{112,"Friction problem"},
		{113,"Travel deviation alert"},
		{114,"Load factor alert"},
		{200,"Board to board communication timeout"},
		{201,"Write was not successful"},
		{202,"FBI card booted"},
		{203,"Both LS1 and LS2 on"}		
	}
	CLASS CONTAINED & DYNAMIC;
	HANDLING READ;
}

event_2  LIKE VARIABLE event_1 {}
event_3  LIKE VARIABLE event_1 {}	 
event_4  LIKE VARIABLE event_1 {}	 
event_5  LIKE VARIABLE event_1 {}	 
event_6  LIKE VARIABLE event_1 {}	 
event_7  LIKE VARIABLE event_1 {}	 
event_8  LIKE VARIABLE event_1 {}	 
event_9  LIKE VARIABLE event_1 {}	 
event_10 LIKE VARIABLE event_1 {}	 
event_11 LIKE VARIABLE event_1 {}	 
event_12 LIKE VARIABLE event_1 {}	 
event_13 LIKE VARIABLE event_1 {}	 
event_14 LIKE VARIABLE event_1 {}	 
event_15 LIKE VARIABLE event_1 {}	 
event_16 LIKE VARIABLE event_1 {}	 
event_17 LIKE VARIABLE event_1 {}	 
event_18 LIKE VARIABLE event_1 {}	 
event_19 LIKE VARIABLE event_1 {}	 
event_20 LIKE VARIABLE event_1 {}	 

VARIABLE event_count_1
{
	LABEL "";
	HELP "Number of consecutively occured events.";
	TYPE UNSIGNED_INTEGER (1);
	CLASS CONTAINED & DYNAMIC;
	HANDLING READ;
}

event_count_2  LIKE VARIABLE event_count_1 {}
event_count_3  LIKE VARIABLE event_count_1 {}	 
event_count_4  LIKE VARIABLE event_count_1 {}	 
event_count_5  LIKE VARIABLE event_count_1 {}	 
event_count_6  LIKE VARIABLE event_count_1 {}	 
event_count_7  LIKE VARIABLE event_count_1 {}	 
event_count_8  LIKE VARIABLE event_count_1 {}	 
event_count_9  LIKE VARIABLE event_count_1 {}	 
event_count_10 LIKE VARIABLE event_count_1 {}	 
event_count_11 LIKE VARIABLE event_count_1 {}	 
event_count_12 LIKE VARIABLE event_count_1 {}	 
event_count_13 LIKE VARIABLE event_count_1 {}	 
event_count_14 LIKE VARIABLE event_count_1 {}	 
event_count_15 LIKE VARIABLE event_count_1 {}	 
event_count_16 LIKE VARIABLE event_count_1 {}	 
event_count_17 LIKE VARIABLE event_count_1 {}	 
event_count_18 LIKE VARIABLE event_count_1 {}	 
event_count_19 LIKE VARIABLE event_count_1 {}	 
event_count_20 LIKE VARIABLE event_count_1 {}	

VARIABLE event_time_1
{
	LABEL "";
	HELP "Event time stamp as device operation hours. If there are consecutively occured events, the time stamp reports the last event occurency time.";
	TYPE FLOAT;
	CONSTANT_UNIT "h";
	CLASS CONTAINED & DYNAMIC;
	HANDLING READ;
}

event_time_2  LIKE VARIABLE event_time_1 {}
event_time_3  LIKE VARIABLE event_time_1 {}	 
event_time_4  LIKE VARIABLE event_time_1 {}	 
event_time_5  LIKE VARIABLE event_time_1 {}	 
event_time_6  LIKE VARIABLE event_time_1 {}	 
event_time_7  LIKE VARIABLE event_time_1 {}	 
event_time_8  LIKE VARIABLE event_time_1 {}	 
event_time_9  LIKE VARIABLE event_time_1 {}	 
event_time_10 LIKE VARIABLE event_time_1 {}	 
event_time_11 LIKE VARIABLE event_time_1 {}	 
event_time_12 LIKE VARIABLE event_time_1 {}	 
event_time_13 LIKE VARIABLE event_time_1 {}	 
event_time_14 LIKE VARIABLE event_time_1 {}	 
event_time_15 LIKE VARIABLE event_time_1 {}	 
event_time_16 LIKE VARIABLE event_time_1 {}	 
event_time_17 LIKE VARIABLE event_time_1 {}	 
event_time_18 LIKE VARIABLE event_time_1 {}	 
event_time_19 LIKE VARIABLE event_time_1 {}	 
event_time_20 LIKE VARIABLE event_time_1 {}



VARIABLE source_1
{
	LABEL "0%";
	HELP "This table tells the current inherent flow characteristics without any signal modifications."
	" The values are relative flow coefficients at corresponding valve openings.";
	TYPE FLOAT
	{
		MIN_VALUE 0;
		MAX_VALUE 1;
	}
	CONSTANT_UNIT "Rel flow";
	CLASS CONTAINED & DYNAMIC;
	HANDLING READ & WRITE;
}

source_2  LIKE VARIABLE source_1 {REDEFINE LABEL "5%";}
source_3  LIKE VARIABLE source_1 {REDEFINE LABEL "10%";}	 
source_4  LIKE VARIABLE source_1 {REDEFINE LABEL "15%";}	 
source_5  LIKE VARIABLE source_1 {REDEFINE LABEL "20%";}	 
source_6  LIKE VARIABLE source_1 {REDEFINE LABEL "25%";}	 
source_7  LIKE VARIABLE source_1 {REDEFINE LABEL "30%";}	 
source_8  LIKE VARIABLE source_1 {REDEFINE LABEL "35%";}	 
source_9  LIKE VARIABLE source_1 {REDEFINE LABEL "40%";}	 
source_10 LIKE VARIABLE source_1 {REDEFINE LABEL "45%";}	 
source_11 LIKE VARIABLE source_1 {REDEFINE LABEL "50%";}	 
source_12 LIKE VARIABLE source_1 {REDEFINE LABEL "55%";}	 
source_13 LIKE VARIABLE source_1 {REDEFINE LABEL "60%";}	 
source_14 LIKE VARIABLE source_1 {REDEFINE LABEL "65%";}	 
source_15 LIKE VARIABLE source_1 {REDEFINE LABEL "70%";}	 
source_16 LIKE VARIABLE source_1 {REDEFINE LABEL "75%";}	 
source_17 LIKE VARIABLE source_1 {REDEFINE LABEL "80%";}	 
source_18 LIKE VARIABLE source_1 {REDEFINE LABEL "85%";}	 
source_19 LIKE VARIABLE source_1 {REDEFINE LABEL "90%";}	 
source_20 LIKE VARIABLE source_1 {REDEFINE LABEL "95%";}
source_21 LIKE VARIABLE source_1 {REDEFINE LABEL "100%";}

VARIABLE target_1
{
	LABEL "0%";
	HELP "This table tells the desired inherent flow characteristics."
		" The table values are the relative flow coefficients at corresponding valve openings.";	
	
	TYPE FLOAT
	{
		MIN_VALUE 0;
		MAX_VALUE 1;
	}
	CONSTANT_UNIT "Rel flow";
	CLASS CONTAINED & DYNAMIC;
	HANDLING READ & WRITE;
}

target_2  LIKE VARIABLE target_1 {REDEFINE LABEL "5%";}
target_3  LIKE VARIABLE target_1 {REDEFINE LABEL "10%";}	 
target_4  LIKE VARIABLE target_1 {REDEFINE LABEL "15%";}	 
target_5  LIKE VARIABLE target_1 {REDEFINE LABEL "20%";}	 
target_6  LIKE VARIABLE target_1 {REDEFINE LABEL "25%";}	 
target_7  LIKE VARIABLE target_1 {REDEFINE LABEL "30%";}	 
target_8  LIKE VARIABLE target_1 {REDEFINE LABEL "35%";}	 
target_9  LIKE VARIABLE target_1 {REDEFINE LABEL "40%";}	 
target_10 LIKE VARIABLE target_1 {REDEFINE LABEL "45%";}	 
target_11 LIKE VARIABLE target_1 {REDEFINE LABEL "50%";}	 
target_12 LIKE VARIABLE target_1 {REDEFINE LABEL "55%";}	 
target_13 LIKE VARIABLE target_1 {REDEFINE LABEL "60%";}	 
target_14 LIKE VARIABLE target_1 {REDEFINE LABEL "65%";}	 
target_15 LIKE VARIABLE target_1 {REDEFINE LABEL "70%";}	 
target_16 LIKE VARIABLE target_1 {REDEFINE LABEL "75%";}	 
target_17 LIKE VARIABLE target_1 {REDEFINE LABEL "80%";}	 
target_18 LIKE VARIABLE target_1 {REDEFINE LABEL "85%";}	 
target_19 LIKE VARIABLE target_1 {REDEFINE LABEL "90%";}	 
target_20 LIKE VARIABLE target_1 {REDEFINE LABEL "95%";}
target_21 LIKE VARIABLE target_1 {REDEFINE LABEL "100%";}

VARIABLE signal_mod_1
{
	LABEL "0%";
	HELP "Signal modification table"
	" The values are outputs at corresponding inputs.";
	TYPE FLOAT
	{
		MIN_VALUE 0;
		MAX_VALUE 100;
	}
	CONSTANT_UNIT "%";
	CLASS CONTAINED & DYNAMIC;
	HANDLING READ & WRITE;
}

signal_mod_2  LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "5%";}
signal_mod_3  LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "10%";}	 
signal_mod_4  LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "15%";}	 
signal_mod_5  LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "20%";}	 
signal_mod_6  LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "25%";}	 
signal_mod_7  LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "30%";}	 
signal_mod_8  LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "35%";}	 
signal_mod_9  LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "40%";}	 
signal_mod_10 LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "45%";}	 
signal_mod_11 LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "50%";}	 
signal_mod_12 LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "55%";}	 
signal_mod_13 LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "60%";}	 
signal_mod_14 LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "65%";}	 
signal_mod_15 LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "70%";}	 
signal_mod_16 LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "75%";}	 
signal_mod_17 LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "80%";}	 
signal_mod_18 LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "85%";}	 
signal_mod_19 LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "90%";}	 
signal_mod_20 LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "95%";}
signal_mod_21 LIKE VARIABLE signal_mod_1 {REDEFINE LABEL "100%";}


VARIABLE fill_source
{
	LABEL "Fill table";
	HELP "The table can be filled with Linear, Equal percentage or Quick opening tables and can also be cleared.";
	TYPE ENUMERATED (1)
	{
		{0,"User defined"},
		{1,"Linear"},
		{2,"Equal percentage 1:25"},
		{3,"Equal percentage 1:33"},
		{4,"Equal percentage 1:50"},
		{5,"Quick opening (Equal percentage inverse 1:25)"},
		{6,"Quick opening (Equal percentage inverse 1:33)"},
		{7,"Quick opening (Equal percentage inverse 1:50)"},
		{9,"Neles L1-series butterfly valve"},
		{10,"Neles R-series segment valve"},
		{11,"Neles M-series ball valve"},		
		{8,"Clear"}
	}
	CONSTANT_UNIT "%";
	CLASS CONTAINED;
	HANDLING READ & WRITE;
}

fill_target LIKE VARIABLE fill_source {}

VARIABLE characterization
{
	LABEL "Characterization";
	HELP "The flow characterization design tool changes the valve inherent flow characteristics curve to any desired curve."
		" Current inherent characteristics table tells the flow characteristics without any signal modifications."
		" Desired inherent characteristics table tells the desired characteristics. Based on this information, the tool calculates the required signal modification,"
		" Signal modification table, which is as well user editable. This parameter controls the characterization.";
	TYPE ENUMERATED (1)
	{
		{0,"Off"},
		{1,"On"},
		{2,"Calculate new Signal mod table from CURRENT and DESIRED tables"},
		{3,"Clear Signal mod table"},
		{4,"Enable new Signal mod table using all table values"},
		{5,"Enable new Signal mod table using every second table value"}
	}
	CLASS CONTAINED;
	HANDLING READ & WRITE;
}

VARIABLE vc_state
{
    LABEL [VC_STATE_LABEL];
    HELP [VC_STATE_LABEL_HELP];
    CLASS CONTAINED & DYNAMIC;
    TYPE BIT_ENUMERATED (2)
    {
		{0x0001,"Reserved for future use"}
		{0x0002,"Local override"},
		{0x0004,"Fail-safe"},
		{0x0008,"Device failure"},
		{0x0010,"event_log update"},
		{0x0020,"xd_error_extension update"},
		{0x0040,"Reserved for future use"},
		{0x0080,"VC parameter changed"},
		{0x0100,"Reserved for future use"},
		{0x0200,"Reserved for future use"},
		{0x0400,"Low limited"},
		{0x0800,"High limited"},
		{0x1000,"Write enabled"},
		{0x2000,"Simulate enabled"},
		{0x4000,"ls1_valve_closed"},
		{0x8000,"ls2_valve_open"}
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE vc_cmd
{
    LABEL [VC_CMD_LABEL];
    HELP [VC_CMD_LABEL_HELP];
    CLASS CONTAINED & DYNAMIC;
    TYPE BIT_ENUMERATED (1)
    {
		{0x00000001,"Bypass signal mods"},
		{0x00000002,"Restart processor"},
		{0x00000004,"Open valve to calibrated 100 %"},
		{0x00000008,"Close valve against mechanical limit"},
		{0x00000010,"Reserved for future use"},
		{0x00000020,"Reserved for future use"},
		{0x00000040,"Reserved for future use"},
		{0x00000080,"Reserved for future use"}
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}


VARIABLE action_id
{
    LABEL [ACTION_ID_LABEL];
    HELP [ACTION_ID_LABEL_HELP];
    CLASS CONTAINED ;
    TYPE ENUMERATED (1)
    {
		{ID_NONE,"None"},
		{ID_VALVE_TEST,"Valve test"},
		{ID_POS_CAL,"Pos sensor calib"},
		{ID_POS_BIAS,"Pos sensor bias"},
		{ID_PRES_ZERO,"Pressure zero calib"},
		{ID_PRES_SPAN,"Pressure span calib"},
		{ID_TEMP,"Temperature calib"}
    }
    CONSTANT_UNIT   [blank] ;
	HANDLING	READ & WRITE; 
}

VARIABLE action_ctrl
{
    LABEL [ACTION_CTRL_LABEL];
    HELP [ACTION_ID_LABEL_HELP];
    CLASS CONTAINED;
    TYPE ENUMERATED (1)
    {
		{CTRL_NONE,"None"},
		{CTRL_START,"Start"},
		{CTRL_CANCEL,"Cancel"},
		{CTRL_STATUS,"Status query"}
    }
    CONSTANT_UNIT   [blank] ;
	HANDLING	READ & WRITE; 
}

VARIABLE action_status
{
    LABEL [ACTION_STATUS_LABEL];
    HELP [ACTION_STATUS_LABEL_HELP];
    CLASS CONTAINED & DYNAMIC;
    TYPE ENUMERATED (1)
    {
		{STAT_IDLE			,"Operation is idle"},
		{STAT_INITIALIZING	,"Operation is initializing"},
		{STAT_RUNNING		,"Operation is running"},
		{STAT_CANCELED		,"Operation was canceled"},
		{STAT_CANCELLING	,"Operation is cancelling"},		
		{STAT_SUCCESFULL	,"Operation was succesfull"},
		{STAT_UNSUCCESFULL	,"Operation was unsuccesfull"},
		{STAT_UNKNOWN		,"Operation status is unknown"}
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ;
}

VARIABLE data1
{
    LABEL [DATA1_LABEL];
    CLASS CONTAINED;
    TYPE UNSIGNED_INTEGER (1)
	{
		MIN_VALUE 0;
		MAX_VALUE UINT8_MAX;
	}
    CONSTANT_UNIT   [blank] ;
	HANDLING	READ & WRITE;
}

VARIABLE data2
{
    LABEL [DATA2_LABEL];
    CLASS CONTAINED;
    TYPE FLOAT;
    CONSTANT_UNIT   [blank] ;
	HANDLING	READ & WRITE; 
}

VARIABLE data3
{
    LABEL [DATA3_LABEL];
    CLASS CONTAINED;
    TYPE FLOAT;
    CONSTANT_UNIT   [blank] ;
	HANDLING	READ & WRITE; 
}

VARIABLE data4
{
    LABEL [DATA4_LABEL];
    CLASS CONTAINED;
    TYPE FLOAT;
    CONSTANT_UNIT   [blank] ;
	HANDLING	READ & WRITE; 
}

VARIABLE data5
{
    LABEL [DATA5_LABEL];
    CLASS CONTAINED;
    TYPE FLOAT;
    CONSTANT_UNIT   [blank] ;
	HANDLING	READ & WRITE; 
}




/***********************************************************************/
/*    Function Block                                                   */
/***********************************************************************/

BLOCK function_block_1
{
	TYPE	FUNCTION;
	NUMBER	1;
}

func1_blk_reserve							LIKE VARIABLE	phys_blk_reserve
{
}

VARIABLE func1_blk_object
{
	LABEL		[blk_block_object];
	HELP		[blk_block_object_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{	2,	[blk_block_object_FUNCTION]		}
	}
	HANDLING	READ;
}

VARIABLE func1_blk_parent_class
{
	LABEL		[blk_parent_class];
	HELP		[func_blk_parent_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{	2,	[func_blk_parent_class_OUTPUT]	}
	}
	HANDLING	READ;
}

VARIABLE func1_blk_class
{
	LABEL		[blk_class];
	HELP		[func_blk_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{	1,	[func_blk_class_AO]		}
	}	
	HANDLING	READ;
}

func1_blk_dd_reference						LIKE VARIABLE	phys_blk_dd_reference
{											
}											
											
func1_blk_dd_rev							LIKE VARIABLE	phys_blk_dd_rev
{											
}											
											
func1_blk_profile							LIKE VARIABLE	phys_blk_profile
{											
}											
											
func1_blk_profile_rev						LIKE VARIABLE	phys_blk_profile_rev
{											
}											
											
func1_blk_execution_time					LIKE VARIABLE	phys_blk_execution_time
{											
}											
											
func1_blk_num_parameters					LIKE VARIABLE	phys_blk_num_parameters
{											
}											
											
func1_blk_index_view_1						LIKE VARIABLE	phys_blk_index_view_1
{											
}

func1_blk_num_view_lists					LIKE VARIABLE	phys_blk_num_view_lists
{											
}											
											
func1_st_rev								LIKE VARIABLE	phys_st_rev
{											
} 											
											
func1_tag_desc								LIKE VARIABLE	phys_tag_desc
{											
}											
											
func1_strategy								LIKE VARIABLE	phys_strategy
{											
}											
											
func1_alert_key								LIKE VARIABLE	phys_alert_key
{											
}

func1_target_mode							LIKE VARIABLE	phys_target_mode
{
	REDEFINE TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	BLOCK_MODE_AUTO;
		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
}

func1_actual_mode							LIKE VARIABLE	phys_actual_mode
{
	REDEFINE TYPE		ENUMERATED (1)
	{
		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
}

func1_permitted_mode						LIKE VARIABLE	phys_permitted_mode
{
	REDEFINE TYPE		BIT_ENUMERATED (1)
	{
		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
}

func1_normal_mode							LIKE VARIABLE	phys_normal_mode
{
	REDEFINE TYPE		ENUMERATED (1)
	{
		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
}

func1_current_state_alarm_sum				LIKE VARIABLE	phys_current_state_alarm_sum
{
	REDEFINE TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x0200,	[limit_state_HI_HI]		},
		{	0x0400,	[limit_state_HI]		},
		{	0x0800,	[limit_state_LO_LO]		},
		{	0x1000,	[limit_state_LO]		},
		{	0x8000,	[limit_state_ST_REV]	}
	}
}

func1_unacknowledged_state_alarm_sum		LIKE VARIABLE	phys_unacknowledged_state_alarm_sum
{
	REDEFINE TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x0200,	[limit_state_HI_HI]		},
		{	0x0400,	[limit_state_HI]		},
		{	0x0800,	[limit_state_LO_LO]		},
		{	0x1000,	[limit_state_LO]		},
		{	0x8000,	[limit_state_ST_REV]	}
	}
}

func1_unreported_state_alarm_sum			LIKE VARIABLE	phys_unreported_state_alarm_sum
{
	REDEFINE TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x0200,	[limit_state_HI_HI]		},
		{	0x0400,	[limit_state_HI]		},
		{	0x0800,	[limit_state_LO_LO]		},
		{	0x1000,	[limit_state_LO]		},
		{	0x8000,	[limit_state_ST_REV]	}
	}
}

func1_disabled_state_alarm_sum				LIKE VARIABLE	phys_disabled_state_alarm_sum
{
	REDEFINE TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x0200,	[limit_state_HI_HI]		},
		{	0x0400,	[limit_state_HI]		},
		{	0x0800,	[limit_state_LO_LO]		},
		{	0x1000,	[limit_state_LO]		},
		{	0x8000,	[limit_state_ST_REV]	}
	}
}

VARIABLE func1_batch_id
{
	LABEL		[func_batch_id];		
	HELP		[func_batch_id_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_batch_unit
{
	LABEL		[func_batch_unit];		
	HELP		[func_batch_unit_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_batch_operation
{
	LABEL		[func_batch_operation];		
	HELP		[func_batch_operation_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_batch_phase
{
	LABEL		[func_batch_phase];		
	HELP		[func_batch_phase_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
}

/***********************************************************************/
/*    Function Block: Analog Output							           */
/***********************************************************************/

VARIABLE func1_setpoint_value
{
	LABEL		[func_ao_setpoint_value];		
	HELP		[func_ao_setpoint_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_setpoint_status_quality
{
	LABEL		[status_quality];		
	HELP		[func_ao_setpoint_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_QUALITY
	}
	POST_EDIT_ACTIONS
	{
		method_set_status_limit
	}
	HANDLING	READ & WRITE;
}

func1_setpoint_status_limit					LIKE VARIABLE	func1_setpoint_status_quality
{
	REDEFINE LABEL		[status_limit];
	REDEFINE HELP [status_limit_help];
	REDEFINE TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_LIMIT
	}
}


VARIABLE func1_pv_upper_range_value
{
	LABEL		[func_pv_scale_upper_value];
	HELP		[func_pv_scale_upper_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	100.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_pv_lower_range_value
{
	LABEL		[func_pv_scale_lower_value];
	HELP		[func_pv_scale_lower_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_pv_unit
{
	LABEL		[func_pv_scale_unit];
	HELP		[func_pv_scale_unit_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	1342;
		UNIT_LIST
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_pv_decimal_point
{
	LABEL		[decimal_point];
	HELP		[decimal_point_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	2;
		{	0,   "0"		},
		{	1,   "1"		},
		{	2,   "2"		},
		{	3,   "3"		},
		{	4,   "4"		},
		{	5,   "5"		},
		{	6,   "6"		}
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_readback_value
{
	LABEL		[func_ao_readback_value];		
	HELP		[func_ao_readback_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ;
}

VARIABLE func1_readback_status_quality
{
	LABEL		[status_quality];		
	HELP		[func_ao_readback_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_QUALITY
	}
	HANDLING	READ;
}

func1_readback_status_limit					LIKE VARIABLE	func1_readback_status_quality
{
	REDEFINE LABEL		[status_limit];
	REDEFINE HELP [status_limit_help];
	REDEFINE TYPE		ENUMERATED (1)
	{
		STATUS_LIMIT
	}
}

VARIABLE func1_rcas_in_value
{
	LABEL		[func_rcas_in_value];
	HELP		[func_rcas_in_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_rcas_in_status_quality
{
	LABEL		[status_quality];		
	HELP		[func_rcas_in_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_QUALITY
	}
	POST_EDIT_ACTIONS
	{
		method_set_status_limit
	}
	HANDLING	READ & WRITE;
}

func1_rcas_in_status_limit					LIKE VARIABLE	func1_rcas_in_status_quality
{
	REDEFINE LABEL		[status_limit];	
		REDEFINE HELP [status_limit_help];
	REDEFINE TYPE		ENUMERATED (1)
	{
		STATUS_LIMIT
	}
}

VARIABLE func1_in_channel
{
	LABEL		[func_in_channel];
	HELP		[func_in_channel_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0x13A;
	}
	HANDLING	READ & WRITE;
}

func1_out_channel							LIKE VARIABLE	func1_in_channel
{
	REDEFINE LABEL [func_out_channel];
	REDEFINE HELP  [func_out_channel_help];
	REDEFINE TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0x139;
	}
}

VARIABLE func1_fsafe_time
{
	LABEL		[func_ao_fsafe_time];
	HELP		[func_ao_fsafe_time_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	30.0;
		MIN_VALUE		0.0;
		MAX_VALUE		100.0;
	}
	CONSTANT_UNIT	[sec];
	HANDLING	READ & WRITE;
}

VARIABLE func1_fsafe_type
{
	LABEL		[func_ao_fsafe_type];
	HELP		[func_ao_fsafe_type_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	2;
		{	0,	[func_ao_fsafe_type_FAIL_SAFE_VALUE]		},
		{	1,	[func_ao_fsafe_type_STORING_LAST_SETPOINT]	},
		{	2,	[func_ao_fsafe_type_FAIL_SAFE_POSITION]		}
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_fsafe_value
{
	LABEL		[func_ao_fsafe_value];
	HELP		[func_ao_fsafe_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
		MIN_VALUE		0.0;
		MAX_VALUE		100.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_rcas_out_value
{
	LABEL		[func_rcas_out_value];
	HELP		[func_rcas_out_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE func1_rcas_out_status_quality
{
	LABEL		[status_quality];
	HELP		[func_rcas_out_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_QUALITY
	}
	HANDLING	READ;
}

func1_rcas_out_status_limit					LIKE VARIABLE	func1_rcas_out_status_quality
{
	REDEFINE LABEL		[status_limit];		
	REDEFINE HELP [status_limit_help];
	REDEFINE TYPE		ENUMERATED (1)
	{
		STATUS_LIMIT
	}
}

VARIABLE func1_position_discrete_value
{
	LABEL		[func_ao_position_discrete_value];
	HELP		[func_ao_position_discrete_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		{	0,	[func_ao_position_discrete_status_NOT_INIT]			},	
		{	1,	[func_ao_position_discrete_status_CLOSED]			},
		{	2,	[func_ao_position_discrete_status_OPENED]			},
		{	3,	[func_ao_position_discrete_status_INTERMEDIATE]		}
	}
	HANDLING	READ;
}

VARIABLE func1_position_discrete_status_quality
{
	LABEL		[status_quality];		
	HELP		[func_ao_position_discrete_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_QUALITY
	}
	HANDLING	READ;
}

func1_position_discrete_status_limit		LIKE VARIABLE	func1_position_discrete_status_quality
{
	REDEFINE LABEL		[status_limit];
		REDEFINE HELP [status_limit_help];
	REDEFINE TYPE		ENUMERATED (1)
	{
		STATUS_LIMIT
	}
}

VARIABLE func1_setpoint_deviation
{
	LABEL		[func_ao_setpoint_deviation];
	HELP		[func_ao_setpoint_deviation_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	CONSTANT_UNIT	[Percent];
	HANDLING	READ;
}

#define CB_FAIL_SAFE		0x00010000		/* Bit  0 */
#define CB_REQ_LOC_OP		0x00020000		/* Bit  1 */
#define CB_LOCAL_OP			0x00040000		/* Bit  2 */
#define CB_OVERRIDE			0x00080000		/* Bit  3 */
#define CB_DISC_DIR			0x00100000		/* Bit  4 */
#define CB_TORQUE_D_OP		0x00200000		/* Bit  5 */
#define CB_TORQUE_D_CL		0x00400000		/* Bit  6 */
#define CB_TRAV_TIME		0x00800000		/* Bit  7 */
#define CB_ACT_OPEN			0x00000100		/* Bit  8 */
#define CB_ACT_CLOSE		0x00000200		/* Bit  9 */
#define CB_UPDATE_EVT		0x00000400		/* Bit 10 */
#define CB_SIMULATE			0x00000800		/* Bit 11 */
#define CB_DISTURBANCE		0x00001000		/* Bit 12 */
#define CB_CONTR_ERR		0x00002000		/* Bit 13 */
#define CB_CONTR_INACT		0x00004000		/* Bit 14 */
#define CB_SELFTEST			0x00008000		/* Bit 15 */
#define CB_TOT_VALVE_TRAV	0x00000001		/* Bit 16 */

VARIABLE func1_check_back
{
	LABEL		[func_check_back];
	HELP		[func_check_back_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (3)
	{
		{	0,					[dia_OK],				[dia_OK_help]				},
		{	CB_FAIL_SAFE,		[cb_FAIL_SAFE],			[cb_FAIL_SAFE_help]			},
		{	CB_REQ_LOC_OP,		[cb_REQ_LOC_OP],		[cb_REQ_LOC_OP_help]		},
		{	CB_LOCAL_OP,		[cb_LOCAL_OP],			[cb_LOCAL_OP_help]			},
		{	CB_OVERRIDE,		[cb_OVERRIDE],			[cb_OVERRIDE_help]			},
		{	CB_DISC_DIR,		[cb_DISC_DIR],			[cb_DISC_DIR_help]			},
		{	CB_TORQUE_D_OP,		[cb_TORQUE_D_OP],		[cb_TORQUE_D_OP_help]		},
		{	CB_TORQUE_D_CL,		[cb_TORQUE_D_CL],		[cb_TORQUE_D_CL_help]		},
		{	CB_TRAV_TIME,		[cb_TRAV_TIME],			[cb_TRAV_TIME_help]			},
		{	CB_ACT_OPEN,		[cb_ACT_OPEN],			[cb_ACT_OPEN_help]			},
		{	CB_ACT_CLOSE,		[cb_ACT_CLOSE],			[cb_ACT_CLOSE_help]			},
		{	CB_UPDATE_EVT,		[cb_UPDATE_EVT],		[cb_UPDATE_EVT_help]		},
		{	CB_SIMULATE,		[cb_SIMULATE],			[cb_SIMULATE_help]			},
		{	CB_DISTURBANCE,		[cb_DISTURBANCE],		[cb_DISTURBANCE_help]		},
		{	CB_CONTR_ERR,		[cb_CONTR_ERR],			[cb_CONTR_ERR_help]			},
		{	CB_CONTR_INACT,		[cb_CONTR_INACT],		[cb_CONTR_INACT_help]		},
		{	CB_SELFTEST,		[cb_SELFTEST],			[cb_SELFTEST_help]			},
		{	CB_TOT_VALVE_TRAV,	[cb_TOT_VALVE_TRAV],	[cb_TOT_VALVE_TRAV_help]	}
	}
	HANDLING	READ;
}

VARIABLE func1_check_back_mask
{
	LABEL		[func_check_back_mask];
	HELP		[func_check_back_mask_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (3)
	{
		{	CB_FAIL_SAFE,		[cb_FAIL_SAFE],			[cb_FAIL_SAFE_help]			},
		{	CB_REQ_LOC_OP,		[cb_REQ_LOC_OP],		[cb_REQ_LOC_OP_help]		},
		{	CB_LOCAL_OP,		[cb_LOCAL_OP],			[cb_LOCAL_OP_help]			},
		{	CB_OVERRIDE,		[cb_OVERRIDE],			[cb_OVERRIDE_help]			},
		{	CB_DISC_DIR,		[cb_DISC_DIR],			[cb_DISC_DIR_help]			},
		{	CB_TORQUE_D_OP,		[cb_TORQUE_D_OP],		[cb_TORQUE_D_OP_help]		},
		{	CB_TORQUE_D_CL,		[cb_TORQUE_D_CL],		[cb_TORQUE_D_CL_help]		},
		{	CB_TRAV_TIME,		[cb_TRAV_TIME],			[cb_TRAV_TIME_help]			},
		{	CB_ACT_OPEN,		[cb_ACT_OPEN],			[cb_ACT_OPEN_help]			},
		{	CB_ACT_CLOSE,		[cb_ACT_CLOSE],			[cb_ACT_CLOSE_help]			},
		{	CB_UPDATE_EVT,		[cb_UPDATE_EVT],		[cb_UPDATE_EVT_help]		},
		{	CB_SIMULATE,		[cb_SIMULATE],			[cb_SIMULATE_help]			},
		{	CB_DISTURBANCE,		[cb_DISTURBANCE],		[cb_DISTURBANCE_help]		},
		{	CB_CONTR_ERR,		[cb_CONTR_ERR],			[cb_CONTR_ERR_help]			},
		{	CB_CONTR_INACT,		[cb_CONTR_INACT],		[cb_CONTR_INACT_help]		},
		{	CB_SELFTEST,		[cb_SELFTEST],			[cb_SELFTEST_help]			},
		{	CB_TOT_VALVE_TRAV,	[cb_TOT_VALVE_TRAV],	[cb_TOT_VALVE_TRAV_help]	}
	}
	HANDLING	READ;
}

VARIABLE func1_simulate_value
{
	LABEL		[func_simulate_value];
	HELP		[func_ao_simulate_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_simulate_status_quality
{
	LABEL		[status_quality];		
	HELP		[func_simulate_status_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_QUALITY
	}
	POST_EDIT_ACTIONS
	{
		method_set_status_limit
	}
	HANDLING	READ & WRITE;
}

func1_simulate_status_limit					LIKE VARIABLE	func1_simulate_status_quality
{
	REDEFINE LABEL		[status_limit];		
	REDEFINE TYPE		ENUMERATED (1)
	{
		STATUS_LIMIT
	}
}

VARIABLE func1_simulation_enabled
{
	LABEL		[func_simulation_enabled];
	HELP		[func_simulation_enabled_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{	0,	[disabled]		},
		{	1,	[enabled]		}
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_increase_close
{
	LABEL		[func_ao_increase_close];
	HELP		[func_ao_increase_close_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{	0,	[func_ao_increase_close_RISING]		},
		{	1,	[func_ao_increase_close_FALLING]	}
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_out_value
{
	LABEL		[func_out_value];
	HELP		[func_ao_out_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING
		IF (func1_target_mode == BLOCK_MODE_MAN)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

VARIABLE func1_out_status_quality
{
	LABEL		[status_quality];		
	HELP		[func_out_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_QUALITY
	}
	POST_EDIT_ACTIONS
	{
		IF (func1_target_mode == BLOCK_MODE_MAN)
		{
			method_set_status_limit
		}
	}
	HANDLING
		IF (func1_target_mode == BLOCK_MODE_MAN)
		{
			READ & WRITE;
		}
		ELSE {
			READ;
		}
}

func1_out_status_limit						LIKE VARIABLE	func1_out_status_quality
{
	REDEFINE LABEL		[status_limit];		
	REDEFINE TYPE		ENUMERATED (1)
	{
		STATUS_LIMIT
	}
}

VARIABLE func1_out_upper_range_value
{
	LABEL		[func_out_scale_upper_value];
	HELP		[func_out_scale_upper_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	100.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_out_lower_range_value
{
	LABEL		[func_out_scale_lower_value];
	HELP		[func_out_scale_lower_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE func1_out_unit
{
	LABEL		[func_out_scale_unit];
	HELP		[func_out_scale_unit_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	1342;
		{ 1342,  [Percent],	[Percent_help]	}
	}
	HANDLING	READ & WRITE;
}

func1_out_decimal_point						LIKE VARIABLE	func1_pv_decimal_point
{
}


/***********************************************************************/
/*    Unit relations                                                   */
/***********************************************************************/

/* Physical Block */
/* no unit relations */

/* Transducer Block */
/* no unit relations */


/* Function Block Analog Input */
UNIT AO_PV_SCALE_UNIT
{
	func1_pv_unit:
	
	func1_pv_upper_range_value,
	func1_pv_lower_range_value,
	func1_readback_value,
	func1_setpoint_value,
	func1_rcas_in_value,
	func1_rcas_out_value,
	func1_fsafe_value,
	func1_simulate_value,
}

UNIT AO_OUT_SCALE_UNIT
{
	func1_out_unit:

	func1_out_value,
	func1_out_upper_range_value,
	func1_out_lower_range_value
}


/********************************************************************/
/*		Refresh relations											*/
/********************************************************************/



/*******************************************************************************/
/*****	MENU Bar  **************************************************************/
/*******************************************************************************/

MENU Menu_Main_Specialist
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_S_Device,
		Menu_View,
		Menu_S_Options,
		Menu_Help
	}
}

MENU Menu_Main_Maintenance
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_M_Device,
		Menu_View,
		Menu_Options,
		Menu_Help
	}
}


/***********************************************************************/
/*	Menu: Device													   */
/***********************************************************************/


MENU Menu_S_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_NodeAddress,
		SEPARATOR,
		std_LoadinDevice,										
		std_LoadinPC,
		SEPARATOR,
		OnlineDialog_operation,
		OnlineDialog_characterization,
		OnlineWindow_valve_test,
		SEPARATOR,
		OnlineDialog_write_locking,
		OnlineDialog_calibration,
		OnlineDialog_reset,
		IF (valid_pw) {OnlineDialog_service} 
	}
}

MENU Menu_M_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_LoadinDevice,										
		std_LoadinPC											
	}
}

METHOD std_NodeAddress
{
	LABEL		[menu_Device_NodeAddress];
	DEFINITION
	{
	}
}

METHOD std_LoadinDevice
{
	LABEL		[menu_Device_LoadinDevice];
	DEFINITION
	{
	}
}

METHOD std_LoadinPC
{
	LABEL		[menu_Device_LoadinPC];
	DEFINITION
	{
	}
}


/***********************************************************************/
/*	Menu: View														   */
/***********************************************************************/


MENU Menu_View
{
	LABEL		[menu_View];
	ITEMS
	{
		OnlineWindow_display,
		OnlineWindow_diagnosis,
		OnlineWindow_valve_diagnosis,
		OnlineWindow_event_log,
		SEPARATOR,
		std_Funktionsleiste,
		std_Statuszeile,
		SEPARATOR,
		std_Update
	}
}

METHOD std_Funktionsleiste
{
	LABEL		[menu_View_Toolbar];
	DEFINITION
	{
	}
}

METHOD std_Statuszeile
{
	LABEL		[menu_View_Statusbar];
	DEFINITION
	{
	}
}

METHOD std_Update
{
	LABEL		[menu_View_Update];
	DEFINITION
	{
	}
}

/***********************************************************************/
/*****	Online-Windows  ************************************************/
/***********************************************************************/


MENU OnlineWindow_display
{
	LABEL		[menu_dialog_display];
	ITEMS
	{
		Page_display_measure,
		Page_display_out
	}
}

MENU Page_display_measure
{
	LABEL		[menu_dialog_display_measure];
	ITEMS
	{
		BarVal_display_readback,
		Group_display_readback,
		Group_display_setpoint,
		func1_position_discrete_value,
		func1_setpoint_deviation,
		func1_check_back
	}
}

MENU BarVal_display_readback
{
	LABEL		[func_ao_readback_value];
	ITEMS
	{
		func1_readback_value,
		func1_pv_lower_range_value		(READ_ONLY),
		func1_pv_upper_range_value		(READ_ONLY)
	}
}

MENU Group_display_readback
{
	LABEL		[func_ao_readback_value];
	ITEMS
	{
		func1_readback_value,
		SEPARATOR,
		func1_readback_status_quality,
		func1_readback_status_limit
	}
}

MENU Group_display_setpoint
{
	LABEL		[func_ao_setpoint_value];
	ITEMS
	{
		func1_setpoint_value			(READ_ONLY),
		SEPARATOR,
		func1_setpoint_status_quality	(READ_ONLY),
		func1_setpoint_status_limit		(READ_ONLY)
	}
}

MENU Page_display_out
{
	LABEL		[menu_dialog_display_output];
	ITEMS
	{
		BarVal_display_out,
		Group_display_out,
		BarVal_display_trans1_positioning_value,
		Group_display_trans1_positioning_value,
		func1_check_back
	}
}

VARIABLE zero_percent
{
	LABEL		"zero";
	CLASS		LOCAL;
	TYPE		FLOAT
	{
			DEFAULT_VALUE	0;
	}
	CONSTANT_UNIT	[Percent];
	HANDLING	READ;
}

VARIABLE hundred_percent
{
	LABEL		"hundred";
	CLASS		LOCAL;
	TYPE		FLOAT
	{
			DEFAULT_VALUE	100;
	}
	CONSTANT_UNIT	[Percent];
	HANDLING	READ;
}

MENU BarVal_display_trans1_positioning_value
{
	LABEL		[trans_act_positioning_value];
	ITEMS
	{
		trans1_positioning_value,
		zero_percent,
		hundred_percent
	}
}

MENU Group_display_trans1_positioning_value
{
	LABEL		[trans_act_positioning_value];
	ITEMS
	{
		trans1_positioning_value,
		SEPARATOR,
		trans1_positioning_status_quality,
		trans1_positioning_status_limit
	}
}

MENU BarVal_display_out
{
	LABEL		[func_out_value];
	ITEMS
	{
		func1_out_value					(READ_ONLY),
		func1_out_lower_range_value		(READ_ONLY),
		func1_out_upper_range_value		(READ_ONLY)
	}
}

MENU Group_display_out
{
	LABEL		[func_out_value];
	ITEMS
	{
		func1_out_value					(READ_ONLY),
		SEPARATOR,
		func1_out_status_quality		(READ_ONLY),
		func1_out_status_limit			(READ_ONLY)
	}
}

MENU OnlineWindow_diagnosis
{
	LABEL		[menu_dialog_diagnosis];
	ITEMS
	{
		Page_diagnosis_general,
		Page_diagnosis_profile
	}
}

MENU Page_diagnosis_general
{
	LABEL		[menu_dialog_general];
	ITEMS
	{
		phys_tag_desc			(READ_ONLY),
		phys_device_man_id,
		phys_device_id,
		phys_device_ser_num,
		phys_software_rev,
		phys_hardware_rev,
		phys_install_date		(READ_ONLY),
		func1_check_back,
		phys_diagnosis,
		phys_diagnosis_extension
	}
}

MENU Page_diagnosis_profile
{
	LABEL		[blk_profile];
	ITEMS
	{
		phys_blk_profile,
		phys_blk_profile_rev,
		Group_diagnosis_st_rev
	}
}

MENU Group_diagnosis_st_rev
{
	LABEL		[st_rev];
	ITEMS
	{
		rename_value.PHYS_ST_REV,
		rename_value.TRANS_ST_REV,
		rename_value.FUNC_ST_REV
	}
}

MENU OnlineWindow_valve_diagnosis
{
	LABEL		[menu_OnlineWindow_valve_diagnosis_LABEL];
	ITEMS
	{
		Page_valve_diagnosis_general,
		Page_valve_diagnosis_travel_counters,
		Page_load_factor_trend,
		Page_travel_deviation_trend,
		Page_valve_travel_vs_time_trend
	}
}

MENU Page_load_factor_trend
{
	LABEL		[Page_load_factor_trend_label];
	ITEMS
	{
		OCX_out_display_xy_load_factor
		load_factor_warning_limit (READ_ONLY),
		load_factor_alarm_limit (READ_ONLY),
	}
}

MENU Page_travel_deviation_trend
{
	LABEL		[Page_travel_deviation_trend_label];
	ITEMS
	{
		OCX_out_display_xy_deviation
		travel_deviation_warning_limit (READ_ONLY),
		travel_deviation_alarm_limit (READ_ONLY),
	}
}

MENU Page_valve_travel_vs_time_trend
{
	LABEL		[Page_valve_travel_vs_time_trend_label];
	ITEMS
	{
		OCX_out_display_xy_travel_vs_time,
		elapsed_trend_time,
	}
}

MENU OCX_out_display_xy_travel_vs_time					// OCX-Control
{
	LABEL		"Valve travel vs time";						// beliebiger Name
	STYLE		"PDMTVPROXY.PDMTVProxyCtrl.1";		// Name, unter dem das OCX in Windows registriert ist
	ITEMS
	{
		OCX_ProfilNum_xy,							// Profil-Nummer

		OCX_out_display_valve_travel_vs_time,							// 1. Kurve
		
		OCX_UserSettings_xy		// Fr Speicherung von Settings, die vom Benutzer zur Laufzeit gendert wurden
	}
}

MENU OCX_out_display_valve_travel_vs_time								// 1. Kurve im OCX-Control xy
{
	LABEL		"Valve travel vs time";
	STYLE		"OCX_DYNAMIC_XY";
	ITEMS
	{
		y_values_vs,									// Liste aller x-Wert-Variablen
		x_values_vs,									// Liste aller y-Wert-Variablen
		travel_min	(READ_ONLY),					// Untergrenze x-Bereich
		travel_max	(READ_ONLY),					// Obgrenze x-Bereich
		time_pr_min	(READ_ONLY),					// untergrenze y-Bereich
		time_pr_max	(READ_ONLY),					// Obergrenze y-Bereich
		travel_mark (READ_ONLY),					// x-Wert zustzliche Markierung
		time_pr_mark (READ_ONLY),					// y-Wert zustzliche Markierung
		OCX_y_YScActualRangeMin,					// beliebige weitere kurvenspezifische OCX-Properties
		OCX_y_YScDataRangeMin,
		OCX_y_YScRangeMin,
		OCX_y_logarithmic (READ_ONLY)				// OCX-Property: Logarithmische y-Skale
	}
}

MENU x_values_vs										// Liste aller x-Wert-Variablen
{
	STYLE		"OCX_X_LIST";
    ITEMS
    {
		travel_cheat_0,
		travel_cheat_0,
		travel_cheat_1,
		travel_cheat_1,
		travel_cheat_1,
		travel_cheat_2, 
		travel_cheat_2, 
		travel_cheat_2,
		travel_cheat_3, 
		travel_cheat_3,
		travel_cheat_3,
		travel_cheat_4, 
		travel_cheat_4,
		travel_cheat_4,
		travel_cheat_5, 
		travel_cheat_5,
		travel_cheat_5,
		travel_cheat_6, 
		travel_cheat_6,
		travel_cheat_6,
		travel_cheat_7,
		travel_cheat_7,
		travel_cheat_7, 
		travel_cheat_8,
		travel_cheat_8,
		travel_cheat_8,
		travel_cheat_9,
		travel_cheat_9,
		travel_cheat_9,
		travel_cheat_10, 
		travel_cheat_10
	}
}

MENU y_values_vs										// Liste aller y-Wert-Variablen
{
	STYLE		"OCX_Y_LIST";
    ITEMS
    {
		time_pr_cheat_zero,
		valve_travel_vs_time_trend_table_1, 
		valve_travel_vs_time_trend_table_1,
		time_pr_cheat_zero,
		valve_travel_vs_time_trend_table_2, 
		valve_travel_vs_time_trend_table_2,
		time_pr_cheat_zero,
		valve_travel_vs_time_trend_table_3,
		valve_travel_vs_time_trend_table_3,
		time_pr_cheat_zero,
		valve_travel_vs_time_trend_table_4, 
		valve_travel_vs_time_trend_table_4,
		time_pr_cheat_zero,
		valve_travel_vs_time_trend_table_5,
		valve_travel_vs_time_trend_table_5,
		time_pr_cheat_zero,
		valve_travel_vs_time_trend_table_6, 
		valve_travel_vs_time_trend_table_6,
		time_pr_cheat_zero,
		valve_travel_vs_time_trend_table_7, 
		valve_travel_vs_time_trend_table_7,		
		time_pr_cheat_zero,		
		valve_travel_vs_time_trend_table_8, 
		valve_travel_vs_time_trend_table_8,		
		time_pr_cheat_zero,		
		valve_travel_vs_time_trend_table_9, 
		valve_travel_vs_time_trend_table_9,		
		time_pr_cheat_zero,		
		valve_travel_vs_time_trend_table_10,
		valve_travel_vs_time_trend_table_10,		
		time_pr_cheat_zero
    }
}

time_pr_cheat_zero LIKE VARIABLE valve_travel_vs_time_trend_table_1 {REDEFINE SCALING_FACTOR 0;}
load_factor_cheat_zero LIKE VARIABLE load_factor_table_1 {REDEFINE SCALING_FACTOR 0;}
deviation_cheat_zero LIKE VARIABLE deviation_table_1 {REDEFINE SCALING_FACTOR 0;}


VARIABLE travel_cheat_0			// Untergrenze x-Bereich
{
	CLASS		CONTAINED & DYNAMIC;
	LABEL		"Valve travel";
	CONSTANT_UNIT "%";
	TYPE		FLOAT
	{
		SCALING_FACTOR 0;
	}
	HANDLING    READ;
}

travel_cheat_1 LIKE VARIABLE travel_cheat_0 {REDEFINE SCALING_FACTOR 10;}
travel_cheat_2 LIKE VARIABLE travel_cheat_0 {REDEFINE SCALING_FACTOR 20;}
travel_cheat_2 LIKE VARIABLE travel_cheat_0 {REDEFINE SCALING_FACTOR 20;}
travel_cheat_3 LIKE VARIABLE travel_cheat_0 {REDEFINE SCALING_FACTOR 30;}
travel_cheat_4 LIKE VARIABLE travel_cheat_0 {REDEFINE SCALING_FACTOR 40;}
travel_cheat_5 LIKE VARIABLE travel_cheat_0 {REDEFINE SCALING_FACTOR 50;}
travel_cheat_6 LIKE VARIABLE travel_cheat_0 {REDEFINE SCALING_FACTOR 60;}
travel_cheat_7 LIKE VARIABLE travel_cheat_0 {REDEFINE SCALING_FACTOR 70;}
travel_cheat_8 LIKE VARIABLE travel_cheat_0 {REDEFINE SCALING_FACTOR 80;}
travel_cheat_9 LIKE VARIABLE travel_cheat_0 {REDEFINE SCALING_FACTOR 90;}
travel_cheat_10 LIKE VARIABLE travel_cheat_0 {REDEFINE SCALING_FACTOR 100;}


VARIABLE inp_cheat_0
{
	CLASS		CONTAINED & DYNAMIC;
	LABEL		"Input/Valve position";
	CONSTANT_UNIT "%";
	TYPE		FLOAT
	{
		SCALING_FACTOR 0;
	}
	HANDLING    READ;
}

inp_cheat_1 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 5;}
inp_cheat_2 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 10;}
inp_cheat_3 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 15;}
inp_cheat_4 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 20;}
inp_cheat_5 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 25;}
inp_cheat_6 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 30;}
inp_cheat_7 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 35;}
inp_cheat_8 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 40;}
inp_cheat_9 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 45;}
inp_cheat_10 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 50;}
inp_cheat_11 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 55;}
inp_cheat_12 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 60;}
inp_cheat_13 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 65;}
inp_cheat_14 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 70;}
inp_cheat_15 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 75;}
inp_cheat_16 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 80;}
inp_cheat_17 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 85;}
inp_cheat_18 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 90;}
inp_cheat_19 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 95;}
inp_cheat_20 LIKE VARIABLE inp_cheat_0 {REDEFINE SCALING_FACTOR 100;}

		
VARIABLE travel_min								// Untergrenze x-Bereich
{
	CLASS		LOCAL; //CONTAINED;
	LABEL		"Valve travel";
	CONSTANT_UNIT "%";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0;
	}
	HANDLING    READ;
}

VARIABLE travel_max								// Untergrenze x-Bereich
{
	CLASS		LOCAL; //CONTAINED;
	LABEL		"Valve travel";
	CONSTANT_UNIT "%";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 100;
	}
	HANDLING    READ;
}

VARIABLE time_pr_min								// Untergrenze x-Bereich
{
	CLASS		LOCAL; //CONTAINED;
	LABEL		"";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0;
	}
	HANDLING    READ;
	CONSTANT_UNIT "%";
}

VARIABLE time_pr_max								// Untergrenze x-Bereich
{
	CLASS		LOCAL; //CONTAINED;
	LABEL		"";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 100;
	}
	HANDLING    READ;
	CONSTANT_UNIT "%";	
}

VARIABLE travel_mark								// x-Wert zustzliche Markierung
{
	CLASS		LOCAL;
	LABEL		"Valve travel Mark.";
	CONSTANT_UNIT "%";
	TYPE		FLOAT;
	HANDLING    READ;
}

VARIABLE time_pr_mark								// y-Wert zustzliche Markierung
{
	CLASS		LOCAL;
	LABEL		"";
	TYPE		FLOAT;
	HANDLING    READ;
	CONSTANT_UNIT "%";	
}		
		
MENU OnlineWindow_event_log
{
	LABEL		"Event Log";
	ITEMS
	{
		Page_event_log,
		Page_event_log_1,
		Page_event_log_2,
		Page_event_log_3 
	}
}

MENU Page_event_log
{
	LABEL		[Page_event_log_label];
	ITEMS
	{
		Group_event,
		SEPARATOR,
		Group_event_count,
		SEPARATOR,
		Group_event_time
	}
}


MENU Group_event
{
	LABEL		"Event";
	ITEMS
	{
			event_1,
			event_2, 
			event_3, 
			event_4, 
			event_5 
	}
}

MENU Group_event_count
{
	LABEL		"Count";
	ITEMS
	{
			event_count_1,
			event_count_2, 
			event_count_3, 
			event_count_4, 
			event_count_5 
	}
}

MENU Group_event_time
{
	LABEL		"Time stamp";
	ITEMS
	{
			event_time_1,
			event_time_2, 
			event_time_3, 
			event_time_4, 
			event_time_5 
	}
}

MENU Page_event_log_1
{
	LABEL		[Page_event_log_label_1];
	ITEMS
	{
		Group_event_1,
		SEPARATOR,
		Group_event_count_1,
		SEPARATOR,
		Group_event_time_1
	}
}


MENU Group_event_1
{
	LABEL		"Event";
	ITEMS
	{
			event_6,
			event_7,
			event_8,
			event_9,
			event_10
	}
}

MENU Group_event_count_1
{
	LABEL		"Count";
	ITEMS
	{
			event_count_6,
			event_count_7,
			event_count_8,
			event_count_9,
			event_count_10
	}
}

MENU Group_event_time_1
{
	LABEL		"Time stamp";
	ITEMS
	{
			event_time_6,
			event_time_7,
			event_time_8,
			event_time_9,
			event_time_10
	}
}

MENU Page_event_log_2
{
	LABEL		[Page_event_log_label_2];
	ITEMS
	{
		Group_event_2,
		SEPARATOR,
		Group_event_count_2,
		SEPARATOR,
		Group_event_time_2
	}
}


MENU Group_event_2
{
	LABEL		"Event";
	ITEMS
	{
			event_11,
			event_12,
			event_13,
			event_14,
			event_15
	}
}

MENU Group_event_count_2
{
	LABEL		"Count";
	ITEMS
	{
			event_count_11,
			event_count_12,
			event_count_13,
			event_count_14,
			event_count_15
	}
}

MENU Group_event_time_2
{
	LABEL		"Time stamp";
	ITEMS
	{
			event_time_11,
			event_time_12,
			event_time_13,
			event_time_14,
			event_time_15
	}
}

MENU Page_event_log_3
{
	LABEL		[Page_event_log_label_3];
	ITEMS
	{
		Group_event_3,
		SEPARATOR,
		Group_event_count_3,
		SEPARATOR,
		Group_event_time_3
	}
}


MENU Group_event_3
{
	LABEL		"Event";
	ITEMS
	{
			event_16,
			event_17,
			event_18,
			event_19,
			event_20
	}
}

MENU Group_event_count_3
{
	LABEL		"Count";
	ITEMS
	{
			event_count_16,
			event_count_17,
			event_count_18,
			event_count_19,
			event_count_20
	}
}

MENU Group_event_time_3
{
	LABEL		"Time stamp";
	ITEMS
	{
			event_time_16,
			event_time_17,
			event_time_18,
			event_time_19,
			event_time_20
	}
}


MENU Page_valve_diagnosis_general
{
	LABEL		[Page_valve_diagnosis_general_label];
	ITEMS
	{
		OCX_out_display_yt,
		dev_temperature,
		act_pressure,
		operation_time
	}
}

MENU OCX_out_display_yt								// OCX-Control
{
	LABEL		[measurements_trend_label] ;
	STYLE		"PDMTVPROXY.PDMTVProxyCtrl.1";		// Name, unter dem das OCX in Windows registriert ist
	ITEMS
	{
		OCX_ProfilNum_yt,							// Profil-Nummer

		OCX_out_display_1,							// 1. Kurve
		OCX_out_display_2,							// 2. Kurve
		OCX_UserSettings_yt		// Fr Speicherung von Settings, die vom Benutzer zur Laufzeit gendert wurden
	}
}

VARIABLE OCX_ProfilNum_yt							// Profil-Variable fr OCX yt
{
	LABEL		"ProfilID";
	STYLE		"OCX_PROPERTY";
	CLASS		LOCAL;
	TYPE		INTEGER(2)
	{
		DEFAULT_VALUE	0;							// Profil 0 fr normale y-t-Darstellung
	}
	HANDLING    READ;
}

VARIABLE OCX_UserSettings_yt		// Fr Speicherung von Settings, die vom Benutzer zur Laufzeit gendert wurden
{
	LABEL		"UserSettings";
	STYLE		"OCX_PROPERTY";
	CLASS		LOCAL;
	TYPE		ASCII (1000)
	{
		DEFAULT_VALUE	"";
	}
	HANDLING	READ & WRITE;
}

MENU OCX_out_display_1								// 1. Kurve im OCX-Control yt
{
    LABEL		[DEV_TEMPERATURE_LABEL];
	STYLE		"OCX_DYNAMIC_YT";
	ITEMS
	{
			dev_temperature (READ_ONLY),
			temp_min	(READ_ONLY),
			temp_max	(READ_ONLY)
	}
}

VARIABLE temp_min
{
	LABEL		"temp_min";
	CLASS		LOCAL;
	TYPE		FLOAT
	{
			DEFAULT_VALUE	-40;
	}
	CONSTANT_UNIT [unit_1001];  // celsius
	HANDLING	READ;
}

VARIABLE temp_max
{
	LABEL		"temp_max";
	CLASS		LOCAL;
	TYPE		FLOAT
	{
			DEFAULT_VALUE	85;
	}
	CONSTANT_UNIT [unit_1001];  // celsius
	HANDLING	READ;
}

MENU OCX_out_display_2								// 1. Kurve im OCX-Control yt
{
    LABEL		[ACT_PRESSURE_LABEL];
	STYLE		"OCX_DYNAMIC_YT";
	ITEMS
	{
			act_pressure (READ_ONLY),
			press_min	(READ_ONLY),
			press_max	(READ_ONLY)
	}
}

VARIABLE press_min
{
	LABEL		"temp_min";
	CLASS		LOCAL;
	TYPE		FLOAT
	{
			DEFAULT_VALUE	-15;
	}
	CONSTANT_UNIT [unit_1137];  // bar
	HANDLING	READ;
}

VARIABLE press_max
{
	LABEL		"temp_max";
	CLASS		LOCAL;
	TYPE		FLOAT
	{
			DEFAULT_VALUE	15;
	}
	CONSTANT_UNIT [unit_1137];  // bar
	HANDLING	READ;
}

MENU Page_valve_diagnosis_travel_counters
{
	LABEL		[Page_valve_diagnosis_travel_counters_label];
	ITEMS
	{
		Group_valve_travel_counters,
		Group_act_travel_counters
	}
}

MENU Group_valve_travel_counters
{
	LABEL		[group_valve];
	ITEMS
	{
		valve_travel_counters_full_strokes,
		valve_travel_counters_reversals,
		SEPARATOR,
		rename_value.vtravel_w (READ_ONLY),
		rename_value.vrev_w (READ_ONLY)
	}
}

MENU Group_act_travel_counters
{
	LABEL		[group_actuator];
	ITEMS
	{
		act_travel_counters_full_strokes,
		act_travel_counters_reversals,
		SEPARATOR,
		rename_value.atravel_w (READ_ONLY),
		rename_value.arev_w (READ_ONLY)
	}
}

MENU OnlineWindow_valve_test
{
	LABEL		[menu_OnlineWindow_valve_test_LABEL];
	ITEMS
	{
		Page_vtest_ctrl,
		Page_vtest_step,
		Page_vtest_hyst
	}
}

MENU Page_vtest_ctrl
{
	LABEL		"Valve test";
	ITEMS
	{
		Group_vtest_settings,
		Group_vtest_ctrl,
		SEPARATOR,
		OCX_out_display_yt_vtest
	}
}

MENU Group_vtest_ctrl
{
	LABEL		"Test control";
	ITEMS
	{
		test_start (READ_ONLY),
		method_start_test,
		method_cancel_test
	}
}


MENU OCX_out_display_yt_vtest								// OCX-Control
{
	LABEL		[measurements_trend_label] ;
	STYLE		"PDMTVPROXY.PDMTVProxyCtrl.1";		// Name, unter dem das OCX in Windows registriert ist
	ITEMS
	{
		OCX_ProfilNum_yt,							// Profil-Nummer

		OCX_out_display_pos,							// 1. Kurve
		OCX_out_display_pos_sp,							// 1. Kurve
		OCX_UserSettings_yt		// Fr Speicherung von Settings, die vom Benutzer zur Laufzeit gendert wurden
	}
}

MENU OCX_out_display_pos								// 1. Kurve im OCX-Control yt
{
    LABEL		"Position measurement";
	STYLE		"OCX_DYNAMIC_YT";
	ITEMS
	{
			trans1_feedback_value (READ_ONLY),
			pos_min	(READ_ONLY),
			pos_max	(READ_ONLY)
	}
}

MENU OCX_out_display_pos_sp								// 1. Kurve im OCX-Control yt
{
    LABEL		"Position setpoint";
	STYLE		"OCX_DYNAMIC_YT";
	ITEMS
	{
			trans1_positioning_value (READ_ONLY),
			pos_sp_min	(READ_ONLY),
			pos_sp_max	(READ_ONLY)
	}
}


MENU Group_vtest_settings
{
	LABEL		"Test settings";
	ITEMS
	{
		test_type,
		test_starting_setpoint,
		test_loop_or_step_size,
		test_duration
	}
}

MENU Page_vtest_step
{
	LABEL		"Step resonse test results";
	ITEMS
	{
		Group_last_vtest,
		SEPARATOR,
		OCX_out_display_xy_step
	}
}

MENU Page_vtest_hyst
{
	LABEL		"Hysteresis test results";
	ITEMS
	{
		Group_last_vtest,
		SEPARATOR,
		OCX_out_display_xy_hyst
	}
}

MENU Group_last_vtest
{
	LABEL		"Last test settings";
	ITEMS
	{
		last_test_type,
		last_test_starting_setpoint,
		last_test_loop_or_step_size,
		last_test_duration
	}
}


/*******************************************************************************/
/*****	Valve test graph *******************************************************/
/*******************************************************************************/

MENU OCX_out_display_xy_step						// OCX-Control
{
	LABEL		"Valve test";						// beliebiger Name
	STYLE		"PDMTVPROXY.PDMTVProxyCtrl.1";		// Name, unter dem das OCX in Windows registriert ist
	ITEMS
	{
		OCX_ProfilNum_xy,							// Profil-Nummer

		OCX_out_display_step,							// 1. Kurve
		
		OCX_UserSettings_xy		// Fr Speicherung von Settings, die vom Benutzer zur Laufzeit gendert wurden
	}
}

MENU OCX_out_display_xy_hyst						// OCX-Control
{
	LABEL		"Valve test";						// beliebiger Name
	STYLE		"PDMTVPROXY.PDMTVProxyCtrl.1";		// Name, unter dem das OCX in Windows registriert ist
	ITEMS
	{
		OCX_ProfilNum_xy,							// Profil-Nummer

		OCX_out_display_hyst,							// 1. Kurve
		
		OCX_UserSettings_xy		// Fr Speicherung von Settings, die vom Benutzer zur Laufzeit gendert wurden
	}
}

// ------------------	1. Kurve: x-y-Darstellung	mit Wertepaaren	----------------------------------------


MENU OCX_out_display_step								// 1. Kurve im OCX-Control xy
{
	LABEL		"Valve test";
	STYLE		"OCX_DYNAMIC_XY";
	ITEMS
	{
		y_values,									// Liste aller x-Wert-Variablen
		x_values,									// Liste aller y-Wert-Variablen
		time_min	(READ_ONLY),					// Untergrenze x-Bereich
		last_test_duration	(READ_ONLY),					// Obgrenze x-Bereich
		pos_min	(READ_ONLY),					// untergrenze y-Bereich
		pos_max	(READ_ONLY),					// Obergrenze y-Bereich
		time_mark_s (READ_ONLY),					// x-Wert zustzliche Markierung
		pos_mark (READ_ONLY),					// y-Wert zustzliche Markierung
		OCX_y_YScActualRangeMin,					// beliebige weitere kurvenspezifische OCX-Properties
		OCX_y_YScDataRangeMin,
		OCX_y_YScRangeMin,
		OCX_y_logarithmic (READ_ONLY)				// OCX-Property: Logarithmische y-Skale
	}
}

MENU OCX_out_display_hyst								// 1. Kurve im OCX-Control xy
{
	LABEL		"Valve test";
	STYLE		"OCX_DYNAMIC_XY";
	ITEMS
	{
		y_values,									// Liste aller x-Wert-Variablen
		x_values,									// Liste aller y-Wert-Variablen
		pos_sp_min	(READ_ONLY),					// Untergrenze x-Bereich
		pos_sp_max	(READ_ONLY),					// Obgrenze x-Bereich
		pos_min	(READ_ONLY),					// untergrenze y-Bereich
		pos_max	(READ_ONLY),					// Obergrenze y-Bereich
		pos_sp_mark (READ_ONLY),					// x-Wert zustzliche Markierung
		pos_mark (READ_ONLY),					// y-Wert zustzliche Markierung
		OCX_y_YScActualRangeMin,					// beliebige weitere kurvenspezifische OCX-Properties
		OCX_y_YScDataRangeMin,
		OCX_y_YScRangeMin,
		OCX_y_logarithmic (READ_ONLY)				// OCX-Property: Logarithmische y-Skale
	}
}

MENU x_values										// Liste aller x-Wert-Variablen
{
	STYLE		"OCX_X_LIST";
    ITEMS
    {
		last_valve_test_sp_or_time_table_1,
		last_valve_test_sp_or_time_table_2, 
		last_valve_test_sp_or_time_table_3, 
		last_valve_test_sp_or_time_table_4, 
		last_valve_test_sp_or_time_table_5, 
		last_valve_test_sp_or_time_table_6, 
		last_valve_test_sp_or_time_table_7, 
		last_valve_test_sp_or_time_table_8, 
		last_valve_test_sp_or_time_table_9, 
		last_valve_test_sp_or_time_table_10,
		last_valve_test_sp_or_time_table_11,
		last_valve_test_sp_or_time_table_12,
		last_valve_test_sp_or_time_table_13,
		last_valve_test_sp_or_time_table_14,
		last_valve_test_sp_or_time_table_15,
		last_valve_test_sp_or_time_table_16,
		last_valve_test_sp_or_time_table_17,
		last_valve_test_sp_or_time_table_18,
		last_valve_test_sp_or_time_table_19,
		last_valve_test_sp_or_time_table_20,
		last_valve_test_sp_or_time_table_21,
		last_valve_test_sp_or_time_table_22,
		last_valve_test_sp_or_time_table_23,
		last_valve_test_sp_or_time_table_24,
		last_valve_test_sp_or_time_table_25,
		last_valve_test_sp_or_time_table_26,
		last_valve_test_sp_or_time_table_27,
		last_valve_test_sp_or_time_table_28,
		last_valve_test_sp_or_time_table_29,
		last_valve_test_sp_or_time_table_30,
		last_valve_test_sp_or_time_table_31,
		last_valve_test_sp_or_time_table_32,
		last_valve_test_sp_or_time_table_33,
		last_valve_test_sp_or_time_table_34,
		last_valve_test_sp_or_time_table_35,
		last_valve_test_sp_or_time_table_36,
		last_valve_test_sp_or_time_table_37,
		last_valve_test_sp_or_time_table_38,
		last_valve_test_sp_or_time_table_39,
		last_valve_test_sp_or_time_table_40,
		last_valve_test_sp_or_time_table_41,
		last_valve_test_sp_or_time_table_42,
		last_valve_test_sp_or_time_table_43,
		last_valve_test_sp_or_time_table_44,
		last_valve_test_sp_or_time_table_45,
		last_valve_test_sp_or_time_table_46,
		last_valve_test_sp_or_time_table_47,
		last_valve_test_sp_or_time_table_48,
		last_valve_test_sp_or_time_table_49,
		last_valve_test_sp_or_time_table_50
	}
}

MENU y_values										// Liste aller y-Wert-Variablen
{
	STYLE		"OCX_Y_LIST";
    ITEMS
    {
		last_valve_test_position_table_1,
		last_valve_test_position_table_2, 
		last_valve_test_position_table_3, 
		last_valve_test_position_table_4, 
		last_valve_test_position_table_5, 
		last_valve_test_position_table_6, 
		last_valve_test_position_table_7, 
		last_valve_test_position_table_8, 
		last_valve_test_position_table_9, 
		last_valve_test_position_table_10,
		last_valve_test_position_table_11,
		last_valve_test_position_table_12,
		last_valve_test_position_table_13,
		last_valve_test_position_table_14,
		last_valve_test_position_table_15,
		last_valve_test_position_table_16,
		last_valve_test_position_table_17,
		last_valve_test_position_table_18,
		last_valve_test_position_table_19,
		last_valve_test_position_table_20,
		last_valve_test_position_table_21,
		last_valve_test_position_table_22,
		last_valve_test_position_table_23,
		last_valve_test_position_table_24,
		last_valve_test_position_table_25,
		last_valve_test_position_table_26,
		last_valve_test_position_table_27,
		last_valve_test_position_table_28,
		last_valve_test_position_table_29,
		last_valve_test_position_table_30,
		last_valve_test_position_table_31,
		last_valve_test_position_table_32,
		last_valve_test_position_table_33,
		last_valve_test_position_table_34,
		last_valve_test_position_table_35,
		last_valve_test_position_table_36,
		last_valve_test_position_table_37,
		last_valve_test_position_table_38,
		last_valve_test_position_table_39,
		last_valve_test_position_table_40,
		last_valve_test_position_table_41,
		last_valve_test_position_table_42,
		last_valve_test_position_table_43,
		last_valve_test_position_table_44,
		last_valve_test_position_table_45,
		last_valve_test_position_table_46,
		last_valve_test_position_table_47,
		last_valve_test_position_table_48,
		last_valve_test_position_table_49,
		last_valve_test_position_table_50
    }
}

VARIABLE pos_sp_min								// Untergrenze x-Bereich
{
	CLASS		LOCAL; //CONTAINED;
	LABEL		"Position setpoint";
	CONSTANT_UNIT "%";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0;
	}
	HANDLING    READ;
}

VARIABLE pos_sp_max								// Untergrenze x-Bereich
{
	CLASS		LOCAL; //CONTAINED;
	LABEL		"Position setpoint";
	CONSTANT_UNIT "%";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 100;
	}
	HANDLING    READ;
}

VARIABLE time_min								// Untergrenze x-Bereich
{
	CLASS		LOCAL; //CONTAINED;
	LABEL		"Time";
	CONSTANT_UNIT "s";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0;
	}
	HANDLING    READ;
}

VARIABLE load_factor_max								// Untergrenze y-Bereich
{
	CLASS		LOCAL; //CONTAINED;
	LABEL		"Load factor";
//	STYLE		"OCX_Y_MAX";
	CONSTANT_UNIT	"%";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 100;
	}
	HANDLING    READ;
}

VARIABLE load_factor_min								// Untergrenze y-Bereich
{
	CLASS		LOCAL; //CONTAINED;
	LABEL		"Load factor";
//	STYLE		"OCX_Y_MIN";
	CONSTANT_UNIT	"%";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0;
	}
	HANDLING    READ;
}

VARIABLE outp_min	
{
	CLASS		LOCAL; 
	LABEL		"Output";
	CONSTANT_UNIT	"%";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0;
	}
	HANDLING    READ;
}

VARIABLE outp_max	
{
	CLASS		LOCAL; 
	LABEL		"Output";
	CONSTANT_UNIT	"%";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 100;
	}
	HANDLING    READ;
}

VARIABLE rel_min	
{
	CLASS		LOCAL; 
	LABEL		"";
	CONSTANT_UNIT	"Rel flow";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0;
	}
	HANDLING    READ;
}

VARIABLE rel_max	
{
	CLASS		LOCAL; 
	LABEL		"";
	CONSTANT_UNIT	"Rel flow";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 1;
	}
	HANDLING    READ;
}

VARIABLE inp_min	
{
	CLASS		LOCAL; 
	LABEL		"Input/Valve position";
	CONSTANT_UNIT	"%";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0;
	}
	HANDLING    READ;
}

VARIABLE inp_max	
{
	CLASS		LOCAL; 
	LABEL		"Input/Valve position";
	CONSTANT_UNIT	"%";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 100;
	}
	HANDLING    READ;
}

VARIABLE pos_min								// Untergrenze y-Bereich
{
	CLASS		LOCAL; //CONTAINED;
	LABEL		"Position measurement";
//	STYLE		"OCX_Y_MIN";
	CONSTANT_UNIT	"%";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0;
	}
	HANDLING    READ;
}

VARIABLE dev_max								// Obergrenze y-Bereich
{
	CLASS		LOCAL; //CONTAINED;
	LABEL		"Travel deviation";
//	STYLE		"OCX_Y_MAX";
	CONSTANT_UNIT	"%";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 20;
	}
	HANDLING    READ;
}

VARIABLE pos_max								// Obergrenze y-Bereich
{
	CLASS		LOCAL; //CONTAINED;
	LABEL		"Position measurement";
//	STYLE		"OCX_Y_MAX";
	CONSTANT_UNIT	"%";
	TYPE		FLOAT
	{
		DEFAULT_VALUE 100;
	}
	HANDLING    READ;
}

VARIABLE pos_sp_mark								// x-Wert zustzliche Markierung
{
	CLASS		LOCAL;
//	STYLE		"OCX_X_MARK";
	LABEL		"Position setpoint Mark.";
	CONSTANT_UNIT "%";
	TYPE		FLOAT;
	HANDLING    READ;
}

VARIABLE rel_mark								// x-Wert zustzliche Markierung
{
	CLASS		LOCAL;
	LABEL		"";
	CONSTANT_UNIT "Rel flow";
	TYPE		FLOAT;
	HANDLING    READ;
}

VARIABLE load_factor_mark								// x-Wert zustzliche Markierung
{
	CLASS		LOCAL;
	LABEL		"Load factor Mark.";
	CONSTANT_UNIT "%";
	TYPE		FLOAT;
	HANDLING    READ;
}

VARIABLE pos_mark								// x-Wert zustzliche Markierung
{
	CLASS		LOCAL;
	LABEL		"Position measurement Mark.";
	CONSTANT_UNIT "%";
	TYPE		FLOAT;
	HANDLING    READ;
}

VARIABLE time_mark_s								// y-Wert zustzliche Markierung
{
	CLASS		LOCAL;
//	STYLE		"OCX_X_MARK";
	LABEL		"Time Mark.";
	CONSTANT_UNIT	"s";
	TYPE		FLOAT;
	HANDLING    READ;
}

VARIABLE time_mark_h								// y-Wert zustzliche Markierung
{
	CLASS		LOCAL;
//	STYLE		"OCX_X_MARK";
	LABEL		"Time Mark.";
	CONSTANT_UNIT	"h";
	TYPE		FLOAT;
	HANDLING    READ;
}


// --------------------		Properties der ersten x-y-Kurve		-------------------------------------------

VARIABLE OCX_y_YScActualRangeMin					// OCX-Property: Untergrenze des aktuell sichtbaren x-Bereichs
{
	CLASS		LOCAL;
	LABEL		"YScActualRangeMin";
	STYLE		"OCX_PROPERTY";
	TYPE		FLOAT
	{
		DEFAULT_VALUE	2000;
	}
	HANDLING    READ;
}

VARIABLE OCX_y_YScDataRangeMin						// OCX-Property: Untergrenze des x-Daten-Bereichs
{
	CLASS		LOCAL;
	LABEL		"YScDataRangeMin";
	STYLE		"OCX_PROPERTY";
	TYPE		FLOAT
	{
		DEFAULT_VALUE	2000;
	}
	HANDLING    READ;
}

VARIABLE OCX_y_YScRangeMin							// OCX-Property: Untergrenze des maximalen x-Bereich
{
	CLASS		LOCAL;
	LABEL		"YScRangeMin";
	STYLE		"OCX_PROPERTY";
	TYPE		FLOAT
	{
		DEFAULT_VALUE	2000;
	}
	HANDLING    READ;
}

VARIABLE OCX_y_logarithmic							// OCX-Property: Logarithmische y-Skale
{
	CLASS		LOCAL;
	LABEL		"YScLogarithmic";
	STYLE		"OCX_PROPERTY";
	TYPE		INTEGER(1)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING    READ;
}

VARIABLE OCX_ProfilNum_xy							// Profil-Variable fr OCX yx
{
	LABEL		"ProfilID";
	STYLE		"OCX_PROPERTY";
	CLASS		LOCAL;
	TYPE		INTEGER(2)
	{
		DEFAULT_VALUE	1001;
	}
	HANDLING    READ;
}

VARIABLE OCX_UserSettings_xy		// Fr Speicherung von Settings, die vom Benutzer zur Laufzeit gendert wurden
{
	LABEL		"UserSettings";
	STYLE		"OCX_PROPERTY";
	CLASS		LOCAL;
	TYPE		ASCII (1000)
	{
		DEFAULT_VALUE	"";
	}
	HANDLING	READ & WRITE;
}

VARIABLE OCX_TimeScale								// OCX-Property: Keine Zeitachse
{
	LABEL		"XScTimescale";
	STYLE		"OCX_PROPERTY";
	CLASS		LOCAL;
	TYPE		INTEGER(2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ & WRITE;
}





MENU OCX_out_display_xy_signal_mod						// OCX-Control
{
	LABEL		"Signal modification curve";						// beliebiger Name
	STYLE		"PDMTVPROXY.PDMTVProxyCtrl.1";		// Name, unter dem das OCX in Windows registriert ist
	ITEMS
	{
		OCX_ProfilNum_xy,							// Profil-Nummer

		OCX_out_display_source,			
		OCX_out_display_signal_mod,				
		OCX_out_display_target,							
		OCX_UserSettings_xy		// Fr Speicherung von Settings, die vom Benutzer zur Laufzeit gendert wurden
	}
}

MENU OCX_out_display_signal_mod
{
	LABEL		"Signal modification curve";
	STYLE		"OCX_DYNAMIC_XY";
	ITEMS
	{
		y_values_outputs,
		x_values_inputs,
		inp_min	(READ_ONLY),					// Untergrenze x-Bereich
		inp_max	(READ_ONLY),					// Obgrenze x-Bereich
		outp_min	(READ_ONLY),					// untergrenze y-Bereich
		outp_max	(READ_ONLY),					// Obergrenze y-Bereich
		pos_mark (READ_ONLY),					// x-Wert zustzliche Markierung
		pos_mark (READ_ONLY),					// y-Wert zustzliche Markierung
		OCX_y_YScActualRangeMin,					// beliebige weitere kurvenspezifische OCX-Properties
		OCX_y_YScDataRangeMin,
		OCX_y_YScRangeMin,
		OCX_y_logarithmic (READ_ONLY)				// OCX-Property: Logarithmische y-Skale
	}
}

MENU x_values_inputs	
{
	STYLE		"OCX_X_LIST";
    ITEMS
    {
		inp_cheat_0,
		inp_cheat_1, 
		inp_cheat_2, 
		inp_cheat_3, 
		inp_cheat_4, 
		inp_cheat_5, 
		inp_cheat_6, 
		inp_cheat_7, 
		inp_cheat_8, 
		inp_cheat_9, 
		inp_cheat_10,
		inp_cheat_11,
		inp_cheat_12,
		inp_cheat_13,
		inp_cheat_14,
		inp_cheat_15,
		inp_cheat_16,
		inp_cheat_17,
		inp_cheat_18,
		inp_cheat_19,
		inp_cheat_20
    }
}


MENU y_values_outputs
{
	STYLE		"OCX_Y_LIST";
    ITEMS
    {
		rename_value.graph_signal_mod_1 (READ_ONLY),
		signal_mod_2 (READ_ONLY), 
		signal_mod_3 (READ_ONLY), 
		signal_mod_4 (READ_ONLY), 
		signal_mod_5 (READ_ONLY), 
		signal_mod_6 (READ_ONLY), 
		signal_mod_7 (READ_ONLY), 
		signal_mod_8 (READ_ONLY), 
		signal_mod_9 (READ_ONLY), 
		signal_mod_10 (READ_ONLY),
		signal_mod_11 (READ_ONLY),
		signal_mod_12 (READ_ONLY),
		signal_mod_13 (READ_ONLY),
		signal_mod_14 (READ_ONLY),
		signal_mod_15 (READ_ONLY),
		signal_mod_16 (READ_ONLY),
		signal_mod_17 (READ_ONLY),
		signal_mod_18 (READ_ONLY),
		signal_mod_19 (READ_ONLY),
		signal_mod_20 (READ_ONLY),
		signal_mod_21 (READ_ONLY)
    }
}


MENU OCX_out_display_source
{
	LABEL		"Signal modification curve";
	STYLE		"OCX_DYNAMIC_XY";
	ITEMS
	{
		y_values_source,
		x_values_inputs,
		inp_min	(READ_ONLY),					// Untergrenze x-Bereich
		inp_max	(READ_ONLY),					// Obgrenze x-Bereich
		rel_min	(READ_ONLY),					// untergrenze y-Bereich
		rel_max	(READ_ONLY),					// Obergrenze y-Bereich
		pos_mark (READ_ONLY),					// x-Wert zustzliche Markierung
		rel_mark (READ_ONLY),					// y-Wert zustzliche Markierung
		OCX_y_YScActualRangeMin,					// beliebige weitere kurvenspezifische OCX-Properties
		OCX_y_YScDataRangeMin,
		OCX_y_YScRangeMin,
		OCX_y_logarithmic (READ_ONLY)				// OCX-Property: Logarithmische y-Skale
	}
}

MENU y_values_source
{
	STYLE		"OCX_Y_LIST";
    ITEMS
    {
		rename_value.graph_source_1 (READ_ONLY),
		source_2 (READ_ONLY), 
		source_3 (READ_ONLY), 
		source_4 (READ_ONLY), 
		source_5 (READ_ONLY), 
		source_6 (READ_ONLY), 
		source_7 (READ_ONLY), 
		source_8 (READ_ONLY), 
		source_9 (READ_ONLY), 
		source_10 (READ_ONLY),
		source_11 (READ_ONLY),
		source_12 (READ_ONLY),
		source_13 (READ_ONLY),
		source_14 (READ_ONLY),
		source_15 (READ_ONLY),
		source_16 (READ_ONLY),
		source_17 (READ_ONLY),
		source_18 (READ_ONLY),
		source_19 (READ_ONLY),
		source_20 (READ_ONLY),
		source_21 (READ_ONLY)
    }
}




MENU OCX_out_display_target
{
	LABEL		"Signal modification curve";
	STYLE		"OCX_DYNAMIC_XY";
	ITEMS
	{
		y_values_target,
		x_values_inputs,
		inp_min	(READ_ONLY),					// Untergrenze x-Bereich
		inp_max	(READ_ONLY),					// Obgrenze x-Bereich
		rel_min	(READ_ONLY),					// untergrenze y-Bereich
		rel_max	(READ_ONLY),					// Obergrenze y-Bereich
		pos_mark (READ_ONLY),					// x-Wert zustzliche Markierung
		rel_mark (READ_ONLY),					// y-Wert zustzliche Markierung
		OCX_y_YScActualRangeMin,					// beliebige weitere kurvenspezifische OCX-Properties
		OCX_y_YScDataRangeMin,
		OCX_y_YScRangeMin,
		OCX_y_logarithmic (READ_ONLY)				// OCX-Property: Logarithmische y-Skale
	}
}

MENU y_values_target
{
	STYLE		"OCX_Y_LIST";
    ITEMS
    {
		rename_value.graph_target_1 (READ_ONLY),
		target_2 (READ_ONLY), 
		target_3 (READ_ONLY), 
		target_4 (READ_ONLY), 
		target_5 (READ_ONLY), 
		target_6 (READ_ONLY), 
		target_7 (READ_ONLY), 
		target_8 (READ_ONLY), 
		target_9 (READ_ONLY), 
		target_10 (READ_ONLY),
		target_11 (READ_ONLY),
		target_12 (READ_ONLY),
		target_13 (READ_ONLY),
		target_14 (READ_ONLY),
		target_15 (READ_ONLY),
		target_16 (READ_ONLY),
		target_17 (READ_ONLY),
		target_18 (READ_ONLY),
		target_19 (READ_ONLY),
		target_20 (READ_ONLY),
		target_21 (READ_ONLY)
    }
}











MENU OCX_out_display_xy_deviation						// OCX-Control
{
	LABEL		"deviation";						// beliebiger Name
	STYLE		"PDMTVPROXY.PDMTVProxyCtrl.1";		// Name, unter dem das OCX in Windows registriert ist
	ITEMS
	{
		OCX_ProfilNum_xy,							// Profil-Nummer

		OCX_out_display_deviation,							// 1. Kurve
		
		OCX_UserSettings_xy		// Fr Speicherung von Settings, die vom Benutzer zur Laufzeit gendert wurden
	}
}

// ------------------	1. Kurve: x-y-Darstellung	mit Wertepaaren	----------------------------------------


MENU OCX_out_display_deviation								// 1. Kurve im OCX-Control xy
{
	LABEL		"deviation";
	STYLE		"OCX_DYNAMIC_XY";
	ITEMS
	{
		y_values_deviation,									// Liste aller x-Wert-Variablen
		x_values_deviation,									// Liste aller y-Wert-Variablen
		deviation_time_table_20	(READ_ONLY),					// Untergrenze x-Bereich
		time_min	(READ_ONLY),					// Obgrenze x-Bereich
		pos_min	(READ_ONLY),					// untergrenze y-Bereich
		dev_max	(READ_ONLY),					// Obergrenze y-Bereich
		time_mark_h (READ_ONLY),					// x-Wert zustzliche Markierung
		pos_mark (READ_ONLY),					// y-Wert zustzliche Markierung
		OCX_y_YScActualRangeMin,					// beliebige weitere kurvenspezifische OCX-Properties
		OCX_y_YScDataRangeMin,
		OCX_y_YScRangeMin,
		OCX_y_logarithmic (READ_ONLY)				// OCX-Property: Logarithmische y-Skale
	}
}

MENU x_values_deviation										// Liste aller x-Wert-Variablen
{
	STYLE		"OCX_X_LIST";
    ITEMS
    {
			travel_cheat_0,
			travel_cheat_0,
			deviation_time_table_1,
			deviation_time_table_1,
			deviation_time_table_1,
			deviation_time_table_2, 
			deviation_time_table_2,
			deviation_time_table_2,
			deviation_time_table_3, 
			deviation_time_table_3,
			deviation_time_table_3,
			deviation_time_table_4, 
			deviation_time_table_4,
			deviation_time_table_4,
			deviation_time_table_5, 
			deviation_time_table_5, 
			deviation_time_table_5,
			deviation_time_table_6, 
			deviation_time_table_6, 
			deviation_time_table_6,
			deviation_time_table_7, 
			deviation_time_table_7,
			deviation_time_table_7,
			deviation_time_table_8, 
			deviation_time_table_8,
			deviation_time_table_8,
			deviation_time_table_9, 
			deviation_time_table_9,
			deviation_time_table_9,
			deviation_time_table_10,
			deviation_time_table_10,
			deviation_time_table_10,
			deviation_time_table_11,
			deviation_time_table_11,
			deviation_time_table_11,
			deviation_time_table_12,
			deviation_time_table_12,
			deviation_time_table_12,
    		deviation_time_table_13,
    		deviation_time_table_13,
    		deviation_time_table_13,
			deviation_time_table_14,
			deviation_time_table_14,
			deviation_time_table_14,
			deviation_time_table_15,
			deviation_time_table_15,
			deviation_time_table_15,
			deviation_time_table_16,
			deviation_time_table_16,
			deviation_time_table_16,
			deviation_time_table_17,
			deviation_time_table_17,
			deviation_time_table_17,
			deviation_time_table_18,
			deviation_time_table_18,
			deviation_time_table_18,
			deviation_time_table_19,
			deviation_time_table_19,
			deviation_time_table_19,
			deviation_time_table_20,
			deviation_time_table_20
	}
}

MENU y_values_deviation										// Liste aller y-Wert-Variablen
{
	STYLE		"OCX_Y_LIST";
    ITEMS
    {
			deviation_cheat_zero,
			deviation_table_1,
			deviation_table_1,
			deviation_cheat_zero,
			deviation_table_2, 
			deviation_table_2,
			deviation_cheat_zero,
			deviation_table_3, 
			deviation_table_3,
			deviation_cheat_zero,
			deviation_table_4, 
			deviation_table_4,
			deviation_cheat_zero,
			deviation_table_5, 
			deviation_table_5, 
			deviation_cheat_zero,
			deviation_table_6, 
			deviation_table_6, 
			deviation_cheat_zero,
			deviation_table_7, 
			deviation_table_7,
			deviation_cheat_zero,
			deviation_table_8, 
			deviation_table_8
			deviation_cheat_zero,
			deviation_table_9, 
			deviation_table_9,
			deviation_cheat_zero,
			deviation_table_10,
			deviation_table_10,
			deviation_cheat_zero,
			deviation_table_11,
			deviation_table_11,
			deviation_cheat_zero,
			deviation_table_12,
			deviation_table_12,
			deviation_cheat_zero,
    		deviation_table_13,
    		deviation_table_13,
			deviation_cheat_zero,
			deviation_table_14,
			deviation_table_14,
			deviation_cheat_zero,
			deviation_table_15,
			deviation_table_15,
			deviation_cheat_zero,
			deviation_table_16,
			deviation_table_16,
			deviation_cheat_zero,
			deviation_table_17,
			deviation_table_17,
			deviation_cheat_zero,
			deviation_table_18,
			deviation_table_18,
			deviation_cheat_zero,
			deviation_table_19,
			deviation_table_19,
			deviation_cheat_zero,
			deviation_table_20,
			deviation_table_20,
			deviation_cheat_zero
    }
}

MENU OCX_out_display_xy_load_factor						// OCX-Control
{
	LABEL		"deviation";						// beliebiger Name
	STYLE		"PDMTVPROXY.PDMTVProxyCtrl.1";		// Name, unter dem das OCX in Windows registriert ist
	ITEMS
	{
		OCX_ProfilNum_xy,							// Profil-Nummer

		OCX_out_display_load_factor,							// 1. Kurve
		
		OCX_UserSettings_xy		// Fr Speicherung von Settings, die vom Benutzer zur Laufzeit gendert wurden
	}
}


MENU OCX_out_display_load_factor								// 1. Kurve im OCX-Control xy
{
	LABEL		"Load factor";
	STYLE		"OCX_DYNAMIC_XY";
	ITEMS
	{
		y_values_load_factor,									// Liste aller x-Wert-Variablen
		x_values_load_factor,									// Liste aller y-Wert-Variablen
		load_factor_time_table_20	(READ_ONLY),					// Untergrenze x-Bereich
		time_min	(READ_ONLY),					// Obgrenze x-Bereich
		load_factor_min	(READ_ONLY),					// untergrenze y-Bereich
		load_factor_max	(READ_ONLY),					// Obergrenze y-Bereich
		time_mark_h (READ_ONLY),					// x-Wert zustzliche Markierung
		load_factor_mark (READ_ONLY),					// y-Wert zustzliche Markierung
		OCX_y_YScActualRangeMin,					// beliebige weitere kurvenspezifische OCX-Properties
		OCX_y_YScDataRangeMin,
		OCX_y_YScRangeMin,
		OCX_y_logarithmic (READ_ONLY)				// OCX-Property: Logarithmische y-Skale
	}
}

MENU x_values_load_factor										// Liste aller x-Wert-Variablen
{
	STYLE		"OCX_X_LIST";
    ITEMS
    {
			travel_cheat_0,
			travel_cheat_0,
			load_factor_time_table_1,
			load_factor_time_table_1,
			load_factor_time_table_1,
			load_factor_time_table_2, 
			load_factor_time_table_2,
			load_factor_time_table_2,
			load_factor_time_table_3, 
			load_factor_time_table_3,
			load_factor_time_table_3,
			load_factor_time_table_4, 
			load_factor_time_table_4,
			load_factor_time_table_4,
			load_factor_time_table_5, 
			load_factor_time_table_5, 
			load_factor_time_table_5,
			load_factor_time_table_6, 
			load_factor_time_table_6, 
			load_factor_time_table_6,
			load_factor_time_table_7, 
			load_factor_time_table_7,
			load_factor_time_table_7,
			load_factor_time_table_8, 
			load_factor_time_table_8,
			load_factor_time_table_8,
			load_factor_time_table_9, 
			load_factor_time_table_9,
			load_factor_time_table_9,
			load_factor_time_table_10,
			load_factor_time_table_10,
			load_factor_time_table_10,
			load_factor_time_table_11,
			load_factor_time_table_11,
			load_factor_time_table_11,
			load_factor_time_table_12,
			load_factor_time_table_12,
			load_factor_time_table_12,
    		load_factor_time_table_13,
    		load_factor_time_table_13,
    		load_factor_time_table_13,
			load_factor_time_table_14,
			load_factor_time_table_14,
			load_factor_time_table_14,
			load_factor_time_table_15,
			load_factor_time_table_15,
			load_factor_time_table_15,
			load_factor_time_table_16,
			load_factor_time_table_16,
			load_factor_time_table_16,
			load_factor_time_table_17,
			load_factor_time_table_17,
			load_factor_time_table_17,
			load_factor_time_table_18,
			load_factor_time_table_18,
			load_factor_time_table_18,
			load_factor_time_table_19,
			load_factor_time_table_19,
			load_factor_time_table_19,
			load_factor_time_table_20,
			load_factor_time_table_20
	}
}

MENU y_values_load_factor										// Liste aller y-Wert-Variablen
{
	STYLE		"OCX_Y_LIST";
    ITEMS
    {
			load_factor_cheat_zero,
			load_factor_table_1,
			load_factor_table_1,
			load_factor_cheat_zero,
			load_factor_table_2, 
			load_factor_table_2,
			load_factor_cheat_zero,
			load_factor_table_3, 
			load_factor_table_3,
			load_factor_cheat_zero,
			load_factor_table_4, 
			load_factor_table_4,
			load_factor_cheat_zero,
			load_factor_table_5, 
			load_factor_table_5, 
			load_factor_cheat_zero,
			load_factor_table_6, 
			load_factor_table_6, 
			load_factor_cheat_zero,
			load_factor_table_7, 
			load_factor_table_7,
			load_factor_cheat_zero,
			load_factor_table_8, 
			load_factor_table_8
			load_factor_cheat_zero,
			load_factor_table_9, 
			load_factor_table_9,
			load_factor_cheat_zero,
			load_factor_table_10,
			load_factor_table_10,
			load_factor_cheat_zero,
			load_factor_table_11,
			load_factor_table_11,
			load_factor_cheat_zero,
			load_factor_table_12,
			load_factor_table_12,
			load_factor_cheat_zero,
    		load_factor_table_13,
    		load_factor_table_13,
			load_factor_cheat_zero,
			load_factor_table_14,
			load_factor_table_14,
			load_factor_cheat_zero,
			load_factor_table_15,
			load_factor_table_15,
			load_factor_cheat_zero,
			load_factor_table_16,
			load_factor_table_16,
			load_factor_cheat_zero,
			load_factor_table_17,
			load_factor_table_17,
			load_factor_cheat_zero,
			load_factor_table_18,
			load_factor_table_18,
			load_factor_cheat_zero,
			load_factor_table_19,
			load_factor_table_19,
			load_factor_cheat_zero,
			load_factor_table_20,
			load_factor_table_20,
			load_factor_cheat_zero
    }
}


/*******************************************************************************/
/*****	Online-Dialogs  ********************************************************/
/*******************************************************************************/


MENU OnlineDialog_service
{
	LABEL		"SERVICE";
	ITEMS
	{
		Page_std_cal,
		Page_gw,
		Page_load,
		Page_fdl_err_stats
		Page_channel
	}
}

MENU Page_channel
{
	LABEL		"Channel";
	ITEMS
	{
		func1_in_channel,
		func1_out_channel
	}
}

MENU Page_fdl_err_stats
{
	LABEL		"fdl_err_stats";
	ITEMS
	{
		fdl_err_stats_1,
		fdl_err_stats_2, 
		fdl_err_stats_3, 
		fdl_err_stats_4, 
		fdl_err_stats_5, 
		fdl_err_stats_6, 
		fdl_err_stats_7, 
		fdl_err_stats_8, 
		fdl_err_stats_9, 
		fdl_err_stats_10
	}
}


MENU Page_std_cal
{
	LABEL		"Profile calibration";
	ITEMS
	{
		trans1_self_calibration_cmd,
		trans1_self_calibration_status,
		func1_check_back,
		phys_diagnosis,
		phys_diagnosis_extension
	}
}

MENU Page_load
{
	LABEL		"FBI CPU load";
	ITEMS
	{
		current_load,
		max_load,
		avg_load,
		softing_error_code
	}
}

MENU Page_gw
{
	LABEL		"VC Gateway";
	ITEMS
	{
		vc_gw_index,
		vc_gw_rw,
		vc_gw_data,
		vc_gw_status,
		method_set
	}
}

VARIABLE fdl_err_stats_1
{
    LABEL "FCS";
	CLASS CONTAINED & DYNAMIC;
	TYPE UNSIGNED_INTEGER (4);
	HANDLING READ;
}

fdl_err_stats_2 LIKE VARIABLE fdl_err_stats_1 { REDEFINE LABEL "FRM"; }
fdl_err_stats_3 LIKE VARIABLE fdl_err_stats_1 { REDEFINE LABEL "NEPT"; }
fdl_err_stats_4 LIKE VARIABLE fdl_err_stats_1 { REDEFINE LABEL "WSD"; }
fdl_err_stats_5 LIKE VARIABLE fdl_err_stats_1 { REDEFINE LABEL "WLEN"; }
fdl_err_stats_6 LIKE VARIABLE fdl_err_stats_1 { REDEFINE LABEL "SDR"; }
fdl_err_stats_7 LIKE VARIABLE fdl_err_stats_1 { REDEFINE LABEL "WFC"; }
fdl_err_stats_8 LIKE VARIABLE fdl_err_stats_1 { REDEFINE LABEL "WDS"; }
fdl_err_stats_9 LIKE VARIABLE fdl_err_stats_1 { REDEFINE LABEL "WSS"; }
fdl_err_stats_10 LIKE VARIABLE fdl_err_stats_1 { REDEFINE LABEL "EMPT"; }

VARIABLE current_load
{
    LABEL "Current load";
	CLASS		CONTAINED & DYNAMIC;
	TYPE FLOAT;
	HANDLING	READ;
}

VARIABLE max_load
{
    LABEL "Max load";
	CLASS		CONTAINED & DYNAMIC;
	TYPE FLOAT;
	HANDLING	READ;
}

VARIABLE avg_load
{
    LABEL "Average load";
	CLASS		CONTAINED & DYNAMIC;
	TYPE FLOAT;
	HANDLING	READ;
}


MENU OnlineDialog_operation
{
	LABEL		[menu_dialog_operation];
	ITEMS
	{
		Page_operation_AUTO,
		Page_operation_RCAS,
		Page_operation_MAN,
		Page_simulation
	}
}

MENU Group_setpoint
{
	LABEL		[func_ao_setpoint_value];
	ITEMS
	{
		func1_setpoint_value,
		SEPARATOR,
		func1_setpoint_status_quality,
		func1_setpoint_status_limit
	}
}

MENU Group_out
{
	LABEL		[menu_output];
	ITEMS
	{
		func1_out_value,
		SEPARATOR,
		func1_out_status_quality,
		func1_out_status_limit
	}
}

MENU Group_readback
{
	LABEL		[func_ao_readback_value];
	ITEMS
	{
		func1_readback_value,
		SEPARATOR,
		func1_readback_status_quality,
		func1_readback_status_limit
	}
}

MENU Group_rcas_in
{
	LABEL		[func_rcas_in_value];
	ITEMS
	{
		func1_rcas_in_value,
		SEPARATOR,
		func1_rcas_in_status_quality,
		func1_rcas_in_status_limit
	}
}

MENU Group_rcas_out
{
	LABEL		[func_rcas_out_value];
	ITEMS
	{
		func1_rcas_out_value,
		SEPARATOR,
		func1_rcas_out_status_quality,
		func1_rcas_out_status_limit
	}
}

MENU Page_operation_AUTO
{
	LABEL		[mode_AUTO];
	ITEMS
	{
		func1_target_mode,
		func1_actual_mode,
		Group_setpoint,
		Group_readback,
		func1_setpoint_deviation,
		func1_check_back,
		method_set
	}
}

MENU Page_operation_RCAS
{
	LABEL		[mode_RCAS];
	ITEMS
	{
		func1_target_mode,
		func1_actual_mode,
		Group_rcas_in,
		Group_rcas_out,
		Group_readback,
		func1_setpoint_deviation,
		func1_check_back,
		method_set
	}
}

MENU Page_operation_MAN
{
	LABEL		[mode_MAN];
	ITEMS
	{
		func1_target_mode,
		func1_actual_mode,
		Group_out,
		Group_readback,
		func1_setpoint_deviation,
		func1_check_back,
		method_set
	}
}

MENU Page_simulation
{
	LABEL		[menu_dialog_simulation];
	ITEMS
	{
		func1_simulation_enabled,
		Group_simulation,
		func1_setpoint_deviation,
		func1_check_back,
		method_set
	}
}

MENU Group_simulation
{
	LABEL		[menu_dialog_simulation];
	ITEMS
	{
		func1_simulate_value,
		SEPARATOR,
		func1_simulate_status_quality,
		func1_simulate_status_limit
	}
}

MENU OnlineDialog_reset
{
	LABEL		[master_reset];
	HELP		[master_reset_help];
	ITEMS
	{
		Page_factory_reset,
//		Page_reset_message,
		Page_reset_diagnostics
	}
}

MENU Page_reset_diagnostics
{
	LABEL		[RESET_DIAGNOSTICS_LABEL];
	ITEMS
	{
		reset_diagnostics,
		method_set
	}
}

MENU Page_factory_reset
{
	LABEL		[phys_factory_reset];
	HELP		[phys_factory_reset_help];
	ITEMS
	{
		phys_factory_reset,
		func1_check_back,
		phys_diagnosis,
		phys_diagnosis_extension,
		method_set
	}
}

MENU Page_reset_message
{
	LABEL		[trans_act_self_calibration_cmd_RESET];
	HELP		[trans_act_self_calibration_cmd_RESET_help];
	ITEMS
	{
		rename_value.TRANS_SELF_CAL_RESET,
		func1_check_back,
		phys_diagnosis,
		phys_diagnosis_extension,
		method_reset_checkback
	}
}

MENU OnlineDialog_calibration
{
	LABEL		[OnlineDialog_calibration_label];
	HELP		[OnlineDialog_calibration_help];
	ITEMS
	{
		Page_calibration
		Page_position_sensor_temp_comp
		Page_position_sensor_temp_comp_user
		Page_position_sensor_temp_comp_user_1
	}
}

MENU OnlineDialog_characterization
{
	LABEL		"Flow characterization";
	ITEMS
	{
		Page_source,
		Page_target,
		Page_signal_mod,
		Page_signal_mod_graph
	}
}

MENU Page_signal_mod_graph
{
	LABEL		"Curves";
	ITEMS
	{
		OCX_out_display_xy_signal_mod
	}
}

MENU Page_source
{
	LABEL		"Current inherent characteristics table";
	ITEMS
	{
			source_1,
			source_2, 
			source_3, 
			source_4, 
			source_5, 
			source_6, 
			source_7, 
			source_8, 
			source_9, 
			source_10,
			source_11,
			SEPARATOR,
			source_12,
			source_13,
			source_14,
			source_15,
			source_16,
			source_17,
			source_18,
			source_19,
			source_20,
			source_21,
			fill_source,
			method_set
	}
}

MENU Page_target
{
	LABEL		"Desired inherent characteristics table";
	ITEMS
	{
			target_1,
			target_2, 
			target_3, 
			target_4, 
			target_5, 
			target_6, 
			target_7, 
			target_8, 
			target_9, 
			target_10,
			target_11,
			SEPARATOR,
			target_12,
			target_13,
			target_14,
			target_15,
			target_16,
			target_17,
			target_18,
			target_19,
			target_20,
			target_21,
			fill_target,
			method_set
	}
}

MENU Page_signal_mod
{
	LABEL		"Signal modification table";
	ITEMS
	{
			signal_mod_1,
			signal_mod_2, 
			signal_mod_3, 
			signal_mod_4, 
			signal_mod_5, 
			signal_mod_6, 
			signal_mod_7, 
			signal_mod_8, 
			signal_mod_9, 
			signal_mod_10,
			signal_mod_11,
			SEPARATOR,
			signal_mod_12,
			signal_mod_13,
			signal_mod_14,
			signal_mod_15,
			signal_mod_16,
			signal_mod_17,
			signal_mod_18,
			signal_mod_19,
			signal_mod_20,
			signal_mod_21,
			characterization,
			method_set
	}
}


MENU Page_calibration
{
	LABEL		[OnlineDialog_calibration_label];
	HELP		[OnlineDialog_calibration_help];
	ITEMS
	{
		Group_automatic_travel_calib,
		Group_module_calib
	}
}

MENU Group_module_calib
{
	LABEL		"Module Calibration";
	ITEMS
	{
		method_position_sensor_cal,
		method_pressure_sensor_cal,
		method_temperature_measurement_calibration
	}
}

MENU Group_automatic_travel_calib
{
	LABEL		[Group_automatic_travel_calib_label];
	HELP		[Group_automatic_travel_calib_help];
	ITEMS
	{
		action_status,
		SEPARATOR,
		method_start_self_calibration,
		method_cancel_self_calibration
	}
}

MENU Page_position_sensor_temp_comp
{
	LABEL		[Page_position_sensor_temp_comp_label];
	HELP		[Page_position_sensor_temp_comp_help];
	ITEMS
	{
		pos_sensor_sn,
		pos_sensor_temp_comp,
		method_set
	}
}

MENU Page_position_sensor_temp_comp_user
{
	LABEL		[Page_position_sensor_temp_comp_user_label];
	HELP		[Page_position_sensor_temp_comp_user_help];
	ITEMS
	{
		pos_sensor_temp_comp_min_table_1,
		pos_sensor_temp_comp_min_table_2,
		pos_sensor_temp_comp_min_table_3,
		pos_sensor_temp_comp_min_table_4,
		pos_sensor_temp_comp_min_table_5,
		pos_sensor_temp_comp_min_table_6,
		pos_sensor_temp_comp_min_table_7,
		pos_sensor_temp_comp_min_table_8,
		pos_sensor_temp_comp_min_table_9,
		pos_sensor_temp_comp_min_table_10,
		pos_sensor_temp_comp_min_table_11,
		pos_sensor_temp_comp_min_table_12,
		pos_sensor_temp_comp_min_table_13,
		SEPARATOR,
		pos_sensor_temp_comp_max_table_1,
		pos_sensor_temp_comp_max_table_2,
		pos_sensor_temp_comp_max_table_3,
		pos_sensor_temp_comp_max_table_4,
		pos_sensor_temp_comp_max_table_5,
		pos_sensor_temp_comp_max_table_6,
		pos_sensor_temp_comp_max_table_7,
		pos_sensor_temp_comp_max_table_8,
		pos_sensor_temp_comp_max_table_9,
		pos_sensor_temp_comp_max_table_10,
		pos_sensor_temp_comp_max_table_11,
		pos_sensor_temp_comp_max_table_12,
		pos_sensor_temp_comp_max_table_13,
		method_set
	}
}

MENU Page_position_sensor_temp_comp_user_1
{
	LABEL		[Page_position_sensor_temp_comp_user_label_1];
	HELP		[Page_position_sensor_temp_comp_user_help];
	ITEMS
	{
		pos_sensor_temp_comp_min_table_14,
		pos_sensor_temp_comp_min_table_15,
		pos_sensor_temp_comp_min_table_16,
		pos_sensor_temp_comp_min_table_17,
		pos_sensor_temp_comp_min_table_18,
		pos_sensor_temp_comp_min_table_19,
		pos_sensor_temp_comp_min_table_20,
		pos_sensor_temp_comp_min_table_21,
		pos_sensor_temp_comp_min_table_22,
		pos_sensor_temp_comp_min_table_23,
		pos_sensor_temp_comp_min_table_24,
		pos_sensor_temp_comp_min_table_25,
		pos_sensor_temp_comp_min_table_26,
		SEPARATOR,
		pos_sensor_temp_comp_max_table_14,
		pos_sensor_temp_comp_max_table_15,
		pos_sensor_temp_comp_max_table_16,
		pos_sensor_temp_comp_max_table_17,
		pos_sensor_temp_comp_max_table_18,
		pos_sensor_temp_comp_max_table_19,
		pos_sensor_temp_comp_max_table_20,
		pos_sensor_temp_comp_max_table_21,
		pos_sensor_temp_comp_max_table_22,
		pos_sensor_temp_comp_max_table_23,
		pos_sensor_temp_comp_max_table_24,
		pos_sensor_temp_comp_max_table_25,
		pos_sensor_temp_comp_max_table_26,
		method_set
	}
}



MENU OnlineDialog_write_locking
{
	LABEL		[write_access_protection];
	ITEMS
	{
		phys_hw_write_protection,
		phys_write_locking,
		phys_local_operation_enable,
		method_set
	}
}

/*******************************************************************************/
/*****	Table: Specialist  *****************************************************/
/*******************************************************************************/

MENU Table_Main_Specialist
{
	LABEL	DEVICE_TYPE_STR;
	ITEMS
	{
		Tab_s_ident,
		Tab_s_settings,
		Tab_s_input,
		Tab_s_charact,
		Tab_s_interface,
		Tab_s_certificates
	}
}

MENU Tab_s_ident
{
	LABEL		[menu_ident];

	ITEMS
	{
		Tab_s_ident_opunit,
		Tab_s_ident_device,
		Tab_s_ident_batch_info
	}
}

MENU Tab_s_ident_opunit
{
	LABEL		[menu_ident_opunit];
	ITEMS
	{
		phys_tag_desc,
		phys_descriptor,	
		phys_message	
	}
}

MENU Tab_s_ident_device
{
	LABEL		[menu_ident_device];
	ITEMS
	{
		Tab_s_ident_device_positioner,
		Tab_s_ident_device_actuator,
		Tab_s_ident_device_valve
	}
}

MENU Tab_s_ident_device_positioner
{
	LABEL		[menu_ident_device_positioner];
	ITEMS
	{
		phys_device_man_id,
		phys_device_id,
		phys_software_rev,
		phys_hardware_rev,
		phys_device_ser_num,
		device_pcb_sn,
		phys_install_date,
		phys_blk_profile_rev,
		phys_ident_number,
		Tab_st_rev
	}
}

MENU Tab_st_rev
{
	LABEL		[st_rev];
	ITEMS
	{
		rename_value.PHYS_ST_REV,
		rename_value.TRANS_ST_REV,
		rename_value.FUNC_ST_REV
	}
}

MENU Tab_s_ident_device_actuator
{
	LABEL		[menu_ident_device_actuator];
	ITEMS
	{
		trans1_actuator_man,	
		trans1_actuator_type (READ_ONLY),
		act_type (READ_ONLY),
		trans1_actuator_action (READ_ONLY),
		trans1_actuator_serial_number	
	}
}

MENU Tab_s_ident_device_valve
{
	LABEL		[menu_ident_device_valve];
	ITEMS
	{
		trans1_valve_man,
		trans1_valve_type (READ_ONLY),
		trans1_valve_serial_number	
	}
}

MENU Tab_s_ident_batch_info
{
	LABEL		[menu_ident_batch_info];
	ITEMS
	{
			func1_batch_id,
			func1_batch_unit,
			func1_batch_operation,
			func1_batch_phase
	}
}

MENU Tab_s_settings
{
	LABEL		[menu_settings];
	ITEMS
	{
		Tab_assembly_related_configuration,
		Tab_s_charact_powerloss,
		Tab_servo_controller,
		Tab_s_valve_diagnostics
	}
}

MENU Tab_assembly_related_configuration
{
	LABEL		[menu_assembly_related_configuration_label];
	ITEMS
	{
		pos_sensor_rot,
		act_type,
		trans1_valve_type,
		fail_action,
		trans1_actuator_action,
		dead_angle_comp,
		limit_switches
	}
}


MENU Tab_servo_controller
{
	LABEL		[menu_servo_controller_LABEL];
	ITEMS
	{
		trans1_servo_gain,
		servo_param_d,
		servo_param_b
	}
}

MENU Tab_s_input
{
	LABEL		[menu_input];
	ITEMS
	{
		Tab_s_input_input,
		Tab_s_input_workrange,
		Tab_s_charact_traveltime
//		Tab_s_input_table
	}
}

MENU Tab_s_input_input
{
	LABEL		[menu_input_input];
	ITEMS
	{
		func1_increase_close,
		func1_pv_lower_range_value,	
		func1_pv_upper_range_value,	
		func1_pv_unit,
		trans1_setp_cutoff_dec,
		trans1_setp_cutoff_inc
	}
}

MENU Tab_s_input_workrange
{
	LABEL		[menu_input_workrange];
	ITEMS
	{
		func1_out_lower_range_value,	
		func1_out_upper_range_value,	
		func1_out_unit,
		trans1_travel_limit_lower_value,
		trans1_travel_limit_upper_value
	}
}

MENU Tab_s_input_table
{
	LABEL		[menu_input_table];
	ITEMS
	{
		trans1_lin_type
	}
}

MENU Tab_s_charact_powerloss
{
	LABEL		[menu_charact_powerloss];
	ITEMS
	{
		func1_fsafe_type,
		func1_fsafe_time,
		func1_fsafe_value
	}
}

MENU Tab_s_charact_traveltime
{
	LABEL		[menu_charact_traveltime];
	ITEMS
	{
//		trans1_act_stroke_time_dec,	
//		trans1_act_stroke_time_inc,	
		trans1_travel_rate_dec,
		trans1_travel_rate_inc
	}
}

		
MENU Tab_s_valve_diagnostics
{
	LABEL		[menu_valve_diagnostics_LABEL];
	ITEMS
	{
		supply_pressure,
		travel_deviation_warning_limit,
		travel_deviation_alarm_limit,
		load_factor_warning_limit,
		load_factor_alarm_limit,
		valve_travel_counters_full_strokes_warning_limit,
		valve_travel_counters_reversals_warning_limit,
		act_travel_counters_full_strokes_warning_limit,
		act_travel_counters_reversals_warning_limit
	}
}

MENU Tab_s_interface
{
	LABEL		[menu_interface];
	ITEMS
	{
		Tab_s_interface_maintenance,
		Tab_s_interface_simulate
	}
}



MENU Tab_s_interface_maintenance
{
	LABEL		[menu_interface_maintenance];
	ITEMS
	{
		trans1_device_calib_date,
		trans1_device_config_date,
		trans1_valve_maintenance_date
	}
}

MENU Tab_s_interface_simulate
{
	LABEL		[menu_interface_simulate];
	ITEMS
	{
		func1_simulation_enabled			(READ_ONLY),
		func1_simulate_value				(READ_ONLY),
		func1_simulate_status_quality		(READ_ONLY),
		func1_simulate_status_limit			(READ_ONLY)
	}
}

MENU Tab_s_certificates
{
	LABEL		[menu_certificates];
	ITEMS
	{
		phys_device_certification
	}
}


/*******************************************************************************/
/*****	Table: Maintenance  ****************************************************/
/*******************************************************************************/

MENU Table_Main_Maintenance
{
	LABEL	DEVICE_TYPE_STR;
	ITEMS
	{
		Tab_m_ident
	}
}

MENU Tab_m_ident
{
	LABEL		[menu_ident];

	ITEMS
	{
		Tab_m_ident_opunit,
		Tab_m_ident_device
	}
}

MENU Tab_m_ident_opunit
{
	LABEL		[menu_ident_opunit];
	ITEMS
	{
		phys_tag_desc		(READ_ONLY),
		phys_descriptor,	
		phys_message	
	}
}

MENU Tab_m_ident_device
{
	LABEL		[menu_ident_device];
	ITEMS
	{
		Tab_m_ident_device_positioner,
		Tab_m_ident_device_actuator,
		Tab_m_ident_device_valve
	}
}

MENU Tab_m_ident_device_positioner
{
	LABEL		[menu_ident_device_positioner];
	ITEMS
	{
		phys_device_man_id,
		phys_device_id,
		phys_software_rev,
		phys_hardware_rev,
		phys_device_ser_num,
		device_pcb_sn,
		phys_install_date			(READ_ONLY),
		phys_blk_profile_rev,
		phys_ident_number			(READ_ONLY),
		Tab_st_rev
	}
}

MENU Tab_m_ident_device_actuator
{
	LABEL		[menu_ident_device_actuator];
	ITEMS
	{
		trans1_actuator_man				(READ_ONLY),
		trans1_actuator_type			(READ_ONLY),
		act_type						(READ_ONLY),
		trans1_actuator_action			(READ_ONLY),
		trans1_actuator_serial_number	(READ_ONLY)
	}
}

MENU Tab_m_ident_device_valve
{
	LABEL		[menu_ident_device_valve];
	ITEMS
	{
		trans1_valve_man				(READ_ONLY),
		trans1_valve_type				(READ_ONLY),
		trans1_valve_serial_number	(READ_ONLY)	
	}
}


/*******************************************************************************/
/*****	Communication Error Handling  ******************************************/
/*******************************************************************************/

VARIABLE CommError_0000_009F
{
	LABEL		[comm_err_dp_error_reserved];
	HELP		[comm_err_dp_error_reserved_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00A0_00A0
{
	LABEL		[comm_err_dp_read_error];
	HELP		[comm_err_dp_read_error_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00A1_00A1
{
	LABEL		[comm_err_dp_write_error];
	HELP		[comm_err_dp_write_error_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00A2_00A2
{
	LABEL		[comm_err_dp_module_failure];
	HELP		[comm_err_dp_module_failure_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00A3_00A7
{
	LABEL		[comm_err_dp_application_reserved];
	HELP		[comm_err_dp_application_reserved_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00A8_00A8
{
	LABEL		[comm_err_dp_version_conflict];
	HELP		[comm_err_dp_version_conflict_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00A9_00A9
{
	LABEL		[comm_err_dp_feature_not_supported];
	HELP		[comm_err_dp_feature_not_supported_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00AA_00AF
{
	LABEL		[comm_err_dp_application_user_specific];
	HELP		[comm_err_dp_application_user_specific_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00B0_00B0
{
	LABEL		[comm_err_dp_invalid_index];
	HELP		[comm_err_dp_invalid_index_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00B1_00B1
{
	LABEL		[comm_err_dp_write_length_error];
	HELP		[comm_err_dp_write_length_error_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00B2_00B2
{
	LABEL		[comm_err_dp_invalid_slot];
	HELP		[comm_err_dp_invalid_slot_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00B3_00B3
{
	LABEL		[comm_err_dp_type_conflict];
	HELP		[comm_err_dp_type_conflict_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00B4_00B4
{
	LABEL		[comm_err_dp_invalid_area];
	HELP		[comm_err_dp_invalid_area_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00B5_00B5
{
	LABEL		[comm_err_dp_state_conflict];
	HELP		[comm_err_dp_state_conflict_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00B6_00B6
{
	LABEL		[comm_err_dp_access_denied];
	HELP		[comm_err_dp_access_denied_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00B7_00B7
{
	LABEL		[comm_err_dp_invalid_range];
	HELP		[comm_err_dp_invalid_range_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00B8_00B8
{
	LABEL		[comm_err_dp_invalid_parameter];
	HELP		[comm_err_dp_invalid_parameter_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00B9_00B9
{
	LABEL		[comm_err_dp_invalid_type];
	HELP		[comm_err_dp_invalid_type_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00BA_00BF
{
	LABEL		[comm_err_dp_access_user_specific];
	HELP		[comm_err_dp_access_user_specific_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00C0_00C0
{
	LABEL		[comm_err_dp_read_constrain_conflict];
	HELP		[comm_err_dp_read_constrain_conflict_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00C1_00C1
{
	LABEL		[comm_err_dp_write_constrain_conflict];
	HELP		[comm_err_dp_write_constrain_conflict_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00C2_00C2
{
	LABEL		[comm_err_dp_resource_busy];
	HELP		[comm_err_dp_resource_busy_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00C3_00C3
{
	LABEL		[comm_err_dp_resource_unavailable];
	HELP		[comm_err_dp_resource_unavailable_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00C4_00C7
{
	LABEL		[comm_err_dp_resource_reserved];
	HELP		[comm_err_dp_resource_reserved_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00C8_00CF
{
	LABEL		[comm_err_dp_recource_user_specific];
	HELP		[comm_err_dp_recource_user_specific_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_00D0_00FF
{
	LABEL		[comm_err_dp_user_specific];
	HELP		[comm_err_dp_user_specific_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [ignore]	},
		{ 1, [check]	}
	}
}

VARIABLE CommError_ShowIgnoredErrors
{
	LABEL		[comm_show_ignored_errors];
	HELP		[comm_show_ignored_errors_help];
	CLASS		LOCAL;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	1;
		{ 0, [comm_show_ignored_errors_NOT_SHOW]	},
		{ 1, [comm_show_ignored_errors_SHOW]		}
	}
}

VARIABLE CommError_Delay_Read
{
	LABEL		[comm_delay_read];
	HELP		[comm_delay_read_help];
	CLASS		LOCAL;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE	0;
	}
	CONSTANT_UNIT	[msec];
}

VARIABLE CommError_Delay_Write
{
	LABEL		[comm_delay_write];
	HELP		[comm_delay_write_help];
	CLASS		LOCAL;
	TYPE		UNSIGNED_INTEGER (4)
	{
		DEFAULT_VALUE	0;
	}
	CONSTANT_UNIT	[msec];
}


MENU Menu_CommError
{
	LABEL	" ";
	ITEMS
	{
		CommError_0000_009F,			/* DP Error Reserved							*/
		CommError_00A0_00A0,			/* Application: DP Read Error					*/
		CommError_00A1_00A1,			/* Application: DP Write Error					*/
		CommError_00A2_00A2,			/* Application: DP Module Failure				*/
		CommError_00A3_00A7,			/* Application: DP Application Reserved			*/
		CommError_00A8_00A8,			/* Application: DP Version Conflict				*/
		CommError_00A9_00A9,			/* Application: DP Feature Not Supported		*/
		CommError_00AA_00AF,			/* Application:	DP Application User Specific	*/
		CommError_00B0_00B0,			/* Access:		DP Invalid Index				*/
		CommError_00B1_00B1,			/* Access:		DP Write Length Error			*/
		CommError_00B2_00B2,			/* Access:		DP Invalid Slot					*/
		CommError_00B3_00B3,			/* Access:		DP Type Conflict				*/
		CommError_00B4_00B4,			/* Access:		DP Invalid Area					*/			
		CommError_00B5_00B5,			/* Access:		DP State Conflict				*/			
		CommError_00B6_00B6,			/* Access:		DP Access Denied				*/			
		CommError_00B7_00B7,			/* Access:		DP Invalid Range				*/			
		CommError_00B8_00B8,			/* Access:		DP Invalid Parameter			*/			
		CommError_00B9_00B9,			/* Access:		DP Invalid Type					*/			
		CommError_00BA_00BF,			/* Access:		DP Access User Specific			*/			
		CommError_00C0_00C0,			/* Resource:	DP Read Constrain Conflict		*/
		CommError_00C1_00C1,			/* Resource:	DP Write Constrain Conflict		*/
		CommError_00C2_00C2,			/* Resource:	DP Resource Busy				*/
		CommError_00C3_00C3,			/* Resource:	DP Resource unavailable			*/
		CommError_00C4_00C7,			/* Resource:	DP Resource Reserved			*/
		CommError_00C8_00CF,			/* Resource:	DP Recource User Specific		*/
		CommError_00D0_00FF				/* DP User Specific								*/
	}
}

MENU Menu_CommError_Delay
{
	LABEL	" ";
	ITEMS
	{
		CommError_Delay_Read,
		CommError_Delay_Write
	}
}


MENU OfflineDialog_CommErrorHandling
{
	LABEL 	[menu_dialog_error_handling];
	ITEMS
	{
		Page_CommError_General,
		Page_CommError_Application,
		Page_CommError_Access,
		Page_CommError_Resource,
		Page_CommError_Other
	}
}

MENU Page_CommError_General
{
	LABEL 	[menu_dialog_general];
	ITEMS
	{
		CommError_Delay_Read,
		CommError_Delay_Write,
		CommError_ShowIgnoredErrors,
		CommError_DefaultHandling,
		CommError_CheckAllErrors,
		CommError_IgnoreAllErrors
	}
}

MENU Page_CommError_Application
{
	LABEL 	[menu_dialog_error_handling_application];
	ITEMS
	{
		CommError_00A0_00A0,	/* Application: DP Read Error					*/
		CommError_00A1_00A1,	/* Application: DP Write Error					*/
		CommError_00A2_00A2,	/* Application: DP Module Failure				*/
		CommError_00A3_00A7,	/* Application: DP Application Reserved			*/
		CommError_00A8_00A8,	/* Application: DP Version Conflict				*/
		CommError_00A9_00A9,	/* Application: DP Feature Not Supported		*/
		CommError_00AA_00AF		/* Application:	DP Application User Specific	*/
	}
}

MENU Page_CommError_Access
{
	LABEL 	[menu_dialog_error_handling_access];
	ITEMS
	{
		CommError_00B0_00B0,	/* Access:		DP Invalid Index				*/
		CommError_00B1_00B1,	/* Access:		DP Write Length Error			*/
		CommError_00B2_00B2,	/* Access:		DP Invalid Slot					*/
		CommError_00B3_00B3,	/* Access:		DP Type Conflict				*/
		CommError_00B4_00B4,	/* Access:		DP Invalid Area					*/			
		CommError_00B5_00B5,	/* Access:		DP State Conflict				*/			
		CommError_00B6_00B6,	/* Access:		DP Access Denied				*/			
		CommError_00B7_00B7,	/* Access:		DP Invalid Range				*/			
		CommError_00B8_00B8,	/* Access:		DP Invalid Parameter			*/			
		CommError_00B9_00B9,	/* Access:		DP Invalid Type					*/			
		CommError_00BA_00BF		/* Access:		DP Access User Specific			*/			
	}
}

MENU Page_CommError_Resource
{
	LABEL 	[menu_dialog_error_handling_resource];
	ITEMS
	{
		CommError_00C0_00C0,	/* Resource:	DP Read Constrain Conflict		*/
		CommError_00C1_00C1,	/* Resource:	DP Write Constrain Conflict		*/
		CommError_00C2_00C2,	/* Resource:	DP Resource Busy				*/
		CommError_00C3_00C3,	/* Resource:	DP Resource unavailable			*/
		CommError_00C4_00C7,	/* Resource:	DP Resource Reserved			*/
		CommError_00C8_00CF		/* Resource:	DP Recource User Specific		*/
	}
}

MENU Page_CommError_Other
{
	LABEL 	[menu_dialog_error_handling_other];
	ITEMS
	{
		CommError_0000_009F,
		CommError_00D0_00FF
	}
}

METHOD	CommError_IgnoreAllErrors
{
	LABEL 		[comm_ignore_all_errors];
	HELP		[comm_ignore_all_errors_help];
	DEFINITION
	{
		iassign(CommError_0000_009F, 0);	/* DP Error Reserved							*/
		iassign(CommError_00A0_00A0, 0);	/* Application: DP Read Error					*/
		iassign(CommError_00A1_00A1, 0);	/* Application: DP Write Error					*/
		iassign(CommError_00A2_00A2, 0);	/* Application: DP Module Failure				*/
		iassign(CommError_00A3_00A7, 0);	/* Application: DP Application Reserved			*/
		iassign(CommError_00A8_00A8, 0);	/* Application: DP Version Conflict				*/
		iassign(CommError_00A9_00A9, 0);	/* Application: DP Feature Not Supported		*/
		iassign(CommError_00AA_00AF, 0);	/* Application:	DP Application User Specific	*/
		iassign(CommError_00B0_00B0, 0);	/* Access:		DP Invalid Index				*/
		iassign(CommError_00B1_00B1, 0);	/* Access:		DP Write Length Error			*/
		iassign(CommError_00B2_00B2, 0);	/* Access:		DP Invalid Slot					*/
		iassign(CommError_00B3_00B3, 0);	/* Access:		DP Type Conflict				*/
		iassign(CommError_00B4_00B4, 0);	/* Access:		DP Invalid Area					*/			
		iassign(CommError_00B5_00B5, 0);	/* Access:		DP State Conflict				*/			
		iassign(CommError_00B6_00B6, 0);	/* Access:		DP Access Denied				*/			
		iassign(CommError_00B7_00B7, 0);	/* Access:		DP Invalid Range				*/			
		iassign(CommError_00B8_00B8, 0);	/* Access:		DP Invalid Parameter			*/			
		iassign(CommError_00B9_00B9, 0);	/* Access:		DP Invalid Type					*/			
		iassign(CommError_00BA_00BF, 0);	/* Access:		DP Access User Specific			*/			
		iassign(CommError_00C0_00C0, 0);	/* Resource:	DP Read Constrain Conflict		*/
		iassign(CommError_00C1_00C1, 0);	/* Resource:	DP Write Constrain Conflict		*/
		iassign(CommError_00C2_00C2, 0);	/* Resource:	DP Resource Busy				*/
		iassign(CommError_00C3_00C3, 0);	/* Resource:	DP Resource unavailable			*/
		iassign(CommError_00C4_00C7, 0);	/* Resource:	DP Resource Reserved			*/
		iassign(CommError_00C8_00CF, 0);	/* Resource:	DP Recource User Specific		*/
		iassign(CommError_00D0_00FF, 0);	/* DP User Specific								*/
	}
}

METHOD	CommError_CheckAllErrors
{
	LABEL 		[comm_check_all_errors];
	HELP		[comm_check_all_errors_help];
	DEFINITION
	{
		iassign(CommError_0000_009F, 1);	/* DP Error Reserved							*/
		iassign(CommError_00A0_00A0, 1);	/* Application: DP Read Error					*/
		iassign(CommError_00A1_00A1, 1);	/* Application: DP Write Error					*/
		iassign(CommError_00A2_00A2, 1);	/* Application: DP Module Failure				*/
		iassign(CommError_00A3_00A7, 1);	/* Application: DP Application Reserved			*/
		iassign(CommError_00A8_00A8, 1);	/* Application: DP Version Conflict				*/
		iassign(CommError_00A9_00A9, 1);	/* Application: DP Feature Not Supported		*/
		iassign(CommError_00AA_00AF, 1);	/* Application:	DP Application User Specific	*/
		iassign(CommError_00B0_00B0, 1);	/* Access:		DP Invalid Index				*/
		iassign(CommError_00B1_00B1, 1);	/* Access:		DP Write Length Error			*/
		iassign(CommError_00B2_00B2, 1);	/* Access:		DP Invalid Slot					*/
		iassign(CommError_00B3_00B3, 1);	/* Access:		DP Type Conflict				*/
		iassign(CommError_00B4_00B4, 1);	/* Access:		DP Invalid Area					*/			
		iassign(CommError_00B5_00B5, 1);	/* Access:		DP State Conflict				*/			
		iassign(CommError_00B6_00B6, 1);	/* Access:		DP Access Denied				*/			
		iassign(CommError_00B7_00B7, 1);	/* Access:		DP Invalid Range				*/			
		iassign(CommError_00B8_00B8, 1);	/* Access:		DP Invalid Parameter			*/			
		iassign(CommError_00B9_00B9, 1);	/* Access:		DP Invalid Type					*/			
		iassign(CommError_00BA_00BF, 1);	/* Access:		DP Access User Specific			*/			
		iassign(CommError_00C0_00C0, 1);	/* Resource:	DP Read Constrain Conflict		*/
		iassign(CommError_00C1_00C1, 1);	/* Resource:	DP Write Constrain Conflict		*/
		iassign(CommError_00C2_00C2, 1);	/* Resource:	DP Resource Busy				*/
		iassign(CommError_00C3_00C3, 1);	/* Resource:	DP Resource unavailable			*/
		iassign(CommError_00C4_00C7, 1);	/* Resource:	DP Resource Reserved			*/
		iassign(CommError_00C8_00CF, 1);	/* Resource:	DP Recource User Specific		*/
		iassign(CommError_00D0_00FF, 1);	/* DP User Specific								*/
	}
}

METHOD	CommError_DefaultHandling
{
	LABEL 		[comm_default_handling];
	HELP		[comm_default_handling_help];
	DEFINITION
	{
		lassign(CommError_Delay_Read,  0);	/* Delay after Read Command						*/
		lassign(CommError_Delay_Write, 0);	/* Delay after Write Command					*/
		iassign(CommError_0000_009F, 1);	/* DP Error Reserved							*/
		iassign(CommError_00A0_00A0, 1);	/* Application: DP Read Error					*/
		iassign(CommError_00A1_00A1, 1);	/* Application: DP Write Error					*/
		iassign(CommError_00A2_00A2, 1);	/* Application: DP Module Failure				*/
		iassign(CommError_00A3_00A7, 1);	/* Application: DP Application Reserved			*/
		iassign(CommError_00A8_00A8, 1);	/* Application: DP Version Conflict				*/
		iassign(CommError_00A9_00A9, 1);	/* Application: DP Feature Not Supported		*/
		iassign(CommError_00AA_00AF, 1);	/* Application:	DP Application User Specific	*/
		iassign(CommError_00B0_00B0, 0);	/* Access:		DP Invalid Index				*/
		iassign(CommError_00B1_00B1, 1);	/* Access:		DP Write Length Error			*/
		iassign(CommError_00B2_00B2, 0);	/* Access:		DP Invalid Slot					*/
		iassign(CommError_00B3_00B3, 1);	/* Access:		DP Type Conflict				*/
		iassign(CommError_00B4_00B4, 1);	/* Access:		DP Invalid Area					*/			
		iassign(CommError_00B5_00B5, 0);	/* Access:		DP State Conflict				*/			
		iassign(CommError_00B6_00B6, 1);	/* Access:		DP Access Denied				*/			
		iassign(CommError_00B7_00B7, 1);	/* Access:		DP Invalid Range				*/			
		iassign(CommError_00B8_00B8, 0);	/* Access:		DP Invalid Parameter			*/			
		iassign(CommError_00B9_00B9, 1);	/* Access:		DP Invalid Type					*/			
		iassign(CommError_00BA_00BF, 1);	/* Access:		DP Access User Specific			*/			
		iassign(CommError_00C0_00C0, 1);	/* Resource:	DP Read Constrain Conflict		*/
		iassign(CommError_00C1_00C1, 1);	/* Resource:	DP Write Constrain Conflict		*/
		iassign(CommError_00C2_00C2, 1);	/* Resource:	DP Resource Busy				*/
		iassign(CommError_00C3_00C3, 1);	/* Resource:	DP Resource unavailable			*/
		iassign(CommError_00C4_00C7, 1);	/* Resource:	DP Resource Reserved			*/
		iassign(CommError_00C8_00CF, 1);	/* Resource:	DP Recource User Specific		*/
		iassign(CommError_00D0_00FF, 1);	/* DP User Specific								*/
	}
}


/*******************************************************************************/
/*****	Methods		************************************************************/
/*******************************************************************************/

METHOD method_reset_msg
{
	LABEL		"Reset";
	DEFINITION
	{
		PUT_MESSAGE("ND800PA will disappear from the bus for a short time. After that, the PDM re-establishes the connection.");
	}
}


METHOD method_set
{
	LABEL		[transfer];
	HELP		[transfer_help];
	DEFINITION
	{
	}
}

METHOD method_cancel_test
{
	LABEL		"Cancel test";
	DEFINITION
	{
			iassign (test_start, 2);
			WriteCommand (write_valve_test);
	}
}

METHOD method_start_test
{
	LABEL		"Start test";
	DEFINITION
	{
		int choice;

		choice = SELECT_FROM_LIST([valve_test_warning],[yes_no_label]);
		if ( choice == 0 )
		{
			PUT_MESSAGE([vtest_warning]);
			iassign (test_start, 1);
			WriteCommand (write_valve_test);
		}
	}
}

METHOD method_start_self_calibration
{
	LABEL		[trans_act_self_calibration_cmd_START];
	DEFINITION
	{
		int choice;

		choice = SELECT_FROM_LIST([trans_act_self_calibration_warning],[yes_no_label]);
		if ( choice == 0 )
		{
			PUT_MESSAGE([self_cal_warning]);
			iassign (trans1_self_calibration_cmd, 2);
			WriteCommand (write_trans1_self_calibration_cmd);
		}
	}
}

METHOD 	method_cancel_self_calibration
{
	LABEL		[trans_act_self_calibration_cmd_CANCEL];
	DEFINITION
	{
		iassign(action_id,ID_POS_CAL); 
		iassign(action_ctrl,CTRL_CANCEL);
		WriteCommand(write_vc_action);
		DELAY(CAL_TIMEOUT,[travel_cal_cancel]);
		ReadCommand(read_vc_action);

		if (action_status == STAT_CANCELED)
		{
			PUT_MESSAGE([travel_cal_cancel_ok]);
		} else {
			PUT_MESSAGE([cancel_not_successfull]);
		}
	}
}

METHOD 	method_position_sensor_cal
{
	LABEL		[method_position_sensor_cal_label];
	DEFINITION
	{
		float fvalue;
		int choice;

		choice = SELECT_FROM_LIST([pos_continue], [yes_no_label]);
		if ( choice == 0 )
		{
			fvalue = 50;
			choice = GET_LOCAL_VAR_VALUE([pos_value],fvalue);
			if (choice == -1) p_abort;
			while (fvalue < 0 || fvalue > 100)
			{
				PUT_MESSAGE([pos_range]);
				choice = GET_LOCAL_VAR_VALUE([pos_again],fvalue);
				if (choice == -1) p_abort;
			}

			iassign(action_id,ID_POS_BIAS); 
			iassign(action_ctrl,CTRL_START);
			fassign(data2,0.9*fvalue+10);
			fassign(data3,110);
			fassign(data4,0.6*fvalue+20);
			WriteCommand(write_vc_action);
			DELAY(CAL_TIMEOUT,[pos_bias]);
			ReadCommand(read_vc_action);
			
			if (action_status == STAT_SUCCESFULL)
			{
				PUT_MESSAGE([pos_bias_ok]);
			} else {
				PUT_MESSAGE([op_not_successfull]);
			}
		}
	}
}

METHOD 	method_pressure_sensor_cal
{
	LABEL		[method_pressure_sensor_cal_label];
	DEFINITION
	{
		float fvalue;
		int choice;

		choice = SELECT_FROM_LIST([press_continue], [yes_no_label]);
		if ( choice == 0 )
		{
			PUT_MESSAGE([press_release]);

			iassign(action_id,ID_PRES_ZERO); 
			iassign(action_ctrl,CTRL_START);
			WriteCommand(write_vc_action);
			DELAY(CAL_TIMEOUT,[pres_setting]);			
			ReadCommand(read_vc_action);
			
			if (action_status == STAT_SUCCESFULL)
			{
				PUT_MESSAGE([press_zero_ok]);
			} else {
				PUT_MESSAGE([op_not_successfull]);
				p_abort;
			}
		} else {
			p_abort;
		}
		
		choice = SELECT_FROM_LIST([press_connect], [next_cancel_label]);
		if ( choice == 0 )
		{
			fvalue = 5;
			choice = GET_LOCAL_VAR_VALUE([press_value],fvalue);
			if (choice == -1) p_abort;
			while (fvalue < 0 || fvalue > 1000)
			{
				PUT_MESSAGE([press_range]);
				choice = GET_LOCAL_VAR_VALUE([press_value],fvalue);
				if (choice == -1) p_abort;
			}
			PUT_MESSAGE([move_warning]);

			iassign(action_id,ID_PRES_SPAN); 
			iassign(action_ctrl,CTRL_START);
			fassign(data2,fvalue);
			WriteCommand(write_vc_action);
			
			DELAY(CAL_POLL_TIME,[press_span]);
			ReadCommand(read_vc_action);

			while (action_status == STAT_INITIALIZING || action_status == STAT_RUNNING)
			{
				DELAY(CAL_POLL_TIME,[press_span]);
				ReadCommand(read_vc_action);
			}
			
			if (action_status == STAT_SUCCESFULL)
			{
				PUT_MESSAGE([press_span_ok]);
			} else {
				PUT_MESSAGE([op_not_successfull]);
			}
		}		
	}
}

METHOD 	method_temperature_measurement_calibration
{
	LABEL		[temperature_measurement_calibration_label];
	DEFINITION
	{
		float fvalue;
		int choice;

		fvalue = 25;
		choice = GET_LOCAL_VAR_VALUE([give_temp_value],fvalue);
		if (choice == -1) p_abort;
		while (fvalue < -40 || fvalue > 85)
		{
			PUT_MESSAGE([temp_range]);
			choice = GET_LOCAL_VAR_VALUE([give_temp_value],fvalue);
			if (choice == -1) p_abort;
		}

		iassign(action_id,ID_TEMP); 
		iassign(action_ctrl,CTRL_START);
		fassign(data2,fvalue);
		WriteCommand(write_vc_action);
		DELAY(CAL_TIMEOUT,[temp_cal_msg]);
		ReadCommand(read_vc_action);

		if (action_status == STAT_SUCCESFULL)
		{
			PUT_MESSAGE([temp_cal_ok]);
		} else {
			PUT_MESSAGE([op_not_successfull]);
		}
	}
}


METHOD method_set_status_limit
{
	CLASS		INPUT;
	DEFINITION
	{
		int	quality;
		int block_mode;			/* !!! temp.: bis Methoden mit Aufrufparametern funktionieren !!! */

		quality = ivar_value(func1_setpoint_status_quality);
		if ((quality == 0x20) || (quality == 0x30))
			iassign(func1_setpoint_status_limit, 0);

		quality = ivar_value(func1_rcas_in_status_quality);
		if ((quality == 0x20) || (quality == 0x30))
			iassign(func1_rcas_in_status_limit, 0);

		quality = ivar_value(func1_simulate_status_quality);
		if ((quality == 0x20) || (quality == 0x30))
			iassign(func1_simulate_status_limit, 0);

		block_mode	= ivar_value(func1_target_mode);
		quality		= ivar_value(func1_out_status_quality);
		if ((block_mode == BLOCK_MODE_MAN) && ((quality == 0x20) || (quality == 0x30)))
			iassign(func1_out_status_limit, 0);
	}
}


METHOD method_reset_checkback
{
	LABEL		[trans_act_self_calibration_cmd_RESET];
	HELP		[trans_act_self_calibration_cmd_RESET_help];
	DEFINITION
	{
	}
}

/***********************************************************************/
/*****	Commands  ******************************************************/
/***********************************************************************/

MENU upload_variables
{
	LABEL		[menu_load_to_device];
	ITEMS
	{
	/* PHYSICAL BLOCK */
		phys_tag_desc,						
		phys_descriptor,
		phys_message,
		phys_install_date,
		phys_ident_number

	/* TRANDSDUCER BLOCK */
		trans1_setp_cutoff_dec,
		trans1_setp_cutoff_inc,
		trans1_setp_cutoff_enable,
		trans1_travel_limit_lower_value,
		trans1_travel_limit_upper_value,
		trans1_lin_type,
		trans1_travel_rate_dec,
		trans1_travel_rate_inc,
		trans1_device_calib_date,
		trans1_device_config_date,
		trans1_valve_maintenance_date,
		trans1_actuator_man,
		trans1_actuator_serial_number,
		trans1_valve_man,
		trans1_valve_type,
		trans1_valve_serial_number,
		trans1_actuator_action,
		limit_switches,
		supply_pressure,
		pos_sensor_rot,
		trans1_servo_gain,
		servo_param_d,
		servo_param_b,
		act_type,
		dead_angle_comp,
		fail_action,
		travel_deviation_warning_limit,
		travel_deviation_alarm_limit,
		load_factor_warning_limit,
		load_factor_alarm_limit,
		valve_travel_counters_full_strokes_warning_limit,
		valve_travel_counters_reversals_warning_limit,
		act_travel_counters_full_strokes_warning_limit,
		act_travel_counters_reversals_warning_limit
		

	/* FUNCTION BLOCK */
		func1_batch_id, 
		func1_batch_unit, 
		func1_batch_operation, 
		func1_batch_phase,
		func1_fsafe_type,
		func1_fsafe_time,
		func1_fsafe_value,
		func1_increase_close,
		func1_pv_lower_range_value,
		func1_pv_upper_range_value,
		func1_pv_unit,
		func1_out_lower_range_value,
		func1_out_upper_range_value,
		func1_out_unit
	}
}


/***********************************************************************/
/* Commands - Physical Block										   */
/***********************************************************************/

COMMAND read_phys_blk
{
	BLOCK physical_block;
	INDEX 0;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_blk_reserve, phys_blk_object, phys_blk_parent_class, phys_blk_class,
			phys_blk_dd_reference, phys_blk_dd_rev, phys_blk_profile, phys_blk_profile_rev,
			phys_blk_execution_time, phys_blk_num_parameters, phys_blk_index_view_1,
			phys_blk_num_view_lists
		}
	}
}

COMMAND read_phys_st_rev
{
	BLOCK physical_block;
	INDEX 1;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_st_rev
		}
	}
}

COMMAND read_phys_tag_desc
{
	BLOCK physical_block;
	INDEX 2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_tag_desc
		}
	}
}

COMMAND write_phys_tag_desc
{
	BLOCK physical_block;
	INDEX 2;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_tag_desc
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_strategy
{
	BLOCK physical_block;
	INDEX 3;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_strategy
		}
	}
}

COMMAND write_phys_strategy
{
	BLOCK physical_block;
	INDEX 3;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_strategy
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_alert_key
{
	BLOCK physical_block;
	INDEX 4;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_alert_key
		}
	}
}

COMMAND write_phys_alert_key
{
	BLOCK physical_block;
	INDEX 4;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_alert_key
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_target_mode
{
	BLOCK physical_block;
	INDEX 5;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_target_mode
		}
	}
}

COMMAND write_phys_target_mode
{
	BLOCK physical_block;
	INDEX 5;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		 	phys_target_mode
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_mode
{
	BLOCK physical_block;
	INDEX 6;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			 phys_actual_mode, phys_permitted_mode, phys_normal_mode
		}
	}
}

COMMAND read_phys_alarm
{
	BLOCK physical_block;
	INDEX 7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_current_state_alarm_sum, phys_unacknowledged_state_alarm_sum,
			phys_unreported_state_alarm_sum, phys_disabled_state_alarm_sum
		}
	}
}

COMMAND read_phys_software_rev
{
	BLOCK physical_block;
	INDEX 8;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_software_rev
		}
	}
}

COMMAND read_phys_hardware_rev
{
	BLOCK physical_block;
	INDEX 9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_hardware_rev
		}
	}
}

COMMAND read_phys_device_man_id
{
	BLOCK physical_block;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_device_man_id
		}
	}
}

COMMAND read_phys_device_id
{
	BLOCK physical_block;
	INDEX 11;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_device_id
		}
	}
}

COMMAND read_phys_device_ser_num
{
	BLOCK physical_block;
	INDEX 12;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_device_ser_num
		}
	}
}

COMMAND read_phys_diagnosis
{
	BLOCK physical_block;
	INDEX 13;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_diagnosis
		}
	}
}

COMMAND read_phys_diagnosis_extension
{
	BLOCK physical_block;
	INDEX 14;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_diagnosis_extension,
			phys_diagnosis_extension_rest
		}
	}
}

COMMAND read_phys_diagnosis_mask
{
	BLOCK physical_block;
	INDEX 15;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_diagnosis_mask
		}
	}
}

COMMAND read_phys_diagnosis_extension_mask
{
	BLOCK physical_block;
	INDEX 16;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_diagnosis_extension_mask,
			phys_diagnosis_extension_mask_rest
		}
	}
}

COMMAND read_phys_device_certification
{
	BLOCK physical_block;
	INDEX 17;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_device_certification
		}
	}
}

COMMAND read_phys_write_locking
{
	BLOCK physical_block;
	INDEX 18;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_write_locking
		}
	}
}

COMMAND write_phys_write_locking
{
	BLOCK physical_block;
	INDEX 18;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_write_locking
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_factory_reset
{
	BLOCK physical_block;
	INDEX 19;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_factory_reset
		}
	}
}

COMMAND write_phys_factory_reset
{
	BLOCK physical_block;
	INDEX 19;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_factory_reset
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_descriptor
{
	BLOCK physical_block;
	INDEX 20;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_descriptor
		}
	}
}

COMMAND write_phys_descriptor
{
	BLOCK physical_block;
	INDEX 20;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_descriptor
		}
		REPLY
		{
		}
	}
}

COMMAND read_pw
{
	BLOCK physical_block;
	INDEX 21;
	OPERATION  READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			pw_1,
			pw_2,
			pw_3,
			pw_4,
			pw_5,
			pw_6,
			pw_7
		}
	}
}

COMMAND read_phys_message
{
	BLOCK physical_block;
	INDEX 21;
	OPERATION  READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_message
		}
	}
}

COMMAND write_phys_message
{
	BLOCK physical_block;
	INDEX 21;
	OPERATION  WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_message
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_install_date
{
	BLOCK physical_block;
	INDEX 22;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_install_date
		}
	}
}

COMMAND write_phys_install_date
{
	BLOCK physical_block;
	INDEX 22;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_install_date
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_local_operation_enable
{
	BLOCK physical_block;
	INDEX 23;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_local_operation_enable
		}
	}
}

COMMAND write_phys_local_operation_enable
{
	BLOCK physical_block;
	INDEX 23;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_local_operation_enable
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_ident_number
{
	BLOCK physical_block;
	INDEX 24;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_ident_number
		}
	}
}

COMMAND write_phys_ident_number
{
	BLOCK physical_block;
	INDEX 24;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_ident_number
		}
		REPLY
		{
		}
	}
}

COMMAND read_phys_hw_write_protection
{
	BLOCK physical_block;
	INDEX 25;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_hw_write_protection
		}
	}
}

/***********************************************************************/
/* Commands - Transducer Block										   */
/***********************************************************************/

COMMAND read_trans1_blk
{
	BLOCK transducer_block_1;
	INDEX 0;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_blk_reserve, trans1_blk_object, trans1_blk_parent_class, trans1_blk_class,
			trans1_blk_dd_reference, trans1_blk_dd_rev, trans1_blk_profile, trans1_blk_profile_rev,
			trans1_blk_execution_time, trans1_blk_num_parameters, trans1_blk_index_view_1,
			trans1_blk_num_view_lists
		}
	}
}

COMMAND read_trans1_st_rev
{
	BLOCK transducer_block_1;
	INDEX 1;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_st_rev
		}
	}
}

COMMAND read_trans1_tag_desc
{
	BLOCK transducer_block_1;
	INDEX 2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_tag_desc
		}
	}
}

COMMAND write_trans1_tag_desc
{
	BLOCK transducer_block_1;
	INDEX 2;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_tag_desc
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_strategy
{
	BLOCK transducer_block_1;
	INDEX 3;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_strategy
		}
	}
}

COMMAND write_trans1_strategy
{
	BLOCK transducer_block_1;
	INDEX 3;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_strategy
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_alert_key
{
	BLOCK transducer_block_1;
	INDEX 4;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_alert_key
		}
	}
}

COMMAND write_trans1_alert_key
{
	BLOCK transducer_block_1;
	INDEX 4;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_alert_key
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_target_mode
{
	BLOCK transducer_block_1;
	INDEX 5;
	OPERATION  READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_target_mode
		}
	}
}

COMMAND write_trans1_target_mode
{
	BLOCK transducer_block_1;
	INDEX 5;
	OPERATION  WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_target_mode
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_mode
{
	BLOCK transducer_block_1;
	INDEX 6;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			 trans1_actual_mode, trans1_permitted_mode, trans1_normal_mode
		}
	}
}

COMMAND read_trans1_alarm
{
	BLOCK transducer_block_1;
	INDEX 7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_current_state_alarm_sum, trans1_unacknowledged_state_alarm_sum,
			trans1_unreported_state_alarm_sum, trans1_disabled_state_alarm_sum
		}
	}
}

COMMAND read_trans1_act_stroke_time_dec
{
	BLOCK transducer_block_1;
	INDEX 9;
	OPERATION READ;
	TRANSACTION						
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_act_stroke_time_dec
		}
	}
}

COMMAND read_trans1_act_stroke_time_inc
{
	BLOCK transducer_block_1;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_act_stroke_time_inc
		}
	}
}


COMMAND read_trans1_deadband
{
	BLOCK transducer_block_1;
	INDEX 22;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_deadband
		}
	}
}

COMMAND write_trans1_deadband
{
	BLOCK transducer_block_1;
	INDEX 22;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_deadband
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_device_calib_date
{
	BLOCK transducer_block_1;
	INDEX 23;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_device_calib_date
		}
	}
}

COMMAND write_trans1_device_calib_date
{
	BLOCK transducer_block_1;
	INDEX 23;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_device_calib_date
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_device_config_date
{
	BLOCK transducer_block_1;
	INDEX 24;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_device_config_date
		}
	}
}

COMMAND write_trans1_device_config_date
{
	BLOCK transducer_block_1;
	INDEX 24;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_device_config_date
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_lin_type
{
	BLOCK transducer_block_1;
	INDEX 25;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_lin_type
		}
	}
}

COMMAND write_trans1_lin_type
{
	BLOCK transducer_block_1;
	INDEX 25;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_lin_type
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_rated_travel
{
	BLOCK transducer_block_1;
	INDEX 32;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_rated_travel_value
		}
	}
}

COMMAND write_trans1_rated_travel
{
	BLOCK transducer_block_1;
	INDEX 32;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_rated_travel_value
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_self_calibration_cmd
{
	BLOCK transducer_block_1;
	INDEX 33;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_self_calibration_cmd	
		}
	}
}

COMMAND write_trans1_self_calibration_cmd
{
	BLOCK transducer_block_1;
	INDEX 33;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_self_calibration_cmd	
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_self_calibration_status
{
	BLOCK transducer_block_1;
	INDEX 34;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_self_calibration_status	
		}
	}
}

COMMAND read_trans1_servo_gain
{
	BLOCK transducer_block_1;
	INDEX 35;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_servo_gain
		}
	}
}

COMMAND write_trans1_servo_gain
{
	BLOCK transducer_block_1;
	INDEX 35;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_servo_gain	
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans1_setp_cutoff_dec
{
	BLOCK transducer_block_1;
	INDEX 38;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_setp_cutoff_dec
		}
	}
}

COMMAND write_trans1_setp_cutoff_dec
{
	BLOCK transducer_block_1;
	INDEX 38;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_setp_cutoff_dec	
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_setp_cutoff_inc
{
	BLOCK transducer_block_1;
	INDEX 39;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_setp_cutoff_inc
		}
	}
}

COMMAND write_trans1_setp_cutoff_inc
{
	BLOCK transducer_block_1;
	INDEX 39;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_setp_cutoff_inc	
		}
		REPLY
		{
		}
	}
}



COMMAND read_trans1_travel_limit_low
{
	BLOCK transducer_block_1;
	INDEX 47;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_travel_limit_lower_value
		}
	}
}

COMMAND write_trans1_travel_limit_low
{
	BLOCK transducer_block_1;
	INDEX 47;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_travel_limit_lower_value
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_travel_limit_upper
{
	BLOCK transducer_block_1;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_travel_limit_upper_value
		}
	}
}

COMMAND write_trans1_travel_limit_upper
{
	BLOCK transducer_block_1;
	INDEX 48;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_travel_limit_upper_value
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_travel_rate_dec
{
	BLOCK transducer_block_1;
	INDEX 49;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_travel_rate_dec
		}
	}
}

COMMAND write_trans1_travel_rate_dec
{
	BLOCK transducer_block_1;
	INDEX 49;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_travel_rate_dec
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_travel_rate_inc
{
	BLOCK transducer_block_1;
	INDEX 50;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_travel_rate_inc
		}
	}
}

COMMAND write_trans1_travel_rate_inc
{
	BLOCK transducer_block_1;
	INDEX 50;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_travel_rate_inc
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_valve_maintenance_date
{
	BLOCK transducer_block_1;
	INDEX 51;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_valve_maintenance_date
		}
	}
}

COMMAND write_trans1_valve_maintenance_date
{
	BLOCK transducer_block_1;
	INDEX 51;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_valve_maintenance_date
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_positioning_value
{
	BLOCK transducer_block_1;
	INDEX 57;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_positioning_value,
			trans1_positioning_status_quality	<0xFC>,
			trans1_positioning_status_limit		<0x03>
		}
	}
}

COMMAND write_trans1_positioning_value
{
	BLOCK transducer_block_1;
	INDEX 57;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_positioning_value,
			trans1_positioning_status_quality	<0xFC>,
			trans1_positioning_status_limit		<0x03>
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_feedback_value
{
	BLOCK transducer_block_1;
	INDEX 58;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_feedback_value,
			trans1_feedback_status_quality	<0xFC>,
			trans1_feedback_status_limit	<0x03>
		}
	}
}

COMMAND read_trans1_valve_man
{
	BLOCK transducer_block_1;
	INDEX 59;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_valve_man
		}
	}
}

COMMAND write_trans1_valve_man
{
	BLOCK transducer_block_1;
	INDEX 59;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_valve_man
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_actuator_man
{
	BLOCK transducer_block_1;
	INDEX 60;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_actuator_man
		}
	}
}

COMMAND write_trans1_actuator_man
{
	BLOCK transducer_block_1;
	INDEX 60;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_actuator_man
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_valve_type
{
	BLOCK transducer_block_1;
	INDEX 61;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_valve_type
		}
	}
}

COMMAND write_trans1_valve_type
{
	BLOCK transducer_block_1;
	INDEX 61;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_valve_type
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_actuator_type
{
	BLOCK transducer_block_1;
	INDEX 62;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_actuator_type
		}
	}
}

COMMAND read_trans1_actuator_action
{
	BLOCK transducer_block_1;
	INDEX 63;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_actuator_action
		}
	}
}

COMMAND write_trans1_actuator_action
{
	BLOCK transducer_block_1;
	INDEX 63;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_actuator_action
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_valve_serial_number
{
	BLOCK transducer_block_1;
	INDEX 64;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_valve_serial_number
		}
	}
}

COMMAND write_trans1_valve_serial_number
{
	BLOCK transducer_block_1;
	INDEX 64;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_valve_serial_number
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_actuator_serial_number
{
	BLOCK transducer_block_1;
	INDEX 65;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_actuator_serial_number
		}
	}
}

COMMAND write_trans1_actuator_serial_number
{
	BLOCK transducer_block_1;
	INDEX 65;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_actuator_serial_number
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_additional_gear_ser_number
{
	BLOCK transducer_block_1;
	INDEX 66;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_additional_gear_ser_number
		}
	}
}

COMMAND write_trans1_additional_gear_ser_number
{
	BLOCK transducer_block_1;
	INDEX 66;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_additional_gear_ser_number
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_additional_gear_man
{
	BLOCK transducer_block_1;
	INDEX 67;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_additional_gear_man
		}
	}
}

COMMAND write_trans1_additional_gear_man
{
	BLOCK transducer_block_1;
	INDEX 67;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_additional_gear_man
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_additional_gear_id
{
	BLOCK transducer_block_1;
	INDEX 68;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_additional_gear_id
		}
	}
}

COMMAND write_trans1_additional_gear_id
{
	BLOCK transducer_block_1;
	INDEX 68;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_additional_gear_id
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_additional_gear_install_date
{
	BLOCK transducer_block_1;
	INDEX 69;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_additional_gear_install_date
		}
	}
}

COMMAND write_trans1_additional_gear_install_date
{
	BLOCK transducer_block_1;
	INDEX 69;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_additional_gear_install_date
		}
		REPLY
		{
		}
	}
}

/***********************************************************************/
/* Commands - Transducer Block - Manufacturer specific				   */
/***********************************************************************/

COMMAND read_device_pcb_sn
{
	BLOCK physical_block;
	INDEX 33;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			device_pcb_sn 
		}
	}
}

COMMAND read_softing_error_code
{
	BLOCK physical_block;
	INDEX 35;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			softing_error_code 
		}
	}
}

COMMAND read_servo_param_d 
{
	BLOCK transducer_block_1;
	INDEX 100;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			servo_param_d
		}
	}
}

COMMAND write_servo_param_d
{
	BLOCK transducer_block_1;
	INDEX 100;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			servo_param_d
		}
		REPLY
		{
		}
	}
}


COMMAND read_servo_param_b
{
	BLOCK transducer_block_1;
	INDEX 102;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			servo_param_b
		}
	}
}

COMMAND write_servo_param_b
{
	BLOCK transducer_block_1;
	INDEX 102;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			servo_param_b
		}
		REPLY
		{
		}
	}
}


COMMAND read_act_type
{
	BLOCK transducer_block_1;
	INDEX 104;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			act_type
		}
	}
}
COMMAND write_act_type
{
	BLOCK transducer_block_1;
	INDEX 104;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			act_type
		}
		REPLY
		{
		}
	}
}

COMMAND read_supply_pressure
{
	BLOCK transducer_block_1;
	INDEX 106;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			supply_pressure
		}
	}
}
COMMAND write_supply_pressure 
{
	BLOCK transducer_block_1;
	INDEX 106;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			supply_pressure
		}
		REPLY
		{
		}
	}
}


COMMAND read_fail_action
{
	BLOCK transducer_block_1;
	INDEX 108;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			fail_action
		}
	}
}
COMMAND write_fail_action 
{
	BLOCK transducer_block_1;
	INDEX 108;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			fail_action
		}
		REPLY
		{
		}
	}
}

COMMAND read_pos_sensor_rot
{
	BLOCK transducer_block_1;
	INDEX 110;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			pos_sensor_rot
		}
	}
}
COMMAND write_pos_sensor_rot  
{
	BLOCK transducer_block_1;
	INDEX 110;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			pos_sensor_rot
		}
		REPLY
		{
		}
	}
}

COMMAND read_dead_angle_comp 
{
	BLOCK transducer_block_1;
	INDEX 112;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			dead_angle_comp
		}
	}
}
COMMAND write_dead_angle_comp
{
	BLOCK transducer_block_1;
	INDEX 112;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		dead_angle_comp 
		}
		REPLY
		{
		}
	}
}

COMMAND read_act_pressure 
{
	BLOCK transducer_block_1;
	INDEX 120;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		   act_pressure
		}
	}
}

COMMAND read_dev_temperature 
{
	BLOCK transducer_block_1;
	INDEX 122;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		   dev_temperature
		}
	}
}


COMMAND read_operation_time	
{
	BLOCK transducer_block_1;
	INDEX 124;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		   operation_time
		}
	}
}

COMMAND read_travel_deviation_warning_limit	
{
	BLOCK transducer_block_1;
	INDEX 135;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		   travel_deviation_warning_limit
		}
	}
}

COMMAND warite_travel_deviation_warning_limit	
{
	BLOCK transducer_block_1;
	INDEX 135;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			travel_deviation_warning_limit
		}
		REPLY
		{
		}
	}
}

COMMAND read_travel_deviation_alarm_limit	
{
	BLOCK transducer_block_1;
	INDEX 136;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		   travel_deviation_alarm_limit
		}
	}
}

COMMAND write_travel_deviation_alarm_limit	
{
	BLOCK transducer_block_1;
	INDEX 136;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			travel_deviation_alarm_limit
		}
		REPLY
		{
		}
	}
}

COMMAND read_load_factor_warning_limit	
{
	BLOCK transducer_block_1;
	INDEX 143;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		   load_factor_warning_limit
		}
	}
}

COMMAND warite_load_factor_warning_limit	
{
	BLOCK transducer_block_1;
	INDEX 143;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			load_factor_warning_limit
		}
		REPLY
		{
		}
	}
}

COMMAND read_load_factor_alarm_limit	
{
	BLOCK transducer_block_1;
	INDEX 144;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		   load_factor_alarm_limit
		}
	}
}

COMMAND warite_load_factor_alarm_limit	
{
	BLOCK transducer_block_1;
	INDEX 144;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			load_factor_alarm_limit
		}
		REPLY
		{
		}
	}
}

COMMAND read_valve_travel_counters
{
	BLOCK transducer_block_1;
	INDEX 146;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		valve_travel_counters_full_strokes, 
		valve_travel_counters_full_strokes_warning_limit, 
		valve_travel_counters_reversals, 
		valve_travel_counters_reversals_warning_limit
		}
	}
}

COMMAND write_valve_travel_counters
{
	BLOCK transducer_block_1;
	INDEX 146;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		valve_travel_counters_full_strokes, 
		valve_travel_counters_full_strokes_warning_limit, 
		valve_travel_counters_reversals, 
		valve_travel_counters_reversals_warning_limit
		}
		REPLY
		{
		}
	}
}

COMMAND read_act_travel_counters 
{
	BLOCK transducer_block_1;
	INDEX 148;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		 act_travel_counters_full_strokes, 
		 act_travel_counters_full_strokes_warning_limit, 
		 act_travel_counters_reversals, 
		 act_travel_counters_reversals_warning_limit
		}
	}
}

COMMAND write_act_travel_counters 
{
	BLOCK transducer_block_1;
	INDEX 148;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			act_travel_counters_full_strokes, 
			act_travel_counters_full_strokes_warning_limit, 
			act_travel_counters_reversals, 
			act_travel_counters_reversals_warning_limit
		}
		REPLY
		{
		}
	}
}

COMMAND read_reset_diagnostics 
{
	BLOCK transducer_block_1;
	INDEX 150;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		   reset_diagnostics
		}
	}
}

COMMAND write_reset_diagnostics
{
	BLOCK transducer_block_1;
	INDEX 150;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			reset_diagnostics 
		}
		REPLY
		{
		}
	}
}

COMMAND read_pos_sensor_sn 
{
	BLOCK transducer_block_1;
	INDEX 164;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		   pos_sensor_sn 
		}
	}
}

COMMAND write_pos_sensor_sn 
{
	BLOCK transducer_block_1;
	INDEX 164;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			pos_sensor_sn 
		}
		REPLY
		{
		}
	}
}

COMMAND read_pos_sensor_temp_comp 
{
	BLOCK transducer_block_1;
	INDEX 168;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		   pos_sensor_temp_comp 
		}
	}
}

COMMAND write_pos_sensor_temp_comp
{
	BLOCK transducer_block_1;
	INDEX 168;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			pos_sensor_temp_comp 
		}
		REPLY
		{
		}
	}
}

COMMAND read_last_valve_test_settings
{
	BLOCK transducer_block_1;
	INDEX 154;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			last_test_type,
			last_test_starting_setpoint,
			last_test_loop_or_step_size,
			last_test_duration
		}
	}
}

COMMAND read_valve_test
{
	BLOCK transducer_block_1;
	INDEX 152;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			test_type,
			test_starting_setpoint,
			test_loop_or_step_size,
			test_duration,
			test_start
		}
	}
}

COMMAND write_valve_test
{
	BLOCK transducer_block_1;
	INDEX 152;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			test_type,
			test_starting_setpoint,
			test_loop_or_step_size,
			test_duration,
			test_start
		}
		REPLY
		{
		}
	}
}

COMMAND read_pos_sensor_temp_comp_min_table
{
	BLOCK transducer_block_1;
	INDEX 170;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			pos_sensor_temp_comp_min_table_1,
			pos_sensor_temp_comp_min_table_2,
			pos_sensor_temp_comp_min_table_3,
			pos_sensor_temp_comp_min_table_4,
			pos_sensor_temp_comp_min_table_5,
			pos_sensor_temp_comp_min_table_6,
			pos_sensor_temp_comp_min_table_7,
			pos_sensor_temp_comp_min_table_8,
			pos_sensor_temp_comp_min_table_9,
			pos_sensor_temp_comp_min_table_10,
			pos_sensor_temp_comp_min_table_11,
			pos_sensor_temp_comp_min_table_12,
			pos_sensor_temp_comp_min_table_13,
			pos_sensor_temp_comp_min_table_14,
			pos_sensor_temp_comp_min_table_15,
			pos_sensor_temp_comp_min_table_16,
			pos_sensor_temp_comp_min_table_17,
			pos_sensor_temp_comp_min_table_18,
			pos_sensor_temp_comp_min_table_19,
			pos_sensor_temp_comp_min_table_20,
			pos_sensor_temp_comp_min_table_21,
			pos_sensor_temp_comp_min_table_22,
			pos_sensor_temp_comp_min_table_23,
			pos_sensor_temp_comp_min_table_24,
			pos_sensor_temp_comp_min_table_25,
			pos_sensor_temp_comp_min_table_26
		}
	}
}

COMMAND write_pos_sensor_temp_comp_min_table
{
	BLOCK transducer_block_1;
	INDEX 170;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			pos_sensor_temp_comp_min_table_1,
			pos_sensor_temp_comp_min_table_2,
			pos_sensor_temp_comp_min_table_3,
			pos_sensor_temp_comp_min_table_4,
			pos_sensor_temp_comp_min_table_5,
			pos_sensor_temp_comp_min_table_6,
			pos_sensor_temp_comp_min_table_7,
			pos_sensor_temp_comp_min_table_8,
			pos_sensor_temp_comp_min_table_9,
			pos_sensor_temp_comp_min_table_10,
			pos_sensor_temp_comp_min_table_11,
			pos_sensor_temp_comp_min_table_12,
			pos_sensor_temp_comp_min_table_13,
			pos_sensor_temp_comp_min_table_14,
			pos_sensor_temp_comp_min_table_15,
			pos_sensor_temp_comp_min_table_16,
			pos_sensor_temp_comp_min_table_17,
			pos_sensor_temp_comp_min_table_18,
			pos_sensor_temp_comp_min_table_19,
			pos_sensor_temp_comp_min_table_20,
			pos_sensor_temp_comp_min_table_21,
			pos_sensor_temp_comp_min_table_22,
			pos_sensor_temp_comp_min_table_23,
			pos_sensor_temp_comp_min_table_24,
			pos_sensor_temp_comp_min_table_25,
			pos_sensor_temp_comp_min_table_26
		}
		REPLY
		{
		}
	}
}


COMMAND read_pos_sensor_temp_comp_max_table 
{
	BLOCK transducer_block_1;
	INDEX 172;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			pos_sensor_temp_comp_max_table_1,
			pos_sensor_temp_comp_max_table_2,
			pos_sensor_temp_comp_max_table_3,
			pos_sensor_temp_comp_max_table_4,
			pos_sensor_temp_comp_max_table_5,
			pos_sensor_temp_comp_max_table_6,
			pos_sensor_temp_comp_max_table_7,
			pos_sensor_temp_comp_max_table_8,
			pos_sensor_temp_comp_max_table_9,
			pos_sensor_temp_comp_max_table_10,
			pos_sensor_temp_comp_max_table_11,
			pos_sensor_temp_comp_max_table_12,
			pos_sensor_temp_comp_max_table_13,
			pos_sensor_temp_comp_max_table_14,
			pos_sensor_temp_comp_max_table_15,
			pos_sensor_temp_comp_max_table_16,
			pos_sensor_temp_comp_max_table_17,
			pos_sensor_temp_comp_max_table_18,
			pos_sensor_temp_comp_max_table_19,
			pos_sensor_temp_comp_max_table_20,
			pos_sensor_temp_comp_max_table_21,
			pos_sensor_temp_comp_max_table_22,
			pos_sensor_temp_comp_max_table_23,
			pos_sensor_temp_comp_max_table_24,
			pos_sensor_temp_comp_max_table_25,
			pos_sensor_temp_comp_max_table_26 
		}
	}
}

COMMAND write_pos_sensor_temp_comp_max_table 
{
	BLOCK transducer_block_1;
	INDEX 172;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			pos_sensor_temp_comp_max_table_1,
			pos_sensor_temp_comp_max_table_2,
			pos_sensor_temp_comp_max_table_3,
			pos_sensor_temp_comp_max_table_4,
			pos_sensor_temp_comp_max_table_5,
			pos_sensor_temp_comp_max_table_6,
			pos_sensor_temp_comp_max_table_7,
			pos_sensor_temp_comp_max_table_8,
			pos_sensor_temp_comp_max_table_9,
			pos_sensor_temp_comp_max_table_10,
			pos_sensor_temp_comp_max_table_11,
			pos_sensor_temp_comp_max_table_12,
			pos_sensor_temp_comp_max_table_13,
			pos_sensor_temp_comp_max_table_14,
			pos_sensor_temp_comp_max_table_15,
			pos_sensor_temp_comp_max_table_16,
			pos_sensor_temp_comp_max_table_17,
			pos_sensor_temp_comp_max_table_18,
			pos_sensor_temp_comp_max_table_19,
			pos_sensor_temp_comp_max_table_20,
			pos_sensor_temp_comp_max_table_21,
			pos_sensor_temp_comp_max_table_22,
			pos_sensor_temp_comp_max_table_23,
			pos_sensor_temp_comp_max_table_24,
			pos_sensor_temp_comp_max_table_25,
			pos_sensor_temp_comp_max_table_26
		}
		REPLY
		{
		}
	}
}

COMMAND read_last_valve_test_sp_or_time_table_I
{
	BLOCK transducer_block_1;
	INDEX 156;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			last_valve_test_sp_or_time_table_1,
			last_valve_test_sp_or_time_table_2, 
			last_valve_test_sp_or_time_table_3, 
			last_valve_test_sp_or_time_table_4, 
			last_valve_test_sp_or_time_table_5, 
			last_valve_test_sp_or_time_table_6, 
			last_valve_test_sp_or_time_table_7, 
			last_valve_test_sp_or_time_table_8, 
			last_valve_test_sp_or_time_table_9, 
			last_valve_test_sp_or_time_table_10,
			last_valve_test_sp_or_time_table_11,
			last_valve_test_sp_or_time_table_12,
			last_valve_test_sp_or_time_table_13,
			last_valve_test_sp_or_time_table_14,
			last_valve_test_sp_or_time_table_15,
			last_valve_test_sp_or_time_table_16,
			last_valve_test_sp_or_time_table_17,
			last_valve_test_sp_or_time_table_18,
			last_valve_test_sp_or_time_table_19,
			last_valve_test_sp_or_time_table_20,
			last_valve_test_sp_or_time_table_21,
			last_valve_test_sp_or_time_table_22,
			last_valve_test_sp_or_time_table_23,
			last_valve_test_sp_or_time_table_24,
			last_valve_test_sp_or_time_table_25
		}
	}
}

COMMAND read_last_valve_test_sp_or_time_table_II
{
	BLOCK transducer_block_1;
	INDEX 158;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			last_valve_test_sp_or_time_table_26,
			last_valve_test_sp_or_time_table_27,
			last_valve_test_sp_or_time_table_28,
			last_valve_test_sp_or_time_table_29,
			last_valve_test_sp_or_time_table_30,
			last_valve_test_sp_or_time_table_31,
			last_valve_test_sp_or_time_table_32,
			last_valve_test_sp_or_time_table_33,
			last_valve_test_sp_or_time_table_34,
			last_valve_test_sp_or_time_table_35,
			last_valve_test_sp_or_time_table_36,
			last_valve_test_sp_or_time_table_37,
			last_valve_test_sp_or_time_table_38,
			last_valve_test_sp_or_time_table_39,
			last_valve_test_sp_or_time_table_40,
			last_valve_test_sp_or_time_table_41,
			last_valve_test_sp_or_time_table_42,
			last_valve_test_sp_or_time_table_43,
			last_valve_test_sp_or_time_table_44,
			last_valve_test_sp_or_time_table_45,
			last_valve_test_sp_or_time_table_46,
			last_valve_test_sp_or_time_table_47,
			last_valve_test_sp_or_time_table_48,
			last_valve_test_sp_or_time_table_49,
			last_valve_test_sp_or_time_table_50
		}
	}
}


COMMAND read_last_valve_test_position_table_I
{
	BLOCK transducer_block_1;
	INDEX 160;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			last_valve_test_position_table_1,
			last_valve_test_position_table_2, 
			last_valve_test_position_table_3, 
			last_valve_test_position_table_4, 
			last_valve_test_position_table_5, 
			last_valve_test_position_table_6, 
			last_valve_test_position_table_7, 
			last_valve_test_position_table_8, 
			last_valve_test_position_table_9, 
			last_valve_test_position_table_10,
			last_valve_test_position_table_11,
			last_valve_test_position_table_12,
			last_valve_test_position_table_13,
			last_valve_test_position_table_14,
			last_valve_test_position_table_15,
			last_valve_test_position_table_16,
			last_valve_test_position_table_17,
			last_valve_test_position_table_18,
			last_valve_test_position_table_19,
			last_valve_test_position_table_20,
			last_valve_test_position_table_21,
			last_valve_test_position_table_22,
			last_valve_test_position_table_23,
			last_valve_test_position_table_24,
			last_valve_test_position_table_25
		}
	}
}

COMMAND read_last_valve_test_position_table_II
{
	BLOCK transducer_block_1;
	INDEX 162;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			last_valve_test_position_table_26,
			last_valve_test_position_table_27,
			last_valve_test_position_table_28,
			last_valve_test_position_table_29,
			last_valve_test_position_table_30,
			last_valve_test_position_table_31,
			last_valve_test_position_table_32,
			last_valve_test_position_table_33,
			last_valve_test_position_table_34,
			last_valve_test_position_table_35,
			last_valve_test_position_table_36,
			last_valve_test_position_table_37,
			last_valve_test_position_table_38,
			last_valve_test_position_table_39,
			last_valve_test_position_table_40,
			last_valve_test_position_table_41,
			last_valve_test_position_table_42,
			last_valve_test_position_table_43,
			last_valve_test_position_table_44,
			last_valve_test_position_table_45,
			last_valve_test_position_table_46,
			last_valve_test_position_table_47,
			last_valve_test_position_table_48,
			last_valve_test_position_table_49,
			last_valve_test_position_table_50
		}
	}
}

COMMAND read_valve_travel_vs_time_trend
{
	BLOCK transducer_block_1;
	INDEX 138;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
				valve_travel_vs_time_trend_table_1, 
				valve_travel_vs_time_trend_table_2, 
				valve_travel_vs_time_trend_table_3,
				valve_travel_vs_time_trend_table_4, 
				valve_travel_vs_time_trend_table_5, 
				valve_travel_vs_time_trend_table_6, 
				valve_travel_vs_time_trend_table_7, 
				valve_travel_vs_time_trend_table_8, 
				valve_travel_vs_time_trend_table_9, 
				valve_travel_vs_time_trend_table_10,
				elapsed_trend_time
		}
	}
}

COMMAND read_load_factor_cheat_zero {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{load_factor_cheat_zero}}}
COMMAND read_deviation_cheat_zero {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{deviation_cheat_zero}}}
COMMAND read_time_pr_cheat_zero {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{time_pr_cheat_zero}}}
COMMAND read_travel_cheat_0 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{travel_cheat_0}}}
COMMAND read_travel_cheat_1 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{travel_cheat_1}}}
COMMAND read_travel_cheat_2 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{travel_cheat_2}}}
COMMAND read_travel_cheat_3 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{travel_cheat_3}}}
COMMAND read_travel_cheat_4 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{travel_cheat_4}}}
COMMAND read_travel_cheat_5 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{travel_cheat_5}}}
COMMAND read_travel_cheat_6 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{travel_cheat_6}}}
COMMAND read_travel_cheat_7 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{travel_cheat_7}}}
COMMAND read_travel_cheat_8 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{travel_cheat_8}}}
COMMAND read_travel_cheat_9 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{travel_cheat_9}}}
COMMAND read_travel_cheat_10 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{travel_cheat_10}}}





COMMAND read_inp_cheat_0 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_0}}}
COMMAND read_inp_cheat_1 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_1}}}
COMMAND read_inp_cheat_2 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_2}}}
COMMAND read_inp_cheat_3 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_3}}}
COMMAND read_inp_cheat_4 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_4}}}
COMMAND read_inp_cheat_5 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_5}}}
COMMAND read_inp_cheat_6 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_6}}}
COMMAND read_inp_cheat_7 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_7}}}
COMMAND read_inp_cheat_8 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_8}}}
COMMAND read_inp_cheat_9 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_9}}}
COMMAND read_inp_cheat_10 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_10}}}
COMMAND read_inp_cheat_11 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_11}}}
COMMAND read_inp_cheat_12 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_12}}}
COMMAND read_inp_cheat_13 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_13}}}
COMMAND read_inp_cheat_14 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_14}}}
COMMAND read_inp_cheat_15 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_15}}}
COMMAND read_inp_cheat_16 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_16}}}
COMMAND read_inp_cheat_17 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_17}}}
COMMAND read_inp_cheat_18 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_18}}}
COMMAND read_inp_cheat_19 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_19}}}
COMMAND read_inp_cheat_20 {BLOCK transducer_block_1;INDEX 200;OPERATION READ;TRANSACTION{REQUEST{}REPLY{inp_cheat_20}}}


COMMAND read_vc_state 
{
	BLOCK transducer_block_1;
	INDEX 174;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		   vc_state
		}
	}
}


COMMAND read_vc_cmd  
{
	BLOCK transducer_block_1;
	INDEX 176;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
		   vc_cmd 
		}
	}
}


COMMAND read_vc_action 
{
	BLOCK transducer_block_1;
	INDEX 178;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			action_id,
			action_ctrl,
			action_status,
			data1,
			data2,
			data3,
			data4,
			data5			
	   	}
	}
}



COMMAND write_vc_action
{
	BLOCK transducer_block_1;
	INDEX 178;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			action_id,
			action_ctrl,
			action_status,
			data1,
			data2,
			data3,
			data4,
			data5	
		}
		REPLY
		{
		}
	}
}

/***********************************************************************/
/* Commands - Function Block										   */
/***********************************************************************/

COMMAND read_func1_blk
{
	BLOCK function_block_1;
	INDEX 0;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_blk_reserve, func1_blk_object, func1_blk_parent_class, func1_blk_class,
			func1_blk_dd_reference, func1_blk_dd_rev, func1_blk_profile, func1_blk_profile_rev,
			func1_blk_execution_time, func1_blk_num_parameters, func1_blk_index_view_1,
			func1_blk_num_view_lists
		}
	}
}

COMMAND read_func1_st_rev
{
	BLOCK function_block_1;
	INDEX 1;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_st_rev   
		}
	}
}

COMMAND read_func1_tag_desc
{
	BLOCK function_block_1;
	INDEX 2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_tag_desc
		}
	}
}

COMMAND write_func1_tag_desc
{
	BLOCK function_block_1;
	INDEX 2;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_tag_desc
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_strategy
{
	BLOCK function_block_1;
	INDEX 3;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_strategy
		}
	}
}

COMMAND write_func1_strategy
{
	BLOCK function_block_1;
	INDEX 3;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_strategy
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_alert_key
{
	BLOCK function_block_1;
	INDEX 4;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_alert_key
		}
	}
}

COMMAND write_func1_alert_key
{
	BLOCK function_block_1;
	INDEX 4;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_alert_key
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_target_mode
{
	BLOCK function_block_1;
	INDEX 5;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_target_mode
		}
	}
}

COMMAND write_func1_target_mode
{
	BLOCK function_block_1;
	INDEX 5;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_target_mode
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_mode
{
	BLOCK function_block_1;
	INDEX 6;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			 func1_actual_mode, func1_permitted_mode, func1_normal_mode
		}
	}
}

COMMAND read_func1_alarm
{
	BLOCK function_block_1;
	INDEX 7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_current_state_alarm_sum, func1_unacknowledged_state_alarm_sum,
			func1_unreported_state_alarm_sum, func1_disabled_state_alarm_sum
		}
	}
}

COMMAND read_func1_batch_information
{
	BLOCK function_block_1;
	INDEX 8;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_batch_id, func1_batch_unit, func1_batch_operation, func1_batch_phase
		}
	}
}

COMMAND write_func1_batch_information
{
	BLOCK function_block_1;
	INDEX 8;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_batch_id, func1_batch_unit, func1_batch_operation, func1_batch_phase
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_setpoint 
{
	BLOCK function_block_1;
	INDEX 9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_setpoint_value,
			func1_setpoint_status_quality	<0xFC>,
			func1_setpoint_status_limit		<0x03>
		}
	}
}

COMMAND write_func1_setpoint 
{
	BLOCK function_block_1;
	INDEX 9;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_setpoint_value,
			func1_setpoint_status_quality	<0xFC>,
			func1_setpoint_status_limit		<0x03>
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_pv 
{
	BLOCK function_block_1;
	INDEX 11;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_pv_upper_range_value, func1_pv_lower_range_value, 
			func1_pv_unit, func1_pv_decimal_point
		}
	}
}

COMMAND write_func1_pv 
{
	BLOCK function_block_1;
	INDEX 11;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_pv_upper_range_value, func1_pv_lower_range_value, 
			func1_pv_unit, func1_pv_decimal_point
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_readback 
{
	BLOCK function_block_1;
	INDEX 12;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_readback_value,
			func1_readback_status_quality	<0xFC>,
			func1_readback_status_limit		<0x03>
		}
	}
}

COMMAND read_func1_rcas_in
{
	BLOCK function_block_1;
	INDEX 14;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_rcas_in_value,
			func1_rcas_in_status_quality	<0xFC>,
			func1_rcas_in_status_limit		<0x03>
		}
	}
}

COMMAND write_func1_rcas_in
{
	BLOCK function_block_1;
	INDEX 14;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_rcas_in_value,
			func1_rcas_in_status_quality	<0xFC>,
			func1_rcas_in_status_limit		<0x03>
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_in_channel 
{
	BLOCK function_block_1;
	INDEX 21;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_in_channel
		}
	}
}

COMMAND write_func1_in_channel 
{
	BLOCK function_block_1;
	INDEX 21;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_in_channel
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_out_channel 
{
	BLOCK function_block_1;
	INDEX 22;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_out_channel
		}
	}
}

COMMAND write_func1_out_channel 
{
	BLOCK function_block_1;
	INDEX 22;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_out_channel
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_fsafe_time 
{
	BLOCK function_block_1;
	INDEX 23;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_fsafe_time
		}
	}
}

COMMAND write_func1_fsafe_time 
{
	BLOCK function_block_1;
	INDEX 23;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_fsafe_time
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_fsafe_type
{
	BLOCK function_block_1;
	INDEX 24;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_fsafe_type
		}
	}
}

COMMAND write_func1_fsafe_type
{
	BLOCK function_block_1;
	INDEX 24;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_fsafe_type
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_fsafe_value
{
	BLOCK function_block_1;
	INDEX 25;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_fsafe_value
		}
	}
}

COMMAND write_func1_fsafe_value
{
	BLOCK function_block_1;
	INDEX 25;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_fsafe_value
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_rcas_out
{
	BLOCK function_block_1;
	INDEX 27;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_rcas_out_value,
			func1_rcas_out_status_quality	<0xFC>,
			func1_rcas_out_status_limit		<0x03>
		}
	}
}

COMMAND read_func1_current_position 
{
	BLOCK function_block_1;
	INDEX 31;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_position_discrete_value,
			func1_position_discrete_status_quality	<0xFC>,
			func1_position_discrete_status_limit	<0x03>
		}
	}
}

COMMAND read_func1_setpoint_deviation 
{
	BLOCK function_block_1;
	INDEX 32;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_setpoint_deviation
		}
	}
}

COMMAND read_func1_check_back 
{
	BLOCK function_block_1;
	INDEX 33;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_check_back
		}
	}
}

COMMAND read_func1_check_back_mask 
{
	BLOCK function_block_1;
	INDEX 34;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_check_back_mask
		}
	}
}

COMMAND read_func1_simulate 
{
	BLOCK function_block_1;
	INDEX 35;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_simulate_status_quality	<0xFC>,
			func1_simulate_status_limit		<0x03>,
			func1_simulate_value, 
			func1_simulation_enabled
		}
	}
}

COMMAND write_func1_simulate 
{
	BLOCK function_block_1;
	INDEX 35;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_simulate_status_quality	<0xFC>,
			func1_simulate_status_limit		<0x03>,
			func1_simulate_value, 
			func1_simulation_enabled
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_increase_close 
{
	BLOCK function_block_1;
	INDEX 36;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_increase_close
		}
	}
}

COMMAND write_func1_increase_close 
{
	BLOCK function_block_1;
	INDEX 36;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_increase_close
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_out 
{
	BLOCK function_block_1;
	INDEX 37;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_out_value,
			func1_out_status_quality	<0xFC>,
			func1_out_status_limit		<0x03>

		}
	}
}

COMMAND write_func1_out 
{
	BLOCK function_block_1;
	INDEX 37;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_out_value,
			func1_out_status_quality	<0xFC>,
			func1_out_status_limit		<0x03>
		}
		REPLY
		{
		}
	}
}

COMMAND read_func1_out_scale 
{
	BLOCK function_block_1;
	INDEX 38;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			func1_out_upper_range_value, func1_out_lower_range_value, 
			func1_out_unit, func1_out_decimal_point 
		}
	}
}

COMMAND write_func1_out_scale 
{
	BLOCK function_block_1;
	INDEX 38;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			func1_out_upper_range_value, func1_out_lower_range_value, 
			func1_out_unit, func1_out_decimal_point 
		}
		REPLY
		{
		}
	}
}

COMMAND read_deviation_table
{
	BLOCK transducer_block_1;
	INDEX 134;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{ 
		}
		REPLY
		{
			deviation_table_1,
			deviation_table_2, 
			deviation_table_3, 
			deviation_table_4, 
			deviation_table_5, 
			deviation_table_6, 
			deviation_table_7, 
			deviation_table_8, 
			deviation_table_9, 
			deviation_table_10,
			deviation_table_11,
			deviation_table_12,
			deviation_table_13,
			deviation_table_14,
			deviation_table_15,
			deviation_table_16,
			deviation_table_17,
			deviation_table_18,
			deviation_table_19,
			deviation_table_20
		}
	}
}

COMMAND read_deviation_time_table
{
	BLOCK transducer_block_1;
	INDEX 132;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{ 
		}
		REPLY
		{
			deviation_time_table_1,
			deviation_time_table_2, 
			deviation_time_table_3, 
			deviation_time_table_4, 
			deviation_time_table_5, 
			deviation_time_table_6, 
			deviation_time_table_7, 
			deviation_time_table_8, 
			deviation_time_table_9, 
			deviation_time_table_10,
			deviation_time_table_11,
			deviation_time_table_12,
			deviation_time_table_13,
			deviation_time_table_14,
			deviation_time_table_15,
			deviation_time_table_16,
			deviation_time_table_17,
			deviation_time_table_18,
			deviation_time_table_19,
			deviation_time_table_20
		}
	}
}

COMMAND read_load_factor_table
{
	BLOCK transducer_block_1;
	INDEX 142;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{ 
		}
		REPLY
		{
			load_factor_table_1,
			load_factor_table_2, 
			load_factor_table_3, 
			load_factor_table_4, 
			load_factor_table_5, 
			load_factor_table_6, 
			load_factor_table_7, 
			load_factor_table_8, 
			load_factor_table_9, 
			load_factor_table_10,
			load_factor_table_11,
			load_factor_table_12,
			load_factor_table_13,
			load_factor_table_14,
			load_factor_table_15,
			load_factor_table_16,
			load_factor_table_17,
			load_factor_table_18,
			load_factor_table_19,
			load_factor_table_20
		}
	}
}

COMMAND read_load_factor_time_table
{
	BLOCK transducer_block_1;
	INDEX 140;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{ 
		}
		REPLY
		{
			load_factor_time_table_1,
			load_factor_time_table_2, 
			load_factor_time_table_3, 
			load_factor_time_table_4, 
			load_factor_time_table_5, 
			load_factor_time_table_6, 
			load_factor_time_table_7, 
			load_factor_time_table_8, 
			load_factor_time_table_9, 
			load_factor_time_table_10,
			load_factor_time_table_11,
			load_factor_time_table_12,
			load_factor_time_table_13,
			load_factor_time_table_14,
			load_factor_time_table_15,
			load_factor_time_table_16,
			load_factor_time_table_17,
			load_factor_time_table_18,
			load_factor_time_table_19,
			load_factor_time_table_20
		}
	}
}



COMMAND read_event_table
{
	BLOCK transducer_block_1;
	INDEX 126;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{ 
		}
		REPLY
		{
			event_1,
			event_2, 
			event_3, 
			event_4, 
			event_5, 
			event_6, 
			event_7, 
			event_8, 
			event_9, 
			event_10,
			event_11,
			event_12,
			event_13,
			event_14,
			event_15,
			event_16,
			event_17,
			event_18,
			event_19,
			event_20
		}
	}
}


COMMAND read_event_count_table
{
	BLOCK transducer_block_1;
	INDEX 128;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{ 
		}
		REPLY
		{
			event_count_1,
			event_count_2, 
			event_count_3, 
			event_count_4, 
			event_count_5, 
			event_count_6, 
			event_count_7, 
			event_count_8, 
			event_count_9, 
			event_count_10,
			event_count_11,
			event_count_12,
			event_count_13,
			event_count_14,
			event_count_15,
			event_count_16,
			event_count_17,
			event_count_18,
			event_count_19,
			event_count_20
		}
	}
}

COMMAND read_event_time_table
{
	BLOCK transducer_block_1;
	INDEX 130;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{ 
		}
		REPLY
		{
			event_time_1,
			event_time_2, 
			event_time_3, 
			event_time_4, 
			event_time_5, 
			event_time_6, 
			event_time_7, 
			event_time_8, 
			event_time_9, 
			event_time_10,
			event_time_11,
			event_time_12,
			event_time_13,
			event_time_14,
			event_time_15,
			event_time_16,
			event_time_17,
			event_time_18,
			event_time_19,
			event_time_20
		}
	}
}

COMMAND read_source_table
{
	BLOCK transducer_block_1;
	INDEX 114;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{ 
		}
		REPLY
		{
			source_1,
			source_2, 
			source_3, 
			source_4, 
			source_5, 
			source_6, 
			source_7, 
			source_8, 
			source_9, 
			source_10,
			source_11,
			source_12,
			source_13,
			source_14,
			source_15,
			source_16,
			source_17,
			source_18,
			source_19,
			source_20,
			source_21,
			fill_source
		}
	}
}

COMMAND write_source_table
{
	BLOCK transducer_block_1;
	INDEX 114;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{ 
			source_1,
			source_2, 
			source_3, 
			source_4, 
			source_5, 
			source_6, 
			source_7, 
			source_8, 
			source_9, 
			source_10,
			source_11,
			source_12,
			source_13,
			source_14,
			source_15,
			source_16,
			source_17,
			source_18,
			source_19,
			source_20,
			source_21,
			fill_source
		}
		REPLY
		{
		}
	}
}

COMMAND read_target_table
{
	BLOCK transducer_block_1;
	INDEX 116;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{ 
		}
		REPLY
		{
			target_1,
			target_2, 
			target_3, 
			target_4, 
			target_5, 
			target_6, 
			target_7, 
			target_8, 
			target_9, 
			target_10,
			target_11,
			target_12,
			target_13,
			target_14,
			target_15,
			target_16,
			target_17,
			target_18,
			target_19,
			target_20,
			target_21,
			fill_target
		}
	}
}

COMMAND write_target_table
{
	BLOCK transducer_block_1;
	INDEX 116;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{ 
			target_1,
			target_2, 
			target_3, 
			target_4, 
			target_5, 
			target_6, 
			target_7, 
			target_8, 
			target_9, 
			target_10,
			target_11,
			target_12,
			target_13,
			target_14,
			target_15,
			target_16,
			target_17,
			target_18,
			target_19,
			target_20,
			target_21,
			fill_target
		}
		REPLY
		{
		}
	}
}

COMMAND read_signal_mod_table
{
	BLOCK transducer_block_1;
	INDEX 118;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{ 
		}
		REPLY
		{
			signal_mod_1,
			signal_mod_2, 
			signal_mod_3, 
			signal_mod_4, 
			signal_mod_5, 
			signal_mod_6, 
			signal_mod_7, 
			signal_mod_8, 
			signal_mod_9, 
			signal_mod_10,
			signal_mod_11,
			signal_mod_12,
			signal_mod_13,
			signal_mod_14,
			signal_mod_15,
			signal_mod_16,
			signal_mod_17,
			signal_mod_18,
			signal_mod_19,
			signal_mod_20,
			signal_mod_21,
			characterization
		}
	}
}

COMMAND write_signal_mod_table
{
	BLOCK transducer_block_1;
	INDEX 118;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{ 
			signal_mod_1,
			signal_mod_2, 
			signal_mod_3, 
			signal_mod_4, 
			signal_mod_5, 
			signal_mod_6, 
			signal_mod_7, 
			signal_mod_8, 
			signal_mod_9, 
			signal_mod_10,
			signal_mod_11,
			signal_mod_12,
			signal_mod_13,
			signal_mod_14,
			signal_mod_15,
			signal_mod_16,
			signal_mod_17,
			signal_mod_18,
			signal_mod_19,
			signal_mod_20,
			signal_mod_21,
			characterization
		}
		REPLY
		{
		}
	}
}

COMMAND read_vc_gw
{
	BLOCK transducer_block_1;
	INDEX 180;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{ 
		}
		REPLY
		{
			vc_gw_index,
			vc_gw_rw,
			vc_gw_data,			
			vc_gw_status
		}
	}
}

COMMAND write_vc_gw
{
	BLOCK transducer_block_1;
	INDEX 180;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{ 
			vc_gw_index,
			vc_gw_rw,
			vc_gw_data,
			vc_gw_status
		}
		REPLY
		{
		}
	}
}


COMMAND read_limit_switches
{
	BLOCK transducer_block_1;
	INDEX 105;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{ 
		}
		REPLY
		{
			limit_switches
		}
	}
}

COMMAND write_limit_switches
{
	BLOCK transducer_block_1;
	INDEX 105;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{ 
			limit_switches
		}
		REPLY
		{
		}
	}
}

COMMAND read_load
{
	SLOT	201;
	INDEX	2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{ 
		}
		REPLY
		{
			current_load,
			max_load,
			avg_load
		}
	}
}

COMMAND read_fdl_err_stats
{
	SLOT	201;
	INDEX	7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{ 
		}
		REPLY
		{
			fdl_err_stats_1,
			fdl_err_stats_2,
			fdl_err_stats_3,
			fdl_err_stats_4,
			fdl_err_stats_5,
			fdl_err_stats_6,
			fdl_err_stats_7,
			fdl_err_stats_8,
			fdl_err_stats_9,
			fdl_err_stats_10
		}
	}
}




